article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
nav,
section {
  display: block;
}
audio,
canvas,
video {
  display: inline-block;
  *display: inline;
  *zoom: 1;
}
audio:not([controls]) {
  display: none;
}
html {
  font-size: 100%;
  -webkit-text-size-adjust: 100%;
  -ms-text-size-adjust: 100%;
}
a:focus {
  outline: thin dotted #333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
a:hover,
a:active {
  outline: 0;
}
sub,
sup {
  position: relative;
  font-size: 75%;
  line-height: 0;
  vertical-align: baseline;
}
sup {
  top: -0.5em;
}
sub {
  bottom: -0.25em;
}
img {
  /* Responsive images (ensure images don't scale beyond their parents) */
  max-width: 100%;
  /* Part 1: Set a maxium relative to the parent */
  width: auto\9;
  /* IE7-8 need help adjusting responsive images */
  height: auto;
  /* Part 2: Scale the height according to the width, otherwise you get stretching */
  vertical-align: middle;
  border: 0;
  -ms-interpolation-mode: bicubic;
}
#map_canvas img,
.google-maps img {
  max-width: none;
}
button,
input,
select,
textarea {
  margin: 0;
  font-size: 100%;
  vertical-align: middle;
}
button,
input {
  *overflow: visible;
  line-height: normal;
}
button::-moz-focus-inner,
input::-moz-focus-inner {
  padding: 0;
  border: 0;
}
button,
html input[type="button"],
input[type="reset"],
input[type="submit"] {
  -webkit-appearance: button;
  cursor: pointer;
}
label,
select,
button,
input[type="button"],
input[type="reset"],
input[type="submit"],
input[type="radio"],
input[type="checkbox"] {
  cursor: pointer;
}
input[type="search"] {
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
  -webkit-appearance: textfield;
}
input[type="search"]::-webkit-search-decoration,
input[type="search"]::-webkit-search-cancel-button {
  -webkit-appearance: none;
}
textarea {
  overflow: auto;
  vertical-align: top;
}
@media print {
  * {
    text-shadow: none !important;
    color: #000 !important;
    background: transparent !important;
    box-shadow: none !important;
  }
  a,
  a:visited {
    text-decoration: underline;
  }
  a[href]:after {
    content: " (" attr(href) ")";
  }
  abbr[title]:after {
    content: " (" attr(title) ")";
  }
  .ir a:after,
  a[href^="javascript:"]:after,
  a[href^="#"]:after {
    content: "";
  }
  pre,
  blockquote {
    border: 1px solid #999;
    page-break-inside: avoid;
  }
  thead {
    display: table-header-group;
  }
  tr,
  img {
    page-break-inside: avoid;
  }
  img {
    max-width: 100% !important;
  }
  @page {
    margin: 0.5cm;
  }
  p,
  h2,
  h3 {
    orphans: 3;
    widows: 3;
  }
  h2,
  h3 {
    page-break-after: avoid;
  }
}
.clearfix {
  *zoom: 1;
}
.clearfix:before,
.clearfix:after {
  display: table;
  content: "";
  line-height: 0;
}
.clearfix:after {
  clear: both;
}
.hide-text {
  font: 0/0 a;
  color: transparent;
  text-shadow: none;
  background-color: transparent;
  border: 0;
}
.input-block-level {
  display: block;
  width: 100%;
  min-height: 30px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
body {
  margin: 0;
  font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif;
  font-size: 14px;
  line-height: 20px;
  color: #444444;
  background-color: #eeeeee;
}
a {
  color: #e73892;
  text-decoration: none;
}
a:hover,
a:focus {
  color: #bc176c;
  text-decoration: underline;
}
.img-rounded {
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
}
.img-polaroid {
  padding: 4px;
  background-color: #fff;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, 0.2);
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
}
.img-circle {
  -webkit-border-radius: 500px;
  -moz-border-radius: 500px;
  border-radius: 500px;
}
.row {
  margin-left: -20px;
  *zoom: 1;
}
.row:before,
.row:after {
  display: table;
  content: "";
  line-height: 0;
}
.row:after {
  clear: both;
}
[class*="span"] {
  float: left;
  min-height: 1px;
  margin-left: 20px;
}
.container,
.navbar-static-top .container,
.navbar-fixed-top .container,
.navbar-fixed-bottom .container {
  width: 940px;
}
.span12 {
  width: 940px;
}
.span11 {
  width: 860px;
}
.span10 {
  width: 780px;
}
.span9 {
  width: 700px;
}
.span8 {
  width: 620px;
}
.span7 {
  width: 540px;
}
.span6 {
  width: 460px;
}
.span5 {
  width: 380px;
}
.span4 {
  width: 300px;
}
.span3 {
  width: 220px;
}
.span2 {
  width: 140px;
}
.span1 {
  width: 60px;
}
.offset12 {
  margin-left: 980px;
}
.offset11 {
  margin-left: 900px;
}
.offset10 {
  margin-left: 820px;
}
.offset9 {
  margin-left: 740px;
}
.offset8 {
  margin-left: 660px;
}
.offset7 {
  margin-left: 580px;
}
.offset6 {
  margin-left: 500px;
}
.offset5 {
  margin-left: 420px;
}
.offset4 {
  margin-left: 340px;
}
.offset3 {
  margin-left: 260px;
}
.offset2 {
  margin-left: 180px;
}
.offset1 {
  margin-left: 100px;
}
.row-fluid {
  width: 100%;
  *zoom: 1;
}
.row-fluid:before,
.row-fluid:after {
  display: table;
  content: "";
  line-height: 0;
}
.row-fluid:after {
  clear: both;
}
.row-fluid [class*="span"] {
  display: block;
  width: 100%;
  min-height: 30px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  float: left;
  margin-left: 2.12765957%;
  *margin-left: 2.07446809%;
}
.row-fluid [class*="span"]:first-child {
  margin-left: 0;
}
.row-fluid .controls-row [class*="span"] + [class*="span"] {
  margin-left: 2.12765957%;
}
.row-fluid .span12 {
  width: 100%;
  *width: 99.94680851%;
}
.row-fluid .span11 {
  width: 91.4893617%;
  *width: 91.43617021%;
}
.row-fluid .span10 {
  width: 82.9787234%;
  *width: 82.92553191%;
}
.row-fluid .span9 {
  width: 74.46808511%;
  *width: 74.41489362%;
}
.row-fluid .span8 {
  width: 65.95744681%;
  *width: 65.90425532%;
}
.row-fluid .span7 {
  width: 57.44680851%;
  *width: 57.39361702%;
}
.row-fluid .span6 {
  width: 48.93617021%;
  *width: 48.88297872%;
}
.row-fluid .span5 {
  width: 40.42553191%;
  *width: 40.37234043%;
}
.row-fluid .span4 {
  width: 31.91489362%;
  *width: 31.86170213%;
}
.row-fluid .span3 {
  width: 23.40425532%;
  *width: 23.35106383%;
}
.row-fluid .span2 {
  width: 14.89361702%;
  *width: 14.84042553%;
}
.row-fluid .span1 {
  width: 6.38297872%;
  *width: 6.32978723%;
}
.row-fluid .offset12 {
  margin-left: 104.25531915%;
  *margin-left: 104.14893617%;
}
.row-fluid .offset12:first-child {
  margin-left: 102.12765957%;
  *margin-left: 102.0212766%;
}
.row-fluid .offset11 {
  margin-left: 95.74468085%;
  *margin-left: 95.63829787%;
}
.row-fluid .offset11:first-child {
  margin-left: 93.61702128%;
  *margin-left: 93.5106383%;
}
.row-fluid .offset10 {
  margin-left: 87.23404255%;
  *margin-left: 87.12765957%;
}
.row-fluid .offset10:first-child {
  margin-left: 85.10638298%;
  *margin-left: 85%;
}
.row-fluid .offset9 {
  margin-left: 78.72340426%;
  *margin-left: 78.61702128%;
}
.row-fluid .offset9:first-child {
  margin-left: 76.59574468%;
  *margin-left: 76.4893617%;
}
.row-fluid .offset8 {
  margin-left: 70.21276596%;
  *margin-left: 70.10638298%;
}
.row-fluid .offset8:first-child {
  margin-left: 68.08510638%;
  *margin-left: 67.9787234%;
}
.row-fluid .offset7 {
  margin-left: 61.70212766%;
  *margin-left: 61.59574468%;
}
.row-fluid .offset7:first-child {
  margin-left: 59.57446809%;
  *margin-left: 59.46808511%;
}
.row-fluid .offset6 {
  margin-left: 53.19148936%;
  *margin-left: 53.08510638%;
}
.row-fluid .offset6:first-child {
  margin-left: 51.06382979%;
  *margin-left: 50.95744681%;
}
.row-fluid .offset5 {
  margin-left: 44.68085106%;
  *margin-left: 44.57446809%;
}
.row-fluid .offset5:first-child {
  margin-left: 42.55319149%;
  *margin-left: 42.44680851%;
}
.row-fluid .offset4 {
  margin-left: 36.17021277%;
  *margin-left: 36.06382979%;
}
.row-fluid .offset4:first-child {
  margin-left: 34.04255319%;
  *margin-left: 33.93617021%;
}
.row-fluid .offset3 {
  margin-left: 27.65957447%;
  *margin-left: 27.55319149%;
}
.row-fluid .offset3:first-child {
  margin-left: 25.53191489%;
  *margin-left: 25.42553191%;
}
.row-fluid .offset2 {
  margin-left: 19.14893617%;
  *margin-left: 19.04255319%;
}
.row-fluid .offset2:first-child {
  margin-left: 17.0212766%;
  *margin-left: 16.91489362%;
}
.row-fluid .offset1 {
  margin-left: 10.63829787%;
  *margin-left: 10.53191489%;
}
.row-fluid .offset1:first-child {
  margin-left: 8.5106383%;
  *margin-left: 8.40425532%;
}
[class*="span"].hide,
.row-fluid [class*="span"].hide {
  display: none;
}
[class*="span"].pull-right,
.row-fluid [class*="span"].pull-right {
  float: right;
}
.container {
  margin-right: auto;
  margin-left: auto;
  *zoom: 1;
}
.container:before,
.container:after {
  display: table;
  content: "";
  line-height: 0;
}
.container:after {
  clear: both;
}
.container-fluid {
  padding-right: 20px;
  padding-left: 20px;
  *zoom: 1;
}
.container-fluid:before,
.container-fluid:after {
  display: table;
  content: "";
  line-height: 0;
}
.container-fluid:after {
  clear: both;
}
p {
  margin: 0 0 10px;
}
.lead {
  margin-bottom: 20px;
  font-size: 21px;
  font-weight: 200;
  line-height: 30px;
}
small {
  font-size: 85%;
}
strong {
  font-weight: bold;
}
em {
  font-style: italic;
}
cite {
  font-style: normal;
}
.muted {
  color: #999999;
}
a.muted:hover,
a.muted:focus {
  color: #808080;
}
.text-warning {
  color: #c09853;
}
a.text-warning:hover,
a.text-warning:focus {
  color: #a47e3c;
}
.text-error {
  color: #b55457;
}
a.text-error:hover,
a.text-error:focus {
  color: #954143;
}
.text-info {
  color: #3a87ad;
}
a.text-info:hover,
a.text-info:focus {
  color: #2d6987;
}
.text-success {
  color: #468847;
}
a.text-success:hover,
a.text-success:focus {
  color: #356635;
}
.text-left {
  text-align: left;
}
.text-right {
  text-align: right;
}
.text-center {
  text-align: center;
}
h1,
h2,
h3,
h4,
h5,
h6 {
  margin: 10px 0;
  font-family: inherit;
  font-weight: bold;
  line-height: 20px;
  color: inherit;
  text-rendering: optimizelegibility;
}
h1 small,
h2 small,
h3 small,
h4 small,
h5 small,
h6 small {
  font-weight: normal;
  line-height: 1;
  color: #999999;
}
h1,
h2,
h3 {
  line-height: 40px;
}
h1 {
  font-size: 38.5px;
}
h2 {
  font-size: 31.5px;
}
h3 {
  font-size: 24.5px;
}
h4 {
  font-size: 17.5px;
}
h5 {
  font-size: 14px;
}
h6 {
  font-size: 11.9px;
}
h1 small {
  font-size: 24.5px;
}
h2 small {
  font-size: 17.5px;
}
h3 small {
  font-size: 14px;
}
h4 small {
  font-size: 14px;
}
.page-header {
  padding-bottom: 9px;
  margin: 20px 0 30px;
  border-bottom: 1px solid #eeeeee;
}
ul,
ol {
  padding: 0;
  margin: 0 0 10px 25px;
}
ul ul,
ul ol,
ol ol,
ol ul {
  margin-bottom: 0;
}
li {
  line-height: 20px;
}
ul.unstyled,
ol.unstyled {
  margin-left: 0;
  list-style: none;
}
ul.inline,
ol.inline {
  margin-left: 0;
  list-style: none;
}
ul.inline > li,
ol.inline > li {
  display: inline-block;
  *display: inline;
  /* IE7 inline-block hack */
  *zoom: 1;
  padding-left: 5px;
  padding-right: 5px;
}
dl {
  margin-bottom: 20px;
}
dt,
dd {
  line-height: 20px;
}
dt {
  font-weight: bold;
}
dd {
  margin-left: 10px;
}
.dl-horizontal {
  *zoom: 1;
}
.dl-horizontal:before,
.dl-horizontal:after {
  display: table;
  content: "";
  line-height: 0;
}
.dl-horizontal:after {
  clear: both;
}
.dl-horizontal dt {
  float: left;
  width: 160px;
  clear: left;
  text-align: right;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.dl-horizontal dd {
  margin-left: 180px;
}
hr {
  margin: 20px 0;
  border: 0;
  border-top: 1px solid #eeeeee;
  border-bottom: 1px solid #ffffff;
}
abbr[title],
abbr[data-original-title] {
  cursor: help;
  border-bottom: 1px dotted #999999;
}
abbr.initialism {
  font-size: 90%;
  text-transform: uppercase;
}
blockquote {
  padding: 0 0 0 15px;
  margin: 0 0 20px;
  border-left: 5px solid #eeeeee;
}
blockquote p {
  margin-bottom: 0;
  font-size: 17.5px;
  font-weight: 300;
  line-height: 1.25;
}
blockquote small {
  display: block;
  line-height: 20px;
  color: #999999;
}
blockquote small:before {
  content: '\2014 \00A0';
}
blockquote.pull-right {
  float: right;
  padding-right: 15px;
  padding-left: 0;
  border-right: 5px solid #eeeeee;
  border-left: 0;
}
blockquote.pull-right p,
blockquote.pull-right small {
  text-align: right;
}
blockquote.pull-right small:before {
  content: '';
}
blockquote.pull-right small:after {
  content: '\00A0 \2014';
}
q:before,
q:after,
blockquote:before,
blockquote:after {
  content: "";
}
address {
  display: block;
  margin-bottom: 20px;
  font-style: normal;
  line-height: 20px;
}
code,
pre {
  padding: 0 3px 2px;
  font-family: Monaco, Menlo, Consolas, "Courier New", monospace;
  font-size: 12px;
  color: #333333;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
code {
  padding: 2px 4px;
  color: #d14;
  background-color: #f7f7f9;
  border: 1px solid #e1e1e8;
  white-space: nowrap;
}
pre {
  display: block;
  padding: 9.5px;
  margin: 0 0 10px;
  font-size: 13px;
  line-height: 20px;
  word-break: break-all;
  word-wrap: break-word;
  white-space: pre;
  white-space: pre-wrap;
  background-color: #f5f5f5;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, 0.15);
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
pre.prettyprint {
  margin-bottom: 20px;
}
pre code {
  padding: 0;
  color: inherit;
  white-space: pre;
  white-space: pre-wrap;
  background-color: transparent;
  border: 0;
}
.pre-scrollable {
  max-height: 340px;
  overflow-y: scroll;
}
form {
  margin: 0 0 20px;
}
fieldset {
  padding: 0;
  margin: 0;
  border: 0;
}
legend {
  display: block;
  width: 100%;
  padding: 0;
  margin-bottom: 20px;
  font-size: 21px;
  line-height: 40px;
  color: #333333;
  border: 0;
  border-bottom: 1px solid #e5e5e5;
}
legend small {
  font-size: 15px;
  color: #999999;
}
label,
input,
button,
select,
textarea {
  font-size: 14px;
  font-weight: normal;
  line-height: 20px;
}
input,
button,
select,
textarea {
  font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif;
}
label {
  display: block;
  margin-bottom: 5px;
}
select,
textarea,
input[type="text"],
input[type="password"],
input[type="datetime"],
input[type="datetime-local"],
input[type="date"],
input[type="month"],
input[type="time"],
input[type="week"],
input[type="number"],
input[type="email"],
input[type="url"],
input[type="search"],
input[type="tel"],
input[type="color"],
.uneditable-input {
  display: inline-block;
  height: 20px;
  padding: 4px 6px;
  margin-bottom: 10px;
  font-size: 14px;
  line-height: 20px;
  color: #555555;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  vertical-align: middle;
}
input,
textarea,
.uneditable-input {
  width: 206px;
}
textarea {
  height: auto;
}
textarea,
input[type="text"],
input[type="password"],
input[type="datetime"],
input[type="datetime-local"],
input[type="date"],
input[type="month"],
input[type="time"],
input[type="week"],
input[type="number"],
input[type="email"],
input[type="url"],
input[type="search"],
input[type="tel"],
input[type="color"],
.uneditable-input {
  background-color: #ffffff;
  border: 1px solid #cccccc;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -webkit-transition: border linear .2s, box-shadow linear .2s;
  -moz-transition: border linear .2s, box-shadow linear .2s;
  -o-transition: border linear .2s, box-shadow linear .2s;
  transition: border linear .2s, box-shadow linear .2s;
}
textarea:focus,
input[type="text"]:focus,
input[type="password"]:focus,
input[type="datetime"]:focus,
input[type="datetime-local"]:focus,
input[type="date"]:focus,
input[type="month"]:focus,
input[type="time"]:focus,
input[type="week"]:focus,
input[type="number"]:focus,
input[type="email"]:focus,
input[type="url"]:focus,
input[type="search"]:focus,
input[type="tel"]:focus,
input[type="color"]:focus,
.uneditable-input:focus {
  border-color: rgba(82, 168, 236, 0.8);
  outline: 0;
  outline: thin dotted \9;
  /* IE6-9 */
  -webkit-box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(82,168,236,.6);
  -moz-box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(82,168,236,.6);
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(82,168,236,.6);
}
input[type="radio"],
input[type="checkbox"] {
  margin: 4px 0 0;
  *margin-top: 0;
  /* IE7 */
  margin-top: 1px \9;
  /* IE8-9 */
  line-height: normal;
}
input[type="file"],
input[type="image"],
input[type="submit"],
input[type="reset"],
input[type="button"],
input[type="radio"],
input[type="checkbox"] {
  width: auto;
}
select,
input[type="file"] {
  height: 30px;
  /* In IE7, the height of the select element cannot be changed by height, only font-size */
  *margin-top: 4px;
  /* For IE7, add top margin to align select with labels */
  line-height: 30px;
}
select {
  width: 220px;
  border: 1px solid #cccccc;
  background-color: #ffffff;
}
select[multiple],
select[size] {
  height: auto;
}
select:focus,
input[type="file"]:focus,
input[type="radio"]:focus,
input[type="checkbox"]:focus {
  outline: thin dotted #333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
.uneditable-input,
.uneditable-textarea {
  color: #999999;
  background-color: #fcfcfc;
  border-color: #cccccc;
  -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.025);
  -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.025);
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.025);
  cursor: not-allowed;
}
.uneditable-input {
  overflow: hidden;
  white-space: nowrap;
}
.uneditable-textarea {
  width: auto;
  height: auto;
}
input:-moz-placeholder,
textarea:-moz-placeholder {
  color: #999999;
}
input:-ms-input-placeholder,
textarea:-ms-input-placeholder {
  color: #999999;
}
input::-webkit-input-placeholder,
textarea::-webkit-input-placeholder {
  color: #999999;
}
.radio,
.checkbox {
  min-height: 20px;
  padding-left: 20px;
}
.radio input[type="radio"],
.checkbox input[type="checkbox"] {
  float: left;
  margin-left: -20px;
}
.controls > .radio:first-child,
.controls > .checkbox:first-child {
  padding-top: 5px;
}
.radio.inline,
.checkbox.inline {
  display: inline-block;
  padding-top: 5px;
  margin-bottom: 0;
  vertical-align: middle;
}
.radio.inline + .radio.inline,
.checkbox.inline + .checkbox.inline {
  margin-left: 10px;
}
.input-mini {
  width: 60px;
}
.input-small {
  width: 90px;
}
.input-medium {
  width: 150px;
}
.input-large {
  width: 210px;
}
.input-xlarge {
  width: 270px;
}
.input-xxlarge {
  width: 530px;
}
input[class*="span"],
select[class*="span"],
textarea[class*="span"],
.uneditable-input[class*="span"],
.row-fluid input[class*="span"],
.row-fluid select[class*="span"],
.row-fluid textarea[class*="span"],
.row-fluid .uneditable-input[class*="span"] {
  float: none;
  margin-left: 0;
}
.input-append input[class*="span"],
.input-append .uneditable-input[class*="span"],
.input-prepend input[class*="span"],
.input-prepend .uneditable-input[class*="span"],
.row-fluid input[class*="span"],
.row-fluid select[class*="span"],
.row-fluid textarea[class*="span"],
.row-fluid .uneditable-input[class*="span"],
.row-fluid .input-prepend [class*="span"],
.row-fluid .input-append [class*="span"] {
  display: inline-block;
}
input,
textarea,
.uneditable-input {
  margin-left: 0;
}
.controls-row [class*="span"] + [class*="span"] {
  margin-left: 20px;
}
input.span12,
textarea.span12,
.uneditable-input.span12 {
  width: 926px;
}
input.span11,
textarea.span11,
.uneditable-input.span11 {
  width: 846px;
}
input.span10,
textarea.span10,
.uneditable-input.span10 {
  width: 766px;
}
input.span9,
textarea.span9,
.uneditable-input.span9 {
  width: 686px;
}
input.span8,
textarea.span8,
.uneditable-input.span8 {
  width: 606px;
}
input.span7,
textarea.span7,
.uneditable-input.span7 {
  width: 526px;
}
input.span6,
textarea.span6,
.uneditable-input.span6 {
  width: 446px;
}
input.span5,
textarea.span5,
.uneditable-input.span5 {
  width: 366px;
}
input.span4,
textarea.span4,
.uneditable-input.span4 {
  width: 286px;
}
input.span3,
textarea.span3,
.uneditable-input.span3 {
  width: 206px;
}
input.span2,
textarea.span2,
.uneditable-input.span2 {
  width: 126px;
}
input.span1,
textarea.span1,
.uneditable-input.span1 {
  width: 46px;
}
.controls-row {
  *zoom: 1;
}
.controls-row:before,
.controls-row:after {
  display: table;
  content: "";
  line-height: 0;
}
.controls-row:after {
  clear: both;
}
.controls-row [class*="span"],
.row-fluid .controls-row [class*="span"] {
  float: left;
}
.controls-row .checkbox[class*="span"],
.controls-row .radio[class*="span"] {
  padding-top: 5px;
}
input[disabled],
select[disabled],
textarea[disabled],
input[readonly],
select[readonly],
textarea[readonly] {
  cursor: not-allowed;
  background-color: #eeeeee;
}
input[type="radio"][disabled],
input[type="checkbox"][disabled],
input[type="radio"][readonly],
input[type="checkbox"][readonly] {
  background-color: transparent;
}
.control-group.warning .control-label,
.control-group.warning .help-block,
.control-group.warning .help-inline {
  color: #c09853;
}
.control-group.warning .checkbox,
.control-group.warning .radio,
.control-group.warning input,
.control-group.warning select,
.control-group.warning textarea {
  color: #c09853;
}
.control-group.warning input,
.control-group.warning select,
.control-group.warning textarea {
  border-color: #c09853;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}
.control-group.warning input:focus,
.control-group.warning select:focus,
.control-group.warning textarea:focus {
  border-color: #a47e3c;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #dbc59e;
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #dbc59e;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #dbc59e;
}
.control-group.warning .input-prepend .add-on,
.control-group.warning .input-append .add-on {
  color: #c09853;
  background-color: #fcf8e3;
  border-color: #c09853;
}
.control-group.error .control-label,
.control-group.error .help-block,
.control-group.error .help-inline {
  color: #b55457;
}
.control-group.error .checkbox,
.control-group.error .radio,
.control-group.error input,
.control-group.error select,
.control-group.error textarea {
  color: #b55457;
}
.control-group.error input,
.control-group.error select,
.control-group.error textarea {
  border-color: #b55457;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}
.control-group.error input:focus,
.control-group.error select:focus,
.control-group.error textarea:focus {
  border-color: #954143;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #d49b9d;
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #d49b9d;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #d49b9d;
}
.control-group.error .input-prepend .add-on,
.control-group.error .input-append .add-on {
  color: #b55457;
  background-color: #f8f0f0;
  border-color: #b55457;
}
.control-group.success .control-label,
.control-group.success .help-block,
.control-group.success .help-inline {
  color: #468847;
}
.control-group.success .checkbox,
.control-group.success .radio,
.control-group.success input,
.control-group.success select,
.control-group.success textarea {
  color: #468847;
}
.control-group.success input,
.control-group.success select,
.control-group.success textarea {
  border-color: #468847;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}
.control-group.success input:focus,
.control-group.success select:focus,
.control-group.success textarea:focus {
  border-color: #356635;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #7aba7b;
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #7aba7b;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #7aba7b;
}
.control-group.success .input-prepend .add-on,
.control-group.success .input-append .add-on {
  color: #468847;
  background-color: #dff0d8;
  border-color: #468847;
}
.control-group.info .control-label,
.control-group.info .help-block,
.control-group.info .help-inline {
  color: #3a87ad;
}
.control-group.info .checkbox,
.control-group.info .radio,
.control-group.info input,
.control-group.info select,
.control-group.info textarea {
  color: #3a87ad;
}
.control-group.info input,
.control-group.info select,
.control-group.info textarea {
  border-color: #3a87ad;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}
.control-group.info input:focus,
.control-group.info select:focus,
.control-group.info textarea:focus {
  border-color: #2d6987;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #7ab5d3;
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #7ab5d3;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #7ab5d3;
}
.control-group.info .input-prepend .add-on,
.control-group.info .input-append .add-on {
  color: #3a87ad;
  background-color: #d9edf7;
  border-color: #3a87ad;
}
input:focus:invalid,
textarea:focus:invalid,
select:focus:invalid {
  color: #b94a48;
  border-color: #ee5f5b;
}
input:focus:invalid:focus,
textarea:focus:invalid:focus,
select:focus:invalid:focus {
  border-color: #e9322d;
  -webkit-box-shadow: 0 0 6px #f8b9b7;
  -moz-box-shadow: 0 0 6px #f8b9b7;
  box-shadow: 0 0 6px #f8b9b7;
}
.form-actions {
  padding: 19px 20px 20px;
  margin-top: 20px;
  margin-bottom: 20px;
  background-color: #f5f5f5;
  border-top: 1px solid #e5e5e5;
  *zoom: 1;
}
.form-actions:before,
.form-actions:after {
  display: table;
  content: "";
  line-height: 0;
}
.form-actions:after {
  clear: both;
}
.help-block,
.help-inline {
  color: #6a6a6a;
}
.help-block {
  display: block;
  margin-bottom: 10px;
}
.help-inline {
  display: inline-block;
  *display: inline;
  /* IE7 inline-block hack */
  *zoom: 1;
  vertical-align: middle;
  padding-left: 5px;
}
.input-append,
.input-prepend {
  display: inline-block;
  margin-bottom: 10px;
  vertical-align: middle;
  font-size: 0;
  white-space: nowrap;
}
.input-append input,
.input-prepend input,
.input-append select,
.input-prepend select,
.input-append .uneditable-input,
.input-prepend .uneditable-input,
.input-append .dropdown-menu,
.input-prepend .dropdown-menu,
.input-append .popover,
.input-prepend .popover {
  font-size: 14px;
}
.input-append input,
.input-prepend input,
.input-append select,
.input-prepend select,
.input-append .uneditable-input,
.input-prepend .uneditable-input {
  position: relative;
  margin-bottom: 0;
  *margin-left: 0;
  vertical-align: top;
  -webkit-border-radius: 0 3px 3px 0;
  -moz-border-radius: 0 3px 3px 0;
  border-radius: 0 3px 3px 0;
}
.input-append input:focus,
.input-prepend input:focus,
.input-append select:focus,
.input-prepend select:focus,
.input-append .uneditable-input:focus,
.input-prepend .uneditable-input:focus {
  z-index: 2;
}
.input-append .add-on,
.input-prepend .add-on {
  display: inline-block;
  width: auto;
  height: 20px;
  min-width: 16px;
  padding: 4px 5px;
  font-size: 14px;
  font-weight: normal;
  line-height: 20px;
  text-align: center;
  text-shadow: 0 1px 0 #ffffff;
  background-color: #eeeeee;
  border: 1px solid #ccc;
}
.input-append .add-on,
.input-prepend .add-on,
.input-append .btn,
.input-prepend .btn,
.input-append .btn-group > .dropdown-toggle,
.input-prepend .btn-group > .dropdown-toggle {
  vertical-align: top;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.input-append .active,
.input-prepend .active {
  background-color: #a9dba9;
  border-color: #46a546;
}
.input-prepend .add-on,
.input-prepend .btn {
  margin-right: -1px;
}
.input-prepend .add-on:first-child,
.input-prepend .btn:first-child {
  -webkit-border-radius: 3px 0 0 3px;
  -moz-border-radius: 3px 0 0 3px;
  border-radius: 3px 0 0 3px;
}
.input-append input,
.input-append select,
.input-append .uneditable-input {
  -webkit-border-radius: 3px 0 0 3px;
  -moz-border-radius: 3px 0 0 3px;
  border-radius: 3px 0 0 3px;
}
.input-append input + .btn-group .btn:last-child,
.input-append select + .btn-group .btn:last-child,
.input-append .uneditable-input + .btn-group .btn:last-child {
  -webkit-border-radius: 0 3px 3px 0;
  -moz-border-radius: 0 3px 3px 0;
  border-radius: 0 3px 3px 0;
}
.input-append .add-on,
.input-append .btn,
.input-append .btn-group {
  margin-left: -1px;
}
.input-append .add-on:last-child,
.input-append .btn:last-child,
.input-append .btn-group:last-child > .dropdown-toggle {
  -webkit-border-radius: 0 3px 3px 0;
  -moz-border-radius: 0 3px 3px 0;
  border-radius: 0 3px 3px 0;
}
.input-prepend.input-append input,
.input-prepend.input-append select,
.input-prepend.input-append .uneditable-input {
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.input-prepend.input-append input + .btn-group .btn,
.input-prepend.input-append select + .btn-group .btn,
.input-prepend.input-append .uneditable-input + .btn-group .btn {
  -webkit-border-radius: 0 3px 3px 0;
  -moz-border-radius: 0 3px 3px 0;
  border-radius: 0 3px 3px 0;
}
.input-prepend.input-append .add-on:first-child,
.input-prepend.input-append .btn:first-child {
  margin-right: -1px;
  -webkit-border-radius: 3px 0 0 3px;
  -moz-border-radius: 3px 0 0 3px;
  border-radius: 3px 0 0 3px;
}
.input-prepend.input-append .add-on:last-child,
.input-prepend.input-append .btn:last-child {
  margin-left: -1px;
  -webkit-border-radius: 0 3px 3px 0;
  -moz-border-radius: 0 3px 3px 0;
  border-radius: 0 3px 3px 0;
}
.input-prepend.input-append .btn-group:first-child {
  margin-left: 0;
}
input.search-query {
  padding-right: 14px;
  padding-right: 4px \9;
  padding-left: 14px;
  padding-left: 4px \9;
  /* IE7-8 doesn't have border-radius, so don't indent the padding */
  margin-bottom: 0;
  -webkit-border-radius: 15px;
  -moz-border-radius: 15px;
  border-radius: 15px;
}
/* Allow for input prepend/append in search forms */
.form-search .input-append .search-query,
.form-search .input-prepend .search-query {
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.form-search .input-append .search-query {
  -webkit-border-radius: 14px 0 0 14px;
  -moz-border-radius: 14px 0 0 14px;
  border-radius: 14px 0 0 14px;
}
.form-search .input-append .btn {
  -webkit-border-radius: 0 14px 14px 0;
  -moz-border-radius: 0 14px 14px 0;
  border-radius: 0 14px 14px 0;
}
.form-search .input-prepend .search-query {
  -webkit-border-radius: 0 14px 14px 0;
  -moz-border-radius: 0 14px 14px 0;
  border-radius: 0 14px 14px 0;
}
.form-search .input-prepend .btn {
  -webkit-border-radius: 14px 0 0 14px;
  -moz-border-radius: 14px 0 0 14px;
  border-radius: 14px 0 0 14px;
}
.form-search input,
.form-inline input,
.form-horizontal input,
.form-search textarea,
.form-inline textarea,
.form-horizontal textarea,
.form-search select,
.form-inline select,
.form-horizontal select,
.form-search .help-inline,
.form-inline .help-inline,
.form-horizontal .help-inline,
.form-search .uneditable-input,
.form-inline .uneditable-input,
.form-horizontal .uneditable-input,
.form-search .input-prepend,
.form-inline .input-prepend,
.form-horizontal .input-prepend,
.form-search .input-append,
.form-inline .input-append,
.form-horizontal .input-append {
  display: inline-block;
  *display: inline;
  /* IE7 inline-block hack */
  *zoom: 1;
  margin-bottom: 0;
  vertical-align: middle;
}
.form-search .hide,
.form-inline .hide,
.form-horizontal .hide {
  display: none;
}
.form-search label,
.form-inline label,
.form-search .btn-group,
.form-inline .btn-group {
  display: inline-block;
}
.form-search .input-append,
.form-inline .input-append,
.form-search .input-prepend,
.form-inline .input-prepend {
  margin-bottom: 0;
}
.form-search .radio,
.form-search .checkbox,
.form-inline .radio,
.form-inline .checkbox {
  padding-left: 0;
  margin-bottom: 0;
  vertical-align: middle;
}
.form-search .radio input[type="radio"],
.form-search .checkbox input[type="checkbox"],
.form-inline .radio input[type="radio"],
.form-inline .checkbox input[type="checkbox"] {
  float: left;
  margin-right: 3px;
  margin-left: 0;
}
.control-group {
  margin-bottom: 10px;
}
legend + .control-group {
  margin-top: 20px;
  -webkit-margin-top-collapse: separate;
}
.form-horizontal .control-group {
  margin-bottom: 20px;
  *zoom: 1;
}
.form-horizontal .control-group:before,
.form-horizontal .control-group:after {
  display: table;
  content: "";
  line-height: 0;
}
.form-horizontal .control-group:after {
  clear: both;
}
.form-horizontal .control-label {
  float: left;
  width: 160px;
  padding-top: 5px;
  text-align: right;
}
.form-horizontal .controls {
  *display: inline-block;
  *padding-left: 20px;
  margin-left: 180px;
  *margin-left: 0;
}
.form-horizontal .controls:first-child {
  *padding-left: 180px;
}
.form-horizontal .help-block {
  margin-bottom: 0;
}
.form-horizontal input + .help-block,
.form-horizontal select + .help-block,
.form-horizontal textarea + .help-block,
.form-horizontal .uneditable-input + .help-block,
.form-horizontal .input-prepend + .help-block,
.form-horizontal .input-append + .help-block {
  margin-top: 10px;
}
.form-horizontal .form-actions {
  padding-left: 180px;
}
table {
  max-width: 100%;
  background-color: transparent;
  border-collapse: collapse;
  border-spacing: 0;
}
.table {
  width: 100%;
  margin-bottom: 20px;
}
.table th,
.table td {
  padding: 8px;
  line-height: 20px;
  text-align: left;
  vertical-align: top;
  border-top: 1px solid #dddddd;
}
.table th {
  font-weight: bold;
}
.table thead th {
  vertical-align: bottom;
}
.table caption + thead tr:first-child th,
.table caption + thead tr:first-child td,
.table colgroup + thead tr:first-child th,
.table colgroup + thead tr:first-child td,
.table thead:first-child tr:first-child th,
.table thead:first-child tr:first-child td {
  border-top: 0;
}
.table tbody + tbody {
  border-top: 2px solid #dddddd;
}
.table .table {
  background-color: #eeeeee;
}
.table-condensed th,
.table-condensed td {
  padding: 4px 5px;
}
.table-bordered {
  border: 1px solid #dddddd;
  border-collapse: separate;
  *border-collapse: collapse;
  border-left: 0;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.table-bordered th,
.table-bordered td {
  border-left: 1px solid #dddddd;
}
.table-bordered caption + thead tr:first-child th,
.table-bordered caption + tbody tr:first-child th,
.table-bordered caption + tbody tr:first-child td,
.table-bordered colgroup + thead tr:first-child th,
.table-bordered colgroup + tbody tr:first-child th,
.table-bordered colgroup + tbody tr:first-child td,
.table-bordered thead:first-child tr:first-child th,
.table-bordered tbody:first-child tr:first-child th,
.table-bordered tbody:first-child tr:first-child td {
  border-top: 0;
}
.table-bordered thead:first-child tr:first-child > th:first-child,
.table-bordered tbody:first-child tr:first-child > td:first-child,
.table-bordered tbody:first-child tr:first-child > th:first-child {
  -webkit-border-top-left-radius: 4px;
  -moz-border-radius-topleft: 4px;
  border-top-left-radius: 4px;
}
.table-bordered thead:first-child tr:first-child > th:last-child,
.table-bordered tbody:first-child tr:first-child > td:last-child,
.table-bordered tbody:first-child tr:first-child > th:last-child {
  -webkit-border-top-right-radius: 4px;
  -moz-border-radius-topright: 4px;
  border-top-right-radius: 4px;
}
.table-bordered thead:last-child tr:last-child > th:first-child,
.table-bordered tbody:last-child tr:last-child > td:first-child,
.table-bordered tbody:last-child tr:last-child > th:first-child,
.table-bordered tfoot:last-child tr:last-child > td:first-child,
.table-bordered tfoot:last-child tr:last-child > th:first-child {
  -webkit-border-bottom-left-radius: 4px;
  -moz-border-radius-bottomleft: 4px;
  border-bottom-left-radius: 4px;
}
.table-bordered thead:last-child tr:last-child > th:last-child,
.table-bordered tbody:last-child tr:last-child > td:last-child,
.table-bordered tbody:last-child tr:last-child > th:last-child,
.table-bordered tfoot:last-child tr:last-child > td:last-child,
.table-bordered tfoot:last-child tr:last-child > th:last-child {
  -webkit-border-bottom-right-radius: 4px;
  -moz-border-radius-bottomright: 4px;
  border-bottom-right-radius: 4px;
}
.table-bordered tfoot + tbody:last-child tr:last-child td:first-child {
  -webkit-border-bottom-left-radius: 0;
  -moz-border-radius-bottomleft: 0;
  border-bottom-left-radius: 0;
}
.table-bordered tfoot + tbody:last-child tr:last-child td:last-child {
  -webkit-border-bottom-right-radius: 0;
  -moz-border-radius-bottomright: 0;
  border-bottom-right-radius: 0;
}
.table-bordered caption + thead tr:first-child th:first-child,
.table-bordered caption + tbody tr:first-child td:first-child,
.table-bordered colgroup + thead tr:first-child th:first-child,
.table-bordered colgroup + tbody tr:first-child td:first-child {
  -webkit-border-top-left-radius: 4px;
  -moz-border-radius-topleft: 4px;
  border-top-left-radius: 4px;
}
.table-bordered caption + thead tr:first-child th:last-child,
.table-bordered caption + tbody tr:first-child td:last-child,
.table-bordered colgroup + thead tr:first-child th:last-child,
.table-bordered colgroup + tbody tr:first-child td:last-child {
  -webkit-border-top-right-radius: 4px;
  -moz-border-radius-topright: 4px;
  border-top-right-radius: 4px;
}
.table-striped tbody > tr:nth-child(odd) > td,
.table-striped tbody > tr:nth-child(odd) > th {
  background-color: #f9f9f9;
}
.table-hover tbody tr:hover > td,
.table-hover tbody tr:hover > th {
  background-color: #f5f5f5;
}
table td[class*="span"],
table th[class*="span"],
.row-fluid table td[class*="span"],
.row-fluid table th[class*="span"] {
  display: table-cell;
  float: none;
  margin-left: 0;
}
.table td.span1,
.table th.span1 {
  float: none;
  width: 44px;
  margin-left: 0;
}
.table td.span2,
.table th.span2 {
  float: none;
  width: 124px;
  margin-left: 0;
}
.table td.span3,
.table th.span3 {
  float: none;
  width: 204px;
  margin-left: 0;
}
.table td.span4,
.table th.span4 {
  float: none;
  width: 284px;
  margin-left: 0;
}
.table td.span5,
.table th.span5 {
  float: none;
  width: 364px;
  margin-left: 0;
}
.table td.span6,
.table th.span6 {
  float: none;
  width: 444px;
  margin-left: 0;
}
.table td.span7,
.table th.span7 {
  float: none;
  width: 524px;
  margin-left: 0;
}
.table td.span8,
.table th.span8 {
  float: none;
  width: 604px;
  margin-left: 0;
}
.table td.span9,
.table th.span9 {
  float: none;
  width: 684px;
  margin-left: 0;
}
.table td.span10,
.table th.span10 {
  float: none;
  width: 764px;
  margin-left: 0;
}
.table td.span11,
.table th.span11 {
  float: none;
  width: 844px;
  margin-left: 0;
}
.table td.span12,
.table th.span12 {
  float: none;
  width: 924px;
  margin-left: 0;
}
.table tbody tr.success > td {
  background-color: #dff0d8;
}
.table tbody tr.error > td {
  background-color: #f8f0f0;
}
.table tbody tr.warning > td {
  background-color: #fcf8e3;
}
.table tbody tr.info > td {
  background-color: #d9edf7;
}
.table-hover tbody tr.success:hover > td {
  background-color: #d0e9c6;
}
.table-hover tbody tr.error:hover > td {
  background-color: #f0dfe0;
}
.table-hover tbody tr.warning:hover > td {
  background-color: #faf2cc;
}
.table-hover tbody tr.info:hover > td {
  background-color: #c4e3f3;
}
.dropup,
.dropdown {
  position: relative;
}
.dropdown-toggle {
  *margin-bottom: -3px;
}
.dropdown-toggle:active,
.open .dropdown-toggle {
  outline: 0;
}
.caret {
  display: inline-block;
  width: 0;
  height: 0;
  vertical-align: top;
  border-top: 4px solid #000000;
  border-right: 4px solid transparent;
  border-left: 4px solid transparent;
  content: "";
}
.dropdown .caret {
  margin-top: 8px;
  margin-left: 2px;
}
.dropdown-menu {
  position: absolute;
  top: 100%;
  left: 0;
  z-index: 1000;
  display: none;
  float: left;
  min-width: 160px;
  padding: 5px 0;
  margin: 2px 0 0;
  list-style: none;
  background-color: #ffffff;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, 0.2);
  *border-right-width: 2px;
  *border-bottom-width: 2px;
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
  -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  -moz-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  -webkit-background-clip: padding-box;
  -moz-background-clip: padding;
  background-clip: padding-box;
}
.dropdown-menu.pull-right {
  right: 0;
  left: auto;
}
.dropdown-menu .divider {
  *width: 100%;
  height: 1px;
  margin: 9px 1px;
  *margin: -5px 0 5px;
  overflow: hidden;
  background-color: #e5e5e5;
  border-bottom: 1px solid #ffffff;
}
.dropdown-menu > li > a {
  display: block;
  padding: 3px 20px;
  clear: both;
  font-weight: normal;
  line-height: 20px;
  color: #333333;
  white-space: nowrap;
}
.dropdown-menu > li > a:hover,
.dropdown-menu > li > a:focus,
.dropdown-submenu:hover > a,
.dropdown-submenu:focus > a {
  text-decoration: none;
  color: #ffffff;
  background-color: #e62f8d;
  background-image: -moz-linear-gradient(top, #e73892, #e42186);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#e73892), to(#e42186));
  background-image: -webkit-linear-gradient(top, #e73892, #e42186);
  background-image: -o-linear-gradient(top, #e73892, #e42186);
  background-image: linear-gradient(to bottom, #e73892, #e42186);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffe73892', endColorstr='#ffe42186', GradientType=0);
}
.dropdown-menu > .active > a,
.dropdown-menu > .active > a:hover,
.dropdown-menu > .active > a:focus {
  color: #ffffff;
  text-decoration: none;
  outline: 0;
  background-color: #e62f8d;
  background-image: -moz-linear-gradient(top, #e73892, #e42186);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#e73892), to(#e42186));
  background-image: -webkit-linear-gradient(top, #e73892, #e42186);
  background-image: -o-linear-gradient(top, #e73892, #e42186);
  background-image: linear-gradient(to bottom, #e73892, #e42186);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffe73892', endColorstr='#ffe42186', GradientType=0);
}
.dropdown-menu > .disabled > a,
.dropdown-menu > .disabled > a:hover,
.dropdown-menu > .disabled > a:focus {
  color: #999999;
}
.dropdown-menu > .disabled > a:hover,
.dropdown-menu > .disabled > a:focus {
  text-decoration: none;
  background-color: transparent;
  background-image: none;
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  cursor: default;
}
.open {
  *z-index: 1000;
}
.open > .dropdown-menu {
  display: block;
}
.dropdown-backdrop {
  position: fixed;
  left: 0;
  right: 0;
  bottom: 0;
  top: 0;
  z-index: 990;
}
.pull-right > .dropdown-menu {
  right: 0;
  left: auto;
}
.dropup .caret,
.navbar-fixed-bottom .dropdown .caret {
  border-top: 0;
  border-bottom: 4px solid #000000;
  content: "";
}
.dropup .dropdown-menu,
.navbar-fixed-bottom .dropdown .dropdown-menu {
  top: auto;
  bottom: 100%;
  margin-bottom: 1px;
}
.dropdown-submenu {
  position: relative;
}
.dropdown-submenu > .dropdown-menu {
  top: 0;
  left: 100%;
  margin-top: -6px;
  margin-left: -1px;
  -webkit-border-radius: 0 6px 6px 6px;
  -moz-border-radius: 0 6px 6px 6px;
  border-radius: 0 6px 6px 6px;
}
.dropdown-submenu:hover > .dropdown-menu {
  display: block;
}
.dropup .dropdown-submenu > .dropdown-menu {
  top: auto;
  bottom: 0;
  margin-top: 0;
  margin-bottom: -2px;
  -webkit-border-radius: 5px 5px 5px 0;
  -moz-border-radius: 5px 5px 5px 0;
  border-radius: 5px 5px 5px 0;
}
.dropdown-submenu > a:after {
  display: block;
  content: " ";
  float: right;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid;
  border-width: 5px 0 5px 5px;
  border-left-color: #cccccc;
  margin-top: 5px;
  margin-right: -10px;
}
.dropdown-submenu:hover > a:after {
  border-left-color: #ffffff;
}
.dropdown-submenu.pull-left {
  float: none;
}
.dropdown-submenu.pull-left > .dropdown-menu {
  left: -100%;
  margin-left: 10px;
  -webkit-border-radius: 6px 0 6px 6px;
  -moz-border-radius: 6px 0 6px 6px;
  border-radius: 6px 0 6px 6px;
}
.dropdown .dropdown-menu .nav-header {
  padding-left: 20px;
  padding-right: 20px;
}
.typeahead {
  z-index: 1051;
  margin-top: 2px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.well {
  min-height: 20px;
  padding: 19px;
  margin-bottom: 20px;
  background-color: #f5f5f5;
  border: 1px solid #e3e3e3;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
}
.well blockquote {
  border-color: #ddd;
  border-color: rgba(0, 0, 0, 0.15);
}
.well-large {
  padding: 24px;
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
}
.well-small {
  padding: 9px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.fade {
  opacity: 0;
  -webkit-transition: opacity 0.15s linear;
  -moz-transition: opacity 0.15s linear;
  -o-transition: opacity 0.15s linear;
  transition: opacity 0.15s linear;
}
.fade.in {
  opacity: 1;
}
.collapse {
  position: relative;
  height: 0;
  overflow: hidden;
  -webkit-transition: height 0.35s ease;
  -moz-transition: height 0.35s ease;
  -o-transition: height 0.35s ease;
  transition: height 0.35s ease;
}
.collapse.in {
  height: auto;
}
.close {
  float: right;
  font-size: 20px;
  font-weight: bold;
  line-height: 20px;
  color: #000000;
  text-shadow: 0 1px 0 #ffffff;
  opacity: 0.2;
  filter: alpha(opacity=20);
}
.close:hover,
.close:focus {
  color: #000000;
  text-decoration: none;
  cursor: pointer;
  opacity: 0.4;
  filter: alpha(opacity=40);
}
button.close {
  padding: 0;
  cursor: pointer;
  background: transparent;
  border: 0;
  -webkit-appearance: none;
}
.btn {
  display: inline-block;
  *display: inline;
  /* IE7 inline-block hack */
  *zoom: 1;
  padding: 4px 12px;
  margin-bottom: 0;
  font-size: 14px;
  line-height: 20px;
  text-align: center;
  vertical-align: middle;
  cursor: pointer;
  color: #333333;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  background-color: #f7f7f7;
  background-image: -moz-linear-gradient(top, #ffffff, #eaeaea);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#eaeaea));
  background-image: -webkit-linear-gradient(top, #ffffff, #eaeaea);
  background-image: -o-linear-gradient(top, #ffffff, #eaeaea);
  background-image: linear-gradient(to bottom, #ffffff, #eaeaea);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffffff', endColorstr='#ffeaeaea', GradientType=0);
  border-color: #eaeaea #eaeaea #c4c4c4;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  *background-color: #eaeaea;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  border: 1px solid #cccccc;
  *border: 0;
  border-bottom-color: #b3b3b3;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  *margin-left: .3em;
  -webkit-box-shadow: inset 0 1px 0 rgba(255,255,255,.2), 0 1px 2px rgba(0,0,0,.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255,255,255,.2), 0 1px 2px rgba(0,0,0,.05);
  box-shadow: inset 0 1px 0 rgba(255,255,255,.2), 0 1px 2px rgba(0,0,0,.05);
}
.btn:hover,
.btn:focus,
.btn:active,
.btn.active,
.btn.disabled,
.btn[disabled] {
  color: #333333;
  background-color: #eaeaea;
  *background-color: #dddddd;
}
.btn:active,
.btn.active {
  background-color: #d1d1d1 \9;
}
.btn:first-child {
  *margin-left: 0;
}
.btn:hover,
.btn:focus {
  color: #333333;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition: background-position 0.1s linear;
  -moz-transition: background-position 0.1s linear;
  -o-transition: background-position 0.1s linear;
  transition: background-position 0.1s linear;
}
.btn:focus {
  outline: thin dotted #333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
.btn.active,
.btn:active {
  background-image: none;
  outline: 0;
  -webkit-box-shadow: inset 0 2px 4px rgba(0,0,0,.15), 0 1px 2px rgba(0,0,0,.05);
  -moz-box-shadow: inset 0 2px 4px rgba(0,0,0,.15), 0 1px 2px rgba(0,0,0,.05);
  box-shadow: inset 0 2px 4px rgba(0,0,0,.15), 0 1px 2px rgba(0,0,0,.05);
}
.btn.disabled,
.btn[disabled] {
  cursor: default;
  background-image: none;
  opacity: 0.65;
  filter: alpha(opacity=65);
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
}
.btn-large {
  padding: 11px 19px;
  font-size: 17.5px;
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
}
.btn-large [class^="icon-"],
.btn-large [class*=" icon-"] {
  margin-top: 4px;
}
.btn-small {
  padding: 2px 10px;
  font-size: 11.9px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.btn-small [class^="icon-"],
.btn-small [class*=" icon-"] {
  margin-top: 0;
}
.btn-mini [class^="icon-"],
.btn-mini [class*=" icon-"] {
  margin-top: -1px;
}
.btn-mini {
  padding: 0 6px;
  font-size: 10.5px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.btn-block {
  display: block;
  width: 100%;
  padding-left: 0;
  padding-right: 0;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.btn-block + .btn-block {
  margin-top: 5px;
}
input[type="submit"].btn-block,
input[type="reset"].btn-block,
input[type="button"].btn-block {
  width: 100%;
}
.btn-primary.active,
.btn-warning.active,
.btn-danger.active,
.btn-success.active,
.btn-info.active,
.btn-inverse.active {
  color: rgba(255, 255, 255, 0.75);
}
.btn-primary {
  color: #ffffff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #ea53a1;
  background-image: -moz-linear-gradient(top, #ec66ab, #e73892);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ec66ab), to(#e73892));
  background-image: -webkit-linear-gradient(top, #ec66ab, #e73892);
  background-image: -o-linear-gradient(top, #ec66ab, #e73892);
  background-image: linear-gradient(to bottom, #ec66ab, #e73892);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffec66ab', endColorstr='#ffe73892', GradientType=0);
  border-color: #e73892 #e73892 #bc176c;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  *background-color: #e73892;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}
.btn-primary:hover,
.btn-primary:focus,
.btn-primary:active,
.btn-primary.active,
.btn-primary.disabled,
.btn-primary[disabled] {
  color: #ffffff;
  background-color: #e73892;
  *background-color: #e42186;
}
.btn-primary:active,
.btn-primary.active {
  background-color: #d31979 \9;
}
.btn-warning {
  color: #ffffff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #faa732;
  background-image: -moz-linear-gradient(top, #fbb450, #f89406);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#fbb450), to(#f89406));
  background-image: -webkit-linear-gradient(top, #fbb450, #f89406);
  background-image: -o-linear-gradient(top, #fbb450, #f89406);
  background-image: linear-gradient(to bottom, #fbb450, #f89406);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fffbb450', endColorstr='#fff89406', GradientType=0);
  border-color: #f89406 #f89406 #ad6704;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  *background-color: #f89406;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}
.btn-warning:hover,
.btn-warning:focus,
.btn-warning:active,
.btn-warning.active,
.btn-warning.disabled,
.btn-warning[disabled] {
  color: #ffffff;
  background-color: #f89406;
  *background-color: #df8505;
}
.btn-warning:active,
.btn-warning.active {
  background-color: #c67605 \9;
}
.btn-danger {
  color: #ffffff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #da4f49;
  background-image: -moz-linear-gradient(top, #ee5f5b, #bd362f);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ee5f5b), to(#bd362f));
  background-image: -webkit-linear-gradient(top, #ee5f5b, #bd362f);
  background-image: -o-linear-gradient(top, #ee5f5b, #bd362f);
  background-image: linear-gradient(to bottom, #ee5f5b, #bd362f);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffee5f5b', endColorstr='#ffbd362f', GradientType=0);
  border-color: #bd362f #bd362f #802420;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  *background-color: #bd362f;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}
.btn-danger:hover,
.btn-danger:focus,
.btn-danger:active,
.btn-danger.active,
.btn-danger.disabled,
.btn-danger[disabled] {
  color: #ffffff;
  background-color: #bd362f;
  *background-color: #a9302a;
}
.btn-danger:active,
.btn-danger.active {
  background-color: #942a25 \9;
}
.btn-success {
  color: #ffffff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #5bb75b;
  background-image: -moz-linear-gradient(top, #62c462, #51a351);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#62c462), to(#51a351));
  background-image: -webkit-linear-gradient(top, #62c462, #51a351);
  background-image: -o-linear-gradient(top, #62c462, #51a351);
  background-image: linear-gradient(to bottom, #62c462, #51a351);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff62c462', endColorstr='#ff51a351', GradientType=0);
  border-color: #51a351 #51a351 #387038;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  *background-color: #51a351;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}
.btn-success:hover,
.btn-success:focus,
.btn-success:active,
.btn-success.active,
.btn-success.disabled,
.btn-success[disabled] {
  color: #ffffff;
  background-color: #51a351;
  *background-color: #499249;
}
.btn-success:active,
.btn-success.active {
  background-color: #408140 \9;
}
.btn-info {
  color: #ffffff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #49afcd;
  background-image: -moz-linear-gradient(top, #5bc0de, #2f96b4);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#5bc0de), to(#2f96b4));
  background-image: -webkit-linear-gradient(top, #5bc0de, #2f96b4);
  background-image: -o-linear-gradient(top, #5bc0de, #2f96b4);
  background-image: linear-gradient(to bottom, #5bc0de, #2f96b4);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff5bc0de', endColorstr='#ff2f96b4', GradientType=0);
  border-color: #2f96b4 #2f96b4 #1f6377;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  *background-color: #2f96b4;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}
.btn-info:hover,
.btn-info:focus,
.btn-info:active,
.btn-info.active,
.btn-info.disabled,
.btn-info[disabled] {
  color: #ffffff;
  background-color: #2f96b4;
  *background-color: #2a85a0;
}
.btn-info:active,
.btn-info.active {
  background-color: #24748c \9;
}
.btn-inverse {
  color: #ffffff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #363636;
  background-image: -moz-linear-gradient(top, #444444, #222222);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#444444), to(#222222));
  background-image: -webkit-linear-gradient(top, #444444, #222222);
  background-image: -o-linear-gradient(top, #444444, #222222);
  background-image: linear-gradient(to bottom, #444444, #222222);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff444444', endColorstr='#ff222222', GradientType=0);
  border-color: #222222 #222222 #000000;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  *background-color: #222222;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}
.btn-inverse:hover,
.btn-inverse:focus,
.btn-inverse:active,
.btn-inverse.active,
.btn-inverse.disabled,
.btn-inverse[disabled] {
  color: #ffffff;
  background-color: #222222;
  *background-color: #151515;
}
.btn-inverse:active,
.btn-inverse.active {
  background-color: #080808 \9;
}
button.btn,
input[type="submit"].btn {
  *padding-top: 3px;
  *padding-bottom: 3px;
}
button.btn::-moz-focus-inner,
input[type="submit"].btn::-moz-focus-inner {
  padding: 0;
  border: 0;
}
button.btn.btn-large,
input[type="submit"].btn.btn-large {
  *padding-top: 7px;
  *padding-bottom: 7px;
}
button.btn.btn-small,
input[type="submit"].btn.btn-small {
  *padding-top: 3px;
  *padding-bottom: 3px;
}
button.btn.btn-mini,
input[type="submit"].btn.btn-mini {
  *padding-top: 1px;
  *padding-bottom: 1px;
}
.btn-link,
.btn-link:active,
.btn-link[disabled] {
  background-color: transparent;
  background-image: none;
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
}
.btn-link {
  border-color: transparent;
  cursor: pointer;
  color: #e73892;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.btn-link:hover,
.btn-link:focus {
  color: #bc176c;
  text-decoration: underline;
  background-color: transparent;
}
.btn-link[disabled]:hover,
.btn-link[disabled]:focus {
  color: #333333;
  text-decoration: none;
}
.btn-group {
  position: relative;
  display: inline-block;
  *display: inline;
  /* IE7 inline-block hack */
  *zoom: 1;
  font-size: 0;
  vertical-align: middle;
  white-space: nowrap;
  *margin-left: .3em;
}
.btn-group:first-child {
  *margin-left: 0;
}
.btn-group + .btn-group {
  margin-left: 5px;
}
.btn-toolbar {
  font-size: 0;
  margin-top: 10px;
  margin-bottom: 10px;
}
.btn-toolbar > .btn + .btn,
.btn-toolbar > .btn-group + .btn,
.btn-toolbar > .btn + .btn-group {
  margin-left: 5px;
}
.btn-group > .btn {
  position: relative;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.btn-group > .btn + .btn {
  margin-left: -1px;
}
.btn-group > .btn,
.btn-group > .dropdown-menu,
.btn-group > .popover {
  font-size: 14px;
}
.btn-group > .btn-mini {
  font-size: 10.5px;
}
.btn-group > .btn-small {
  font-size: 11.9px;
}
.btn-group > .btn-large {
  font-size: 17.5px;
}
.btn-group > .btn:first-child {
  margin-left: 0;
  -webkit-border-top-left-radius: 4px;
  -moz-border-radius-topleft: 4px;
  border-top-left-radius: 4px;
  -webkit-border-bottom-left-radius: 4px;
  -moz-border-radius-bottomleft: 4px;
  border-bottom-left-radius: 4px;
}
.btn-group > .btn:last-child,
.btn-group > .dropdown-toggle {
  -webkit-border-top-right-radius: 4px;
  -moz-border-radius-topright: 4px;
  border-top-right-radius: 4px;
  -webkit-border-bottom-right-radius: 4px;
  -moz-border-radius-bottomright: 4px;
  border-bottom-right-radius: 4px;
}
.btn-group > .btn.large:first-child {
  margin-left: 0;
  -webkit-border-top-left-radius: 6px;
  -moz-border-radius-topleft: 6px;
  border-top-left-radius: 6px;
  -webkit-border-bottom-left-radius: 6px;
  -moz-border-radius-bottomleft: 6px;
  border-bottom-left-radius: 6px;
}
.btn-group > .btn.large:last-child,
.btn-group > .large.dropdown-toggle {
  -webkit-border-top-right-radius: 6px;
  -moz-border-radius-topright: 6px;
  border-top-right-radius: 6px;
  -webkit-border-bottom-right-radius: 6px;
  -moz-border-radius-bottomright: 6px;
  border-bottom-right-radius: 6px;
}
.btn-group > .btn:hover,
.btn-group > .btn:focus,
.btn-group > .btn:active,
.btn-group > .btn.active {
  z-index: 2;
}
.btn-group .dropdown-toggle:active,
.btn-group.open .dropdown-toggle {
  outline: 0;
}
.btn-group > .btn + .dropdown-toggle {
  padding-left: 8px;
  padding-right: 8px;
  -webkit-box-shadow: inset 1px 0 0 rgba(255,255,255,.125), inset 0 1px 0 rgba(255,255,255,.2), 0 1px 2px rgba(0,0,0,.05);
  -moz-box-shadow: inset 1px 0 0 rgba(255,255,255,.125), inset 0 1px 0 rgba(255,255,255,.2), 0 1px 2px rgba(0,0,0,.05);
  box-shadow: inset 1px 0 0 rgba(255,255,255,.125), inset 0 1px 0 rgba(255,255,255,.2), 0 1px 2px rgba(0,0,0,.05);
  *padding-top: 5px;
  *padding-bottom: 5px;
}
.btn-group > .btn-mini + .dropdown-toggle {
  padding-left: 5px;
  padding-right: 5px;
  *padding-top: 2px;
  *padding-bottom: 2px;
}
.btn-group > .btn-small + .dropdown-toggle {
  *padding-top: 5px;
  *padding-bottom: 4px;
}
.btn-group > .btn-large + .dropdown-toggle {
  padding-left: 12px;
  padding-right: 12px;
  *padding-top: 7px;
  *padding-bottom: 7px;
}
.btn-group.open .dropdown-toggle {
  background-image: none;
  -webkit-box-shadow: inset 0 2px 4px rgba(0,0,0,.15), 0 1px 2px rgba(0,0,0,.05);
  -moz-box-shadow: inset 0 2px 4px rgba(0,0,0,.15), 0 1px 2px rgba(0,0,0,.05);
  box-shadow: inset 0 2px 4px rgba(0,0,0,.15), 0 1px 2px rgba(0,0,0,.05);
}
.btn-group.open .btn.dropdown-toggle {
  background-color: #eaeaea;
}
.btn-group.open .btn-primary.dropdown-toggle {
  background-color: #e73892;
}
.btn-group.open .btn-warning.dropdown-toggle {
  background-color: #f89406;
}
.btn-group.open .btn-danger.dropdown-toggle {
  background-color: #bd362f;
}
.btn-group.open .btn-success.dropdown-toggle {
  background-color: #51a351;
}
.btn-group.open .btn-info.dropdown-toggle {
  background-color: #2f96b4;
}
.btn-group.open .btn-inverse.dropdown-toggle {
  background-color: #222222;
}
.btn .caret {
  margin-top: 8px;
  margin-left: 0;
}
.btn-large .caret {
  margin-top: 6px;
}
.btn-large .caret {
  border-left-width: 5px;
  border-right-width: 5px;
  border-top-width: 5px;
}
.btn-mini .caret,
.btn-small .caret {
  margin-top: 8px;
}
.dropup .btn-large .caret {
  border-bottom-width: 5px;
}
.btn-primary .caret,
.btn-warning .caret,
.btn-danger .caret,
.btn-info .caret,
.btn-success .caret,
.btn-inverse .caret {
  border-top-color: #ffffff;
  border-bottom-color: #ffffff;
}
.btn-group-vertical {
  display: inline-block;
  *display: inline;
  /* IE7 inline-block hack */
  *zoom: 1;
}
.btn-group-vertical > .btn {
  display: block;
  float: none;
  max-width: 100%;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.btn-group-vertical > .btn + .btn {
  margin-left: 0;
  margin-top: -1px;
}
.btn-group-vertical > .btn:first-child {
  -webkit-border-radius: 4px 4px 0 0;
  -moz-border-radius: 4px 4px 0 0;
  border-radius: 4px 4px 0 0;
}
.btn-group-vertical > .btn:last-child {
  -webkit-border-radius: 0 0 4px 4px;
  -moz-border-radius: 0 0 4px 4px;
  border-radius: 0 0 4px 4px;
}
.btn-group-vertical > .btn-large:first-child {
  -webkit-border-radius: 6px 6px 0 0;
  -moz-border-radius: 6px 6px 0 0;
  border-radius: 6px 6px 0 0;
}
.btn-group-vertical > .btn-large:last-child {
  -webkit-border-radius: 0 0 6px 6px;
  -moz-border-radius: 0 0 6px 6px;
  border-radius: 0 0 6px 6px;
}
.alert {
  padding: 8px 35px 8px 14px;
  margin-bottom: 20px;
  text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
  background-color: #fcf8e3;
  border: 1px solid #fbeed5;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.alert,
.alert h4 {
  color: #c09853;
}
.alert h4 {
  margin: 0;
}
.alert .close {
  position: relative;
  top: -2px;
  right: -21px;
  line-height: 20px;
}
.alert-success {
  background-color: #dff0d8;
  border-color: #d6e9c6;
  color: #468847;
}
.alert-success h4 {
  color: #468847;
}
.alert-danger,
.alert-error {
  background-color: #f8f0f0;
  border-color: #c6898b;
  color: #b55457;
}
.alert-danger h4,
.alert-error h4 {
  color: #b55457;
}
.alert-info {
  background-color: #d9edf7;
  border-color: #bce8f1;
  color: #3a87ad;
}
.alert-info h4 {
  color: #3a87ad;
}
.alert-block {
  padding-top: 14px;
  padding-bottom: 14px;
}
.alert-block > p,
.alert-block > ul {
  margin-bottom: 0;
}
.alert-block p + p {
  margin-top: 5px;
}
.nav {
  margin-left: 0;
  margin-bottom: 20px;
  list-style: none;
}
.nav > li > a {
  display: block;
}
.nav > li > a:hover,
.nav > li > a:focus {
  text-decoration: none;
  background-color: #eeeeee;
}
.nav > li > a > img {
  max-width: none;
}
.nav > .pull-right {
  float: right;
}
.nav-header {
  display: block;
  padding: 3px 15px;
  font-size: 11px;
  font-weight: bold;
  line-height: 20px;
  color: #999999;
  text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
  text-transform: uppercase;
}
.nav li + .nav-header {
  margin-top: 9px;
}
.nav-list {
  padding-left: 15px;
  padding-right: 15px;
  margin-bottom: 0;
}
.nav-list > li > a,
.nav-list .nav-header {
  margin-left: -15px;
  margin-right: -15px;
  text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
}
.nav-list > li > a {
  padding: 3px 15px;
}
.nav-list > .active > a,
.nav-list > .active > a:hover,
.nav-list > .active > a:focus {
  color: #ffffff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.2);
  background-color: #e73892;
}
.nav-list [class^="icon-"],
.nav-list [class*=" icon-"] {
  margin-right: 2px;
}
.nav-list .divider {
  *width: 100%;
  height: 1px;
  margin: 9px 1px;
  *margin: -5px 0 5px;
  overflow: hidden;
  background-color: #e5e5e5;
  border-bottom: 1px solid #ffffff;
}
.nav-tabs,
.nav-pills {
  *zoom: 1;
}
.nav-tabs:before,
.nav-pills:before,
.nav-tabs:after,
.nav-pills:after {
  display: table;
  content: "";
  line-height: 0;
}
.nav-tabs:after,
.nav-pills:after {
  clear: both;
}
.nav-tabs > li,
.nav-pills > li {
  float: left;
}
.nav-tabs > li > a,
.nav-pills > li > a {
  padding-right: 12px;
  padding-left: 12px;
  margin-right: 2px;
  line-height: 14px;
}
.nav-tabs {
  border-bottom: 1px solid #ddd;
}
.nav-tabs > li {
  margin-bottom: -1px;
}
.nav-tabs > li > a {
  padding-top: 8px;
  padding-bottom: 8px;
  line-height: 20px;
  border: 1px solid transparent;
  -webkit-border-radius: 4px 4px 0 0;
  -moz-border-radius: 4px 4px 0 0;
  border-radius: 4px 4px 0 0;
}
.nav-tabs > li > a:hover,
.nav-tabs > li > a:focus {
  border-color: #eeeeee #eeeeee #dddddd;
}
.nav-tabs > .active > a,
.nav-tabs > .active > a:hover,
.nav-tabs > .active > a:focus {
  color: #555555;
  background-color: #eeeeee;
  border: 1px solid #ddd;
  border-bottom-color: transparent;
  cursor: default;
}
.nav-pills > li > a {
  padding-top: 8px;
  padding-bottom: 8px;
  margin-top: 2px;
  margin-bottom: 2px;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
}
.nav-pills > .active > a,
.nav-pills > .active > a:hover,
.nav-pills > .active > a:focus {
  color: #ffffff;
  background-color: #e73892;
}
.nav-stacked > li {
  float: none;
}
.nav-stacked > li > a {
  margin-right: 0;
}
.nav-tabs.nav-stacked {
  border-bottom: 0;
}
.nav-tabs.nav-stacked > li > a {
  border: 1px solid #ddd;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.nav-tabs.nav-stacked > li:first-child > a {
  -webkit-border-top-right-radius: 4px;
  -moz-border-radius-topright: 4px;
  border-top-right-radius: 4px;
  -webkit-border-top-left-radius: 4px;
  -moz-border-radius-topleft: 4px;
  border-top-left-radius: 4px;
}
.nav-tabs.nav-stacked > li:last-child > a {
  -webkit-border-bottom-right-radius: 4px;
  -moz-border-radius-bottomright: 4px;
  border-bottom-right-radius: 4px;
  -webkit-border-bottom-left-radius: 4px;
  -moz-border-radius-bottomleft: 4px;
  border-bottom-left-radius: 4px;
}
.nav-tabs.nav-stacked > li > a:hover,
.nav-tabs.nav-stacked > li > a:focus {
  border-color: #ddd;
  z-index: 2;
}
.nav-pills.nav-stacked > li > a {
  margin-bottom: 3px;
}
.nav-pills.nav-stacked > li:last-child > a {
  margin-bottom: 1px;
}
.nav-tabs .dropdown-menu {
  -webkit-border-radius: 0 0 6px 6px;
  -moz-border-radius: 0 0 6px 6px;
  border-radius: 0 0 6px 6px;
}
.nav-pills .dropdown-menu {
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
}
.nav .dropdown-toggle .caret {
  border-top-color: #e73892;
  border-bottom-color: #e73892;
  margin-top: 6px;
}
.nav .dropdown-toggle:hover .caret,
.nav .dropdown-toggle:focus .caret {
  border-top-color: #bc176c;
  border-bottom-color: #bc176c;
}
/* move down carets for tabs */
.nav-tabs .dropdown-toggle .caret {
  margin-top: 8px;
}
.nav .active .dropdown-toggle .caret {
  border-top-color: #fff;
  border-bottom-color: #fff;
}
.nav-tabs .active .dropdown-toggle .caret {
  border-top-color: #555555;
  border-bottom-color: #555555;
}
.nav > .dropdown.active > a:hover,
.nav > .dropdown.active > a:focus {
  cursor: pointer;
}
.nav-tabs .open .dropdown-toggle,
.nav-pills .open .dropdown-toggle,
.nav > li.dropdown.open.active > a:hover,
.nav > li.dropdown.open.active > a:focus {
  color: #ffffff;
  background-color: #999999;
  border-color: #999999;
}
.nav li.dropdown.open .caret,
.nav li.dropdown.open.active .caret,
.nav li.dropdown.open a:hover .caret,
.nav li.dropdown.open a:focus .caret {
  border-top-color: #ffffff;
  border-bottom-color: #ffffff;
  opacity: 1;
  filter: alpha(opacity=100);
}
.tabs-stacked .open > a:hover,
.tabs-stacked .open > a:focus {
  border-color: #999999;
}
.tabbable {
  *zoom: 1;
}
.tabbable:before,
.tabbable:after {
  display: table;
  content: "";
  line-height: 0;
}
.tabbable:after {
  clear: both;
}
.tab-content {
  overflow: auto;
}
.tabs-below > .nav-tabs,
.tabs-right > .nav-tabs,
.tabs-left > .nav-tabs {
  border-bottom: 0;
}
.tab-content > .tab-pane,
.pill-content > .pill-pane {
  display: none;
}
.tab-content > .active,
.pill-content > .active {
  display: block;
}
.tabs-below > .nav-tabs {
  border-top: 1px solid #ddd;
}
.tabs-below > .nav-tabs > li {
  margin-top: -1px;
  margin-bottom: 0;
}
.tabs-below > .nav-tabs > li > a {
  -webkit-border-radius: 0 0 4px 4px;
  -moz-border-radius: 0 0 4px 4px;
  border-radius: 0 0 4px 4px;
}
.tabs-below > .nav-tabs > li > a:hover,
.tabs-below > .nav-tabs > li > a:focus {
  border-bottom-color: transparent;
  border-top-color: #ddd;
}
.tabs-below > .nav-tabs > .active > a,
.tabs-below > .nav-tabs > .active > a:hover,
.tabs-below > .nav-tabs > .active > a:focus {
  border-color: transparent #ddd #ddd #ddd;
}
.tabs-left > .nav-tabs > li,
.tabs-right > .nav-tabs > li {
  float: none;
}
.tabs-left > .nav-tabs > li > a,
.tabs-right > .nav-tabs > li > a {
  min-width: 74px;
  margin-right: 0;
  margin-bottom: 3px;
}
.tabs-left > .nav-tabs {
  float: left;
  margin-right: 19px;
  border-right: 1px solid #ddd;
}
.tabs-left > .nav-tabs > li > a {
  margin-right: -1px;
  -webkit-border-radius: 4px 0 0 4px;
  -moz-border-radius: 4px 0 0 4px;
  border-radius: 4px 0 0 4px;
}
.tabs-left > .nav-tabs > li > a:hover,
.tabs-left > .nav-tabs > li > a:focus {
  border-color: #eeeeee #dddddd #eeeeee #eeeeee;
}
.tabs-left > .nav-tabs .active > a,
.tabs-left > .nav-tabs .active > a:hover,
.tabs-left > .nav-tabs .active > a:focus {
  border-color: #ddd transparent #ddd #ddd;
  *border-right-color: #ffffff;
}
.tabs-right > .nav-tabs {
  float: right;
  margin-left: 19px;
  border-left: 1px solid #ddd;
}
.tabs-right > .nav-tabs > li > a {
  margin-left: -1px;
  -webkit-border-radius: 0 4px 4px 0;
  -moz-border-radius: 0 4px 4px 0;
  border-radius: 0 4px 4px 0;
}
.tabs-right > .nav-tabs > li > a:hover,
.tabs-right > .nav-tabs > li > a:focus {
  border-color: #eeeeee #eeeeee #eeeeee #dddddd;
}
.tabs-right > .nav-tabs .active > a,
.tabs-right > .nav-tabs .active > a:hover,
.tabs-right > .nav-tabs .active > a:focus {
  border-color: #ddd #ddd #ddd transparent;
  *border-left-color: #ffffff;
}
.nav > .disabled > a {
  color: #999999;
}
.nav > .disabled > a:hover,
.nav > .disabled > a:focus {
  text-decoration: none;
  background-color: transparent;
  cursor: default;
}
.navbar {
  overflow: visible;
  margin-bottom: 20px;
  *position: relative;
  *z-index: 2;
}
.navbar-inner {
  min-height: 40px;
  padding-left: 20px;
  padding-right: 20px;
  background-color: #fafafa;
  background-image: -moz-linear-gradient(top, #ffffff, #f2f2f2);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#f2f2f2));
  background-image: -webkit-linear-gradient(top, #ffffff, #f2f2f2);
  background-image: -o-linear-gradient(top, #ffffff, #f2f2f2);
  background-image: linear-gradient(to bottom, #ffffff, #f2f2f2);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffffff', endColorstr='#fff2f2f2', GradientType=0);
  border: 1px solid #d4d4d4;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.065);
  -moz-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.065);
  box-shadow: 0 1px 4px rgba(0, 0, 0, 0.065);
  *zoom: 1;
}
.navbar-inner:before,
.navbar-inner:after {
  display: table;
  content: "";
  line-height: 0;
}
.navbar-inner:after {
  clear: both;
}
.navbar .container {
  width: auto;
}
.nav-collapse.collapse {
  height: auto;
  overflow: visible;
}
.navbar .brand {
  float: left;
  display: block;
  padding: 10px 20px 10px;
  margin-left: -20px;
  font-size: 20px;
  font-weight: 200;
  color: #777777;
  text-shadow: 0 1px 0 #ffffff;
}
.navbar .brand:hover,
.navbar .brand:focus {
  text-decoration: none;
}
.navbar-text {
  margin-bottom: 0;
  line-height: 40px;
  color: #777777;
}
.navbar-link {
  color: #777777;
}
.navbar-link:hover,
.navbar-link:focus {
  color: #333333;
}
.navbar .divider-vertical {
  height: 40px;
  margin: 0 9px;
  border-left: 1px solid #f2f2f2;
  border-right: 1px solid #ffffff;
}
.navbar .btn,
.navbar .btn-group {
  margin-top: 5px;
}
.navbar .btn-group .btn,
.navbar .input-prepend .btn,
.navbar .input-append .btn,
.navbar .input-prepend .btn-group,
.navbar .input-append .btn-group {
  margin-top: 0;
}
.navbar-form {
  margin-bottom: 0;
  *zoom: 1;
}
.navbar-form:before,
.navbar-form:after {
  display: table;
  content: "";
  line-height: 0;
}
.navbar-form:after {
  clear: both;
}
.navbar-form input,
.navbar-form select,
.navbar-form .radio,
.navbar-form .checkbox {
  margin-top: 5px;
}
.navbar-form input,
.navbar-form select,
.navbar-form .btn {
  display: inline-block;
  margin-bottom: 0;
}
.navbar-form input[type="image"],
.navbar-form input[type="checkbox"],
.navbar-form input[type="radio"] {
  margin-top: 3px;
}
.navbar-form .input-append,
.navbar-form .input-prepend {
  margin-top: 5px;
  white-space: nowrap;
}
.navbar-form .input-append input,
.navbar-form .input-prepend input {
  margin-top: 0;
}
.navbar-search {
  position: relative;
  float: left;
  margin-top: 5px;
  margin-bottom: 0;
}
.navbar-search .search-query {
  margin-bottom: 0;
  padding: 4px 14px;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 13px;
  font-weight: normal;
  line-height: 1;
  -webkit-border-radius: 15px;
  -moz-border-radius: 15px;
  border-radius: 15px;
}
.navbar-static-top {
  position: static;
  margin-bottom: 0;
}
.navbar-static-top .navbar-inner {
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.navbar-fixed-top,
.navbar-fixed-bottom {
  position: fixed;
  right: 0;
  left: 0;
  z-index: 1030;
  margin-bottom: 0;
}
.navbar-fixed-top .navbar-inner,
.navbar-static-top .navbar-inner {
  border-width: 0 0 1px;
}
.navbar-fixed-bottom .navbar-inner {
  border-width: 1px 0 0;
}
.navbar-fixed-top .navbar-inner,
.navbar-fixed-bottom .navbar-inner {
  padding-left: 0;
  padding-right: 0;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.navbar-static-top .container,
.navbar-fixed-top .container,
.navbar-fixed-bottom .container {
  width: 940px;
}
.navbar-fixed-top {
  top: 0;
}
.navbar-fixed-top .navbar-inner,
.navbar-static-top .navbar-inner {
  -webkit-box-shadow: 0 1px 10px rgba(0,0,0,.1);
  -moz-box-shadow: 0 1px 10px rgba(0,0,0,.1);
  box-shadow: 0 1px 10px rgba(0,0,0,.1);
}
.navbar-fixed-bottom {
  bottom: 0;
}
.navbar-fixed-bottom .navbar-inner {
  -webkit-box-shadow: 0 -1px 10px rgba(0,0,0,.1);
  -moz-box-shadow: 0 -1px 10px rgba(0,0,0,.1);
  box-shadow: 0 -1px 10px rgba(0,0,0,.1);
}
.navbar .nav {
  position: relative;
  left: 0;
  display: block;
  float: left;
  margin: 0 10px 0 0;
}
.navbar .nav.pull-right {
  float: right;
  margin-right: 0;
}
.navbar .nav > li {
  float: left;
}
.navbar .nav > li > a {
  float: none;
  padding: 10px 15px 10px;
  color: #777777;
  text-decoration: none;
  text-shadow: 0 1px 0 #ffffff;
}
.navbar .nav .dropdown-toggle .caret {
  margin-top: 8px;
}
.navbar .nav > li > a:focus,
.navbar .nav > li > a:hover {
  background-color: transparent;
  color: #333333;
  text-decoration: none;
}
.navbar .nav > .active > a,
.navbar .nav > .active > a:hover,
.navbar .nav > .active > a:focus {
  color: #555555;
  text-decoration: none;
  background-color: #e5e5e5;
  -webkit-box-shadow: inset 0 3px 8px rgba(0, 0, 0, 0.125);
  -moz-box-shadow: inset 0 3px 8px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 8px rgba(0, 0, 0, 0.125);
}
.navbar .btn-navbar {
  display: none;
  float: right;
  padding: 7px 10px;
  margin-left: 5px;
  margin-right: 5px;
  color: #ffffff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #ededed;
  background-image: -moz-linear-gradient(top, #f2f2f2, #e5e5e5);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f2f2f2), to(#e5e5e5));
  background-image: -webkit-linear-gradient(top, #f2f2f2, #e5e5e5);
  background-image: -o-linear-gradient(top, #f2f2f2, #e5e5e5);
  background-image: linear-gradient(to bottom, #f2f2f2, #e5e5e5);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff2f2f2', endColorstr='#ffe5e5e5', GradientType=0);
  border-color: #e5e5e5 #e5e5e5 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  *background-color: #e5e5e5;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  -webkit-box-shadow: inset 0 1px 0 rgba(255,255,255,.1), 0 1px 0 rgba(255,255,255,.075);
  -moz-box-shadow: inset 0 1px 0 rgba(255,255,255,.1), 0 1px 0 rgba(255,255,255,.075);
  box-shadow: inset 0 1px 0 rgba(255,255,255,.1), 0 1px 0 rgba(255,255,255,.075);
}
.navbar .btn-navbar:hover,
.navbar .btn-navbar:focus,
.navbar .btn-navbar:active,
.navbar .btn-navbar.active,
.navbar .btn-navbar.disabled,
.navbar .btn-navbar[disabled] {
  color: #ffffff;
  background-color: #e5e5e5;
  *background-color: #d9d9d9;
}
.navbar .btn-navbar:active,
.navbar .btn-navbar.active {
  background-color: #cccccc \9;
}
.navbar .btn-navbar .icon-bar {
  display: block;
  width: 18px;
  height: 2px;
  background-color: #f5f5f5;
  -webkit-border-radius: 1px;
  -moz-border-radius: 1px;
  border-radius: 1px;
  -webkit-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
  -moz-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
  box-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
}
.btn-navbar .icon-bar + .icon-bar {
  margin-top: 3px;
}
.navbar .nav > li > .dropdown-menu:before {
  content: '';
  display: inline-block;
  border-left: 7px solid transparent;
  border-right: 7px solid transparent;
  border-bottom: 7px solid #ccc;
  border-bottom-color: rgba(0, 0, 0, 0.2);
  position: absolute;
  top: -7px;
  left: 9px;
}
.navbar .nav > li > .dropdown-menu:after {
  content: '';
  display: inline-block;
  border-left: 6px solid transparent;
  border-right: 6px solid transparent;
  border-bottom: 6px solid #ffffff;
  position: absolute;
  top: -6px;
  left: 10px;
}
.navbar-fixed-bottom .nav > li > .dropdown-menu:before {
  border-top: 7px solid #ccc;
  border-top-color: rgba(0, 0, 0, 0.2);
  border-bottom: 0;
  bottom: -7px;
  top: auto;
}
.navbar-fixed-bottom .nav > li > .dropdown-menu:after {
  border-top: 6px solid #ffffff;
  border-bottom: 0;
  bottom: -6px;
  top: auto;
}
.navbar .nav li.dropdown > a:hover .caret,
.navbar .nav li.dropdown > a:focus .caret {
  border-top-color: #333333;
  border-bottom-color: #333333;
}
.navbar .nav li.dropdown.open > .dropdown-toggle,
.navbar .nav li.dropdown.active > .dropdown-toggle,
.navbar .nav li.dropdown.open.active > .dropdown-toggle {
  background-color: #e5e5e5;
  color: #555555;
}
.navbar .nav li.dropdown > .dropdown-toggle .caret {
  border-top-color: #777777;
  border-bottom-color: #777777;
}
.navbar .nav li.dropdown.open > .dropdown-toggle .caret,
.navbar .nav li.dropdown.active > .dropdown-toggle .caret,
.navbar .nav li.dropdown.open.active > .dropdown-toggle .caret {
  border-top-color: #555555;
  border-bottom-color: #555555;
}
.navbar .pull-right > li > .dropdown-menu,
.navbar .nav > li > .dropdown-menu.pull-right {
  left: auto;
  right: 0;
}
.navbar .pull-right > li > .dropdown-menu:before,
.navbar .nav > li > .dropdown-menu.pull-right:before {
  left: auto;
  right: 12px;
}
.navbar .pull-right > li > .dropdown-menu:after,
.navbar .nav > li > .dropdown-menu.pull-right:after {
  left: auto;
  right: 13px;
}
.navbar .pull-right > li > .dropdown-menu .dropdown-menu,
.navbar .nav > li > .dropdown-menu.pull-right .dropdown-menu {
  left: auto;
  right: 100%;
  margin-left: 0;
  margin-right: -1px;
  -webkit-border-radius: 6px 0 6px 6px;
  -moz-border-radius: 6px 0 6px 6px;
  border-radius: 6px 0 6px 6px;
}
.navbar-inverse .navbar-inner {
  background-color: #1b1b1b;
  background-image: -moz-linear-gradient(top, #222222, #111111);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#222222), to(#111111));
  background-image: -webkit-linear-gradient(top, #222222, #111111);
  background-image: -o-linear-gradient(top, #222222, #111111);
  background-image: linear-gradient(to bottom, #222222, #111111);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff222222', endColorstr='#ff111111', GradientType=0);
  border-color: #252525;
}
.navbar-inverse .brand,
.navbar-inverse .nav > li > a {
  color: #999999;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
}
.navbar-inverse .brand:hover,
.navbar-inverse .nav > li > a:hover,
.navbar-inverse .brand:focus,
.navbar-inverse .nav > li > a:focus {
  color: #ffffff;
}
.navbar-inverse .brand {
  color: #999999;
}
.navbar-inverse .navbar-text {
  color: #999999;
}
.navbar-inverse .nav > li > a:focus,
.navbar-inverse .nav > li > a:hover {
  background-color: transparent;
  color: #ffffff;
}
.navbar-inverse .nav .active > a,
.navbar-inverse .nav .active > a:hover,
.navbar-inverse .nav .active > a:focus {
  color: #ffffff;
  background-color: #111111;
}
.navbar-inverse .navbar-link {
  color: #999999;
}
.navbar-inverse .navbar-link:hover,
.navbar-inverse .navbar-link:focus {
  color: #ffffff;
}
.navbar-inverse .divider-vertical {
  border-left-color: #111111;
  border-right-color: #222222;
}
.navbar-inverse .nav li.dropdown.open > .dropdown-toggle,
.navbar-inverse .nav li.dropdown.active > .dropdown-toggle,
.navbar-inverse .nav li.dropdown.open.active > .dropdown-toggle {
  background-color: #111111;
  color: #ffffff;
}
.navbar-inverse .nav li.dropdown > a:hover .caret,
.navbar-inverse .nav li.dropdown > a:focus .caret {
  border-top-color: #ffffff;
  border-bottom-color: #ffffff;
}
.navbar-inverse .nav li.dropdown > .dropdown-toggle .caret {
  border-top-color: #999999;
  border-bottom-color: #999999;
}
.navbar-inverse .nav li.dropdown.open > .dropdown-toggle .caret,
.navbar-inverse .nav li.dropdown.active > .dropdown-toggle .caret,
.navbar-inverse .nav li.dropdown.open.active > .dropdown-toggle .caret {
  border-top-color: #ffffff;
  border-bottom-color: #ffffff;
}
.navbar-inverse .navbar-search .search-query {
  color: #ffffff;
  background-color: #515151;
  border-color: #111111;
  -webkit-box-shadow: inset 0 1px 2px rgba(0,0,0,.1), 0 1px 0 rgba(255,255,255,.15);
  -moz-box-shadow: inset 0 1px 2px rgba(0,0,0,.1), 0 1px 0 rgba(255,255,255,.15);
  box-shadow: inset 0 1px 2px rgba(0,0,0,.1), 0 1px 0 rgba(255,255,255,.15);
  -webkit-transition: none;
  -moz-transition: none;
  -o-transition: none;
  transition: none;
}
.navbar-inverse .navbar-search .search-query:-moz-placeholder {
  color: #cccccc;
}
.navbar-inverse .navbar-search .search-query:-ms-input-placeholder {
  color: #cccccc;
}
.navbar-inverse .navbar-search .search-query::-webkit-input-placeholder {
  color: #cccccc;
}
.navbar-inverse .navbar-search .search-query:focus,
.navbar-inverse .navbar-search .search-query.focused {
  padding: 5px 15px;
  color: #333333;
  text-shadow: 0 1px 0 #ffffff;
  background-color: #ffffff;
  border: 0;
  -webkit-box-shadow: 0 0 3px rgba(0, 0, 0, 0.15);
  -moz-box-shadow: 0 0 3px rgba(0, 0, 0, 0.15);
  box-shadow: 0 0 3px rgba(0, 0, 0, 0.15);
  outline: 0;
}
.navbar-inverse .btn-navbar {
  color: #ffffff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #0e0e0e;
  background-image: -moz-linear-gradient(top, #151515, #040404);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#151515), to(#040404));
  background-image: -webkit-linear-gradient(top, #151515, #040404);
  background-image: -o-linear-gradient(top, #151515, #040404);
  background-image: linear-gradient(to bottom, #151515, #040404);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff151515', endColorstr='#ff040404', GradientType=0);
  border-color: #040404 #040404 #000000;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  *background-color: #040404;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}
.navbar-inverse .btn-navbar:hover,
.navbar-inverse .btn-navbar:focus,
.navbar-inverse .btn-navbar:active,
.navbar-inverse .btn-navbar.active,
.navbar-inverse .btn-navbar.disabled,
.navbar-inverse .btn-navbar[disabled] {
  color: #ffffff;
  background-color: #040404;
  *background-color: #000000;
}
.navbar-inverse .btn-navbar:active,
.navbar-inverse .btn-navbar.active {
  background-color: #000000 \9;
}
.breadcrumb {
  padding: 8px 15px;
  margin: 0 0 20px;
  list-style: none;
  background-color: #f5f5f5;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.breadcrumb > li {
  display: inline-block;
  *display: inline;
  /* IE7 inline-block hack */
  *zoom: 1;
  text-shadow: 0 1px 0 #ffffff;
}
.breadcrumb > li > .divider {
  padding: 0 5px;
  color: #ccc;
}
.breadcrumb > .active {
  color: #999999;
}
.pagination {
  margin: 20px 0;
}
.pagination ul {
  display: inline-block;
  *display: inline;
  /* IE7 inline-block hack */
  *zoom: 1;
  margin-left: 0;
  margin-bottom: 0;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
}
.pagination ul > li {
  display: inline;
}
.pagination ul > li > a,
.pagination ul > li > span {
  float: left;
  padding: 4px 12px;
  line-height: 20px;
  text-decoration: none;
  background-color: #ffffff;
  border: 1px solid #dddddd;
  border-left-width: 0;
}
.pagination ul > li > a:hover,
.pagination ul > li > a:focus,
.pagination ul > .active > a,
.pagination ul > .active > span {
  background-color: #f5f5f5;
}
.pagination ul > .active > a,
.pagination ul > .active > span {
  color: #999999;
  cursor: default;
}
.pagination ul > .disabled > span,
.pagination ul > .disabled > a,
.pagination ul > .disabled > a:hover,
.pagination ul > .disabled > a:focus {
  color: #999999;
  background-color: transparent;
  cursor: default;
}
.pagination ul > li:first-child > a,
.pagination ul > li:first-child > span {
  border-left-width: 1px;
  -webkit-border-top-left-radius: 4px;
  -moz-border-radius-topleft: 4px;
  border-top-left-radius: 4px;
  -webkit-border-bottom-left-radius: 4px;
  -moz-border-radius-bottomleft: 4px;
  border-bottom-left-radius: 4px;
}
.pagination ul > li:last-child > a,
.pagination ul > li:last-child > span {
  -webkit-border-top-right-radius: 4px;
  -moz-border-radius-topright: 4px;
  border-top-right-radius: 4px;
  -webkit-border-bottom-right-radius: 4px;
  -moz-border-radius-bottomright: 4px;
  border-bottom-right-radius: 4px;
}
.pagination-centered {
  text-align: center;
}
.pagination-right {
  text-align: right;
}
.pagination-large ul > li > a,
.pagination-large ul > li > span {
  padding: 11px 19px;
  font-size: 17.5px;
}
.pagination-large ul > li:first-child > a,
.pagination-large ul > li:first-child > span {
  -webkit-border-top-left-radius: 6px;
  -moz-border-radius-topleft: 6px;
  border-top-left-radius: 6px;
  -webkit-border-bottom-left-radius: 6px;
  -moz-border-radius-bottomleft: 6px;
  border-bottom-left-radius: 6px;
}
.pagination-large ul > li:last-child > a,
.pagination-large ul > li:last-child > span {
  -webkit-border-top-right-radius: 6px;
  -moz-border-radius-topright: 6px;
  border-top-right-radius: 6px;
  -webkit-border-bottom-right-radius: 6px;
  -moz-border-radius-bottomright: 6px;
  border-bottom-right-radius: 6px;
}
.pagination-mini ul > li:first-child > a,
.pagination-small ul > li:first-child > a,
.pagination-mini ul > li:first-child > span,
.pagination-small ul > li:first-child > span {
  -webkit-border-top-left-radius: 3px;
  -moz-border-radius-topleft: 3px;
  border-top-left-radius: 3px;
  -webkit-border-bottom-left-radius: 3px;
  -moz-border-radius-bottomleft: 3px;
  border-bottom-left-radius: 3px;
}
.pagination-mini ul > li:last-child > a,
.pagination-small ul > li:last-child > a,
.pagination-mini ul > li:last-child > span,
.pagination-small ul > li:last-child > span {
  -webkit-border-top-right-radius: 3px;
  -moz-border-radius-topright: 3px;
  border-top-right-radius: 3px;
  -webkit-border-bottom-right-radius: 3px;
  -moz-border-radius-bottomright: 3px;
  border-bottom-right-radius: 3px;
}
.pagination-small ul > li > a,
.pagination-small ul > li > span {
  padding: 2px 10px;
  font-size: 11.9px;
}
.pagination-mini ul > li > a,
.pagination-mini ul > li > span {
  padding: 0 6px;
  font-size: 10.5px;
}
.pager {
  margin: 20px 0;
  list-style: none;
  text-align: center;
  *zoom: 1;
}
.pager:before,
.pager:after {
  display: table;
  content: "";
  line-height: 0;
}
.pager:after {
  clear: both;
}
.pager li {
  display: inline;
}
.pager li > a,
.pager li > span {
  display: inline-block;
  padding: 5px 14px;
  background-color: #fff;
  border: 1px solid #ddd;
  -webkit-border-radius: 15px;
  -moz-border-radius: 15px;
  border-radius: 15px;
}
.pager li > a:hover,
.pager li > a:focus {
  text-decoration: none;
  background-color: #f5f5f5;
}
.pager .next > a,
.pager .next > span {
  float: right;
}
.pager .previous > a,
.pager .previous > span {
  float: left;
}
.pager .disabled > a,
.pager .disabled > a:hover,
.pager .disabled > a:focus,
.pager .disabled > span {
  color: #999999;
  background-color: #fff;
  cursor: default;
}
.modal-backdrop {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1040;
  background-color: #000000;
}
.modal-backdrop.fade {
  opacity: 0;
}
.modal-backdrop,
.modal-backdrop.fade.in {
  opacity: 0.8;
  filter: alpha(opacity=80);
}
.modal {
  position: fixed;
  top: 10%;
  left: 50%;
  z-index: 1050;
  width: 560px;
  margin-left: -280px;
  background-color: #ffffff;
  border: 1px solid #999;
  border: 1px solid rgba(0, 0, 0, 0.3);
  *border: 1px solid #999;
  /* IE6-7 */
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
  -webkit-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
  -moz-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
  box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
  -webkit-background-clip: padding-box;
  -moz-background-clip: padding-box;
  background-clip: padding-box;
  outline: none;
}
.modal.fade {
  -webkit-transition: opacity .3s linear, top .3s ease-out;
  -moz-transition: opacity .3s linear, top .3s ease-out;
  -o-transition: opacity .3s linear, top .3s ease-out;
  transition: opacity .3s linear, top .3s ease-out;
  top: -25%;
}
.modal.fade.in {
  top: 10%;
}
.modal-header {
  padding: 9px 15px;
  border-bottom: 1px solid #eee;
}
.modal-header .close {
  margin-top: 2px;
}
.modal-header h3 {
  margin: 0;
  line-height: 30px;
}
.modal-body {
  position: relative;
  overflow-y: auto;
  max-height: 400px;
  padding: 15px;
}
.modal-form {
  margin-bottom: 0;
}
.modal-footer {
  padding: 14px 15px 15px;
  margin-bottom: 0;
  text-align: right;
  background-color: #f5f5f5;
  border-top: 1px solid #ddd;
  -webkit-border-radius: 0 0 6px 6px;
  -moz-border-radius: 0 0 6px 6px;
  border-radius: 0 0 6px 6px;
  -webkit-box-shadow: inset 0 1px 0 #ffffff;
  -moz-box-shadow: inset 0 1px 0 #ffffff;
  box-shadow: inset 0 1px 0 #ffffff;
  *zoom: 1;
}
.modal-footer:before,
.modal-footer:after {
  display: table;
  content: "";
  line-height: 0;
}
.modal-footer:after {
  clear: both;
}
.modal-footer .btn + .btn {
  margin-left: 5px;
  margin-bottom: 0;
}
.modal-footer .btn-group .btn + .btn {
  margin-left: -1px;
}
.modal-footer .btn-block + .btn-block {
  margin-left: 0;
}
.tooltip {
  position: absolute;
  z-index: 1030;
  display: block;
  visibility: visible;
  font-size: 11px;
  line-height: 1.4;
  opacity: 0;
  filter: alpha(opacity=0);
}
.tooltip.in {
  opacity: 0.8;
  filter: alpha(opacity=80);
}
.tooltip.top {
  margin-top: -3px;
  padding: 5px 0;
}
.tooltip.right {
  margin-left: 3px;
  padding: 0 5px;
}
.tooltip.bottom {
  margin-top: 3px;
  padding: 5px 0;
}
.tooltip.left {
  margin-left: -3px;
  padding: 0 5px;
}
.tooltip-inner {
  max-width: 200px;
  padding: 8px;
  color: #ffffff;
  text-align: center;
  text-decoration: none;
  background-color: #000000;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.tooltip-arrow {
  position: absolute;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid;
}
.tooltip.top .tooltip-arrow {
  bottom: 0;
  left: 50%;
  margin-left: -5px;
  border-width: 5px 5px 0;
  border-top-color: #000000;
}
.tooltip.right .tooltip-arrow {
  top: 50%;
  left: 0;
  margin-top: -5px;
  border-width: 5px 5px 5px 0;
  border-right-color: #000000;
}
.tooltip.left .tooltip-arrow {
  top: 50%;
  right: 0;
  margin-top: -5px;
  border-width: 5px 0 5px 5px;
  border-left-color: #000000;
}
.tooltip.bottom .tooltip-arrow {
  top: 0;
  left: 50%;
  margin-left: -5px;
  border-width: 0 5px 5px;
  border-bottom-color: #000000;
}
.thumbnails {
  margin-left: -20px;
  list-style: none;
  *zoom: 1;
}
.thumbnails:before,
.thumbnails:after {
  display: table;
  content: "";
  line-height: 0;
}
.thumbnails:after {
  clear: both;
}
.row-fluid .thumbnails {
  margin-left: 0;
}
.thumbnails > li {
  float: left;
  margin-bottom: 20px;
  margin-left: 20px;
}
.thumbnail {
  display: block;
  padding: 4px;
  line-height: 20px;
  border: 1px solid #ddd;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.055);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.055);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.055);
  -webkit-transition: all 0.2s ease-in-out;
  -moz-transition: all 0.2s ease-in-out;
  -o-transition: all 0.2s ease-in-out;
  transition: all 0.2s ease-in-out;
}
a.thumbnail:hover,
a.thumbnail:focus {
  border-color: #e73892;
  -webkit-box-shadow: 0 1px 4px rgba(0, 105, 214, 0.25);
  -moz-box-shadow: 0 1px 4px rgba(0, 105, 214, 0.25);
  box-shadow: 0 1px 4px rgba(0, 105, 214, 0.25);
}
.thumbnail > img {
  display: block;
  max-width: 100%;
  margin-left: auto;
  margin-right: auto;
}
.thumbnail .caption {
  padding: 9px;
  color: #555555;
}
.label,
.badge {
  display: inline-block;
  padding: 2px 4px;
  font-size: 11.844px;
  font-weight: bold;
  line-height: 14px;
  color: #ffffff;
  vertical-align: baseline;
  white-space: nowrap;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #999999;
}
.label {
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.badge {
  padding-left: 9px;
  padding-right: 9px;
  -webkit-border-radius: 9px;
  -moz-border-radius: 9px;
  border-radius: 9px;
}
.label:empty,
.badge:empty {
  display: none;
}
a.label:hover,
a.label:focus,
a.badge:hover,
a.badge:focus {
  color: #ffffff;
  text-decoration: none;
  cursor: pointer;
}
.label-important,
.badge-important {
  background-color: #b55457;
}
.label-important[href],
.badge-important[href] {
  background-color: #954143;
}
.label-warning,
.badge-warning {
  background-color: #f89406;
}
.label-warning[href],
.badge-warning[href] {
  background-color: #c67605;
}
.label-success,
.badge-success {
  background-color: #468847;
}
.label-success[href],
.badge-success[href] {
  background-color: #356635;
}
.label-info,
.badge-info {
  background-color: #3a87ad;
}
.label-info[href],
.badge-info[href] {
  background-color: #2d6987;
}
.label-inverse,
.badge-inverse {
  background-color: #333333;
}
.label-inverse[href],
.badge-inverse[href] {
  background-color: #1a1a1a;
}
.btn .label,
.btn .badge {
  position: relative;
  top: -1px;
}
.btn-mini .label,
.btn-mini .badge {
  top: 0;
}
@-webkit-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}
@-moz-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}
@-ms-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}
@-o-keyframes progress-bar-stripes {
  from {
    background-position: 0 0;
  }
  to {
    background-position: 40px 0;
  }
}
@keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}
.progress {
  overflow: hidden;
  height: 20px;
  margin-bottom: 20px;
  background-color: #f7f7f7;
  background-image: -moz-linear-gradient(top, #f5f5f5, #f9f9f9);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f5f5f5), to(#f9f9f9));
  background-image: -webkit-linear-gradient(top, #f5f5f5, #f9f9f9);
  background-image: -o-linear-gradient(top, #f5f5f5, #f9f9f9);
  background-image: linear-gradient(to bottom, #f5f5f5, #f9f9f9);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff5f5f5', endColorstr='#fff9f9f9', GradientType=0);
  -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
  -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.progress .bar {
  width: 0%;
  height: 100%;
  color: #ffffff;
  float: left;
  font-size: 12px;
  text-align: center;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #0e90d2;
  background-image: -moz-linear-gradient(top, #149bdf, #0480be);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#149bdf), to(#0480be));
  background-image: -webkit-linear-gradient(top, #149bdf, #0480be);
  background-image: -o-linear-gradient(top, #149bdf, #0480be);
  background-image: linear-gradient(to bottom, #149bdf, #0480be);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff149bdf', endColorstr='#ff0480be', GradientType=0);
  -webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  -moz-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-transition: width 0.6s ease;
  -moz-transition: width 0.6s ease;
  -o-transition: width 0.6s ease;
  transition: width 0.6s ease;
}
.progress .bar + .bar {
  -webkit-box-shadow: inset 1px 0 0 rgba(0,0,0,.15), inset 0 -1px 0 rgba(0,0,0,.15);
  -moz-box-shadow: inset 1px 0 0 rgba(0,0,0,.15), inset 0 -1px 0 rgba(0,0,0,.15);
  box-shadow: inset 1px 0 0 rgba(0,0,0,.15), inset 0 -1px 0 rgba(0,0,0,.15);
}
.progress-striped .bar {
  background-color: #149bdf;
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  -webkit-background-size: 40px 40px;
  -moz-background-size: 40px 40px;
  -o-background-size: 40px 40px;
  background-size: 40px 40px;
}
.progress.active .bar {
  -webkit-animation: progress-bar-stripes 2s linear infinite;
  -moz-animation: progress-bar-stripes 2s linear infinite;
  -ms-animation: progress-bar-stripes 2s linear infinite;
  -o-animation: progress-bar-stripes 2s linear infinite;
  animation: progress-bar-stripes 2s linear infinite;
}
.progress-danger .bar,
.progress .bar-danger {
  background-color: #dd514c;
  background-image: -moz-linear-gradient(top, #ee5f5b, #c43c35);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ee5f5b), to(#c43c35));
  background-image: -webkit-linear-gradient(top, #ee5f5b, #c43c35);
  background-image: -o-linear-gradient(top, #ee5f5b, #c43c35);
  background-image: linear-gradient(to bottom, #ee5f5b, #c43c35);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffee5f5b', endColorstr='#ffc43c35', GradientType=0);
}
.progress-danger.progress-striped .bar,
.progress-striped .bar-danger {
  background-color: #ee5f5b;
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-success .bar,
.progress .bar-success {
  background-color: #5eb95e;
  background-image: -moz-linear-gradient(top, #62c462, #57a957);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#62c462), to(#57a957));
  background-image: -webkit-linear-gradient(top, #62c462, #57a957);
  background-image: -o-linear-gradient(top, #62c462, #57a957);
  background-image: linear-gradient(to bottom, #62c462, #57a957);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff62c462', endColorstr='#ff57a957', GradientType=0);
}
.progress-success.progress-striped .bar,
.progress-striped .bar-success {
  background-color: #62c462;
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-info .bar,
.progress .bar-info {
  background-color: #4bb1cf;
  background-image: -moz-linear-gradient(top, #5bc0de, #339bb9);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#5bc0de), to(#339bb9));
  background-image: -webkit-linear-gradient(top, #5bc0de, #339bb9);
  background-image: -o-linear-gradient(top, #5bc0de, #339bb9);
  background-image: linear-gradient(to bottom, #5bc0de, #339bb9);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff5bc0de', endColorstr='#ff339bb9', GradientType=0);
}
.progress-info.progress-striped .bar,
.progress-striped .bar-info {
  background-color: #5bc0de;
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-warning .bar,
.progress .bar-warning {
  background-color: #faa732;
  background-image: -moz-linear-gradient(top, #fbb450, #f89406);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#fbb450), to(#f89406));
  background-image: -webkit-linear-gradient(top, #fbb450, #f89406);
  background-image: -o-linear-gradient(top, #fbb450, #f89406);
  background-image: linear-gradient(to bottom, #fbb450, #f89406);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fffbb450', endColorstr='#fff89406', GradientType=0);
}
.progress-warning.progress-striped .bar,
.progress-striped .bar-warning {
  background-color: #fbb450;
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.accordion {
  margin-bottom: 20px;
}
.accordion-group {
  margin-bottom: 2px;
  border: 1px solid #e5e5e5;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.accordion-heading {
  border-bottom: 0;
}
.accordion-heading .accordion-toggle {
  display: block;
  padding: 8px 15px;
}
.accordion-toggle {
  cursor: pointer;
}
.accordion-inner {
  padding: 9px 15px;
  border-top: 1px solid #e5e5e5;
}
.carousel {
  position: relative;
  margin-bottom: 20px;
  line-height: 1;
}
.carousel-inner {
  overflow: hidden;
  width: 100%;
  position: relative;
}
.carousel-inner > .item {
  display: none;
  position: relative;
  -webkit-transition: 0.6s ease-in-out left;
  -moz-transition: 0.6s ease-in-out left;
  -o-transition: 0.6s ease-in-out left;
  transition: 0.6s ease-in-out left;
}
.carousel-inner > .item > img,
.carousel-inner > .item > a > img {
  display: block;
  line-height: 1;
}
.carousel-inner > .active,
.carousel-inner > .next,
.carousel-inner > .prev {
  display: block;
}
.carousel-inner > .active {
  left: 0;
}
.carousel-inner > .next,
.carousel-inner > .prev {
  position: absolute;
  top: 0;
  width: 100%;
}
.carousel-inner > .next {
  left: 100%;
}
.carousel-inner > .prev {
  left: -100%;
}
.carousel-inner > .next.left,
.carousel-inner > .prev.right {
  left: 0;
}
.carousel-inner > .active.left {
  left: -100%;
}
.carousel-inner > .active.right {
  left: 100%;
}
.carousel-control {
  position: absolute;
  top: 40%;
  left: 15px;
  width: 40px;
  height: 40px;
  margin-top: -20px;
  font-size: 60px;
  font-weight: 100;
  line-height: 30px;
  color: #ffffff;
  text-align: center;
  background: #222222;
  border: 3px solid #ffffff;
  -webkit-border-radius: 23px;
  -moz-border-radius: 23px;
  border-radius: 23px;
  opacity: 0.5;
  filter: alpha(opacity=50);
}
.carousel-control.right {
  left: auto;
  right: 15px;
}
.carousel-control:hover,
.carousel-control:focus {
  color: #ffffff;
  text-decoration: none;
  opacity: 0.9;
  filter: alpha(opacity=90);
}
.carousel-indicators {
  position: absolute;
  top: 15px;
  right: 15px;
  z-index: 5;
  margin: 0;
  list-style: none;
}
.carousel-indicators li {
  display: block;
  float: left;
  width: 10px;
  height: 10px;
  margin-left: 5px;
  text-indent: -999px;
  background-color: #ccc;
  background-color: rgba(255, 255, 255, 0.25);
  border-radius: 5px;
}
.carousel-indicators .active {
  background-color: #fff;
}
.carousel-caption {
  position: absolute;
  left: 0;
  right: 0;
  bottom: 0;
  padding: 15px;
  background: #333333;
  background: rgba(0, 0, 0, 0.75);
}
.carousel-caption h4,
.carousel-caption p {
  color: #ffffff;
  line-height: 20px;
}
.carousel-caption h4 {
  margin: 0 0 5px;
}
.carousel-caption p {
  margin-bottom: 0;
}
.hero-unit {
  padding: 60px;
  margin-bottom: 30px;
  font-size: 18px;
  font-weight: 200;
  line-height: 30px;
  color: inherit;
  background-color: #eeeeee;
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
}
.hero-unit h1 {
  margin-bottom: 0;
  font-size: 60px;
  line-height: 1;
  color: inherit;
  letter-spacing: -1px;
}
.hero-unit li {
  line-height: 30px;
}
.popover {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 1010;
  display: none;
  max-width: 276px;
  padding: 1px;
  text-align: left;
  background-color: #ffffff;
  -webkit-background-clip: padding-box;
  -moz-background-clip: padding;
  background-clip: padding-box;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, 0.2);
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
  -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  -moz-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  white-space: normal;
}
.popover.top {
  margin-top: -10px;
}
.popover.right {
  margin-left: 10px;
}
.popover.bottom {
  margin-top: 10px;
}
.popover.left {
  margin-left: -10px;
}
.popover-title {
  margin: 0;
  padding: 8px 14px;
  font-size: 14px;
  font-weight: normal;
  line-height: 18px;
  background-color: #f7f7f7;
  border-bottom: 1px solid #ebebeb;
  -webkit-border-radius: 5px 5px 0 0;
  -moz-border-radius: 5px 5px 0 0;
  border-radius: 5px 5px 0 0;
}
.popover-title:empty {
  display: none;
}
.popover-content {
  padding: 9px 14px;
}
.popover .arrow,
.popover .arrow:after {
  position: absolute;
  display: block;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid;
}
.popover .arrow {
  border-width: 11px;
}
.popover .arrow:after {
  border-width: 10px;
  content: "";
}
.popover.top .arrow {
  left: 50%;
  margin-left: -11px;
  border-bottom-width: 0;
  border-top-color: #999;
  border-top-color: rgba(0, 0, 0, 0.25);
  bottom: -11px;
}
.popover.top .arrow:after {
  bottom: 1px;
  margin-left: -10px;
  border-bottom-width: 0;
  border-top-color: #ffffff;
}
.popover.right .arrow {
  top: 50%;
  left: -11px;
  margin-top: -11px;
  border-left-width: 0;
  border-right-color: #999;
  border-right-color: rgba(0, 0, 0, 0.25);
}
.popover.right .arrow:after {
  left: 1px;
  bottom: -10px;
  border-left-width: 0;
  border-right-color: #ffffff;
}
.popover.bottom .arrow {
  left: 50%;
  margin-left: -11px;
  border-top-width: 0;
  border-bottom-color: #999;
  border-bottom-color: rgba(0, 0, 0, 0.25);
  top: -11px;
}
.popover.bottom .arrow:after {
  top: 1px;
  margin-left: -10px;
  border-top-width: 0;
  border-bottom-color: #ffffff;
}
.popover.left .arrow {
  top: 50%;
  right: -11px;
  margin-top: -11px;
  border-right-width: 0;
  border-left-color: #999;
  border-left-color: rgba(0, 0, 0, 0.25);
}
.popover.left .arrow:after {
  right: 1px;
  border-right-width: 0;
  border-left-color: #ffffff;
  bottom: -10px;
}
.pull-right {
  float: right;
}
.pull-left {
  float: left;
}
.hide {
  display: none;
}
.show {
  display: block;
}
.invisible {
  visibility: hidden;
}
.affix {
  position: fixed;
}
/*!
 * Bootstrap Responsive v2.3.2
 *
 * Copyright 2012 Twitter, Inc
 * Licensed under the Apache License v2.0
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Designed and built with all the love in the world @twitter by @mdo and @fat.
 */
@-ms-viewport {
  width: device-width;
}
.hidden {
  display: none;
  visibility: hidden;
}
.visible-phone {
  display: none !important;
}
.visible-tablet {
  display: none !important;
}
.hidden-desktop {
  display: none !important;
}
.visible-desktop {
  display: inherit !important;
}
@media (min-width: 768px) and (max-width: 979px) {
  .hidden-desktop {
    display: inherit !important;
  }
  .visible-desktop {
    display: none !important ;
  }
  .visible-tablet {
    display: inherit !important;
  }
  .hidden-tablet {
    display: none !important;
  }
}
@media (max-width: 767px) {
  .hidden-desktop {
    display: inherit !important;
  }
  .visible-desktop {
    display: none !important;
  }
  .visible-phone {
    display: inherit !important;
  }
  .hidden-phone {
    display: none !important;
  }
}
.visible-print {
  display: none !important;
}
@media print {
  .visible-print {
    display: inherit !important;
  }
  .hidden-print {
    display: none !important;
  }
}
@media (min-width: 768px) and (max-width: 979px) {
  .row {
    margin-left: -20px;
    *zoom: 1;
  }
  .row:before,
  .row:after {
    display: table;
    content: "";
    line-height: 0;
  }
  .row:after {
    clear: both;
  }
  [class*="span"] {
    float: left;
    min-height: 1px;
    margin-left: 20px;
  }
  .container,
  .navbar-static-top .container,
  .navbar-fixed-top .container,
  .navbar-fixed-bottom .container {
    width: 724px;
  }
  .span12 {
    width: 724px;
  }
  .span11 {
    width: 662px;
  }
  .span10 {
    width: 600px;
  }
  .span9 {
    width: 538px;
  }
  .span8 {
    width: 476px;
  }
  .span7 {
    width: 414px;
  }
  .span6 {
    width: 352px;
  }
  .span5 {
    width: 290px;
  }
  .span4 {
    width: 228px;
  }
  .span3 {
    width: 166px;
  }
  .span2 {
    width: 104px;
  }
  .span1 {
    width: 42px;
  }
  .offset12 {
    margin-left: 764px;
  }
  .offset11 {
    margin-left: 702px;
  }
  .offset10 {
    margin-left: 640px;
  }
  .offset9 {
    margin-left: 578px;
  }
  .offset8 {
    margin-left: 516px;
  }
  .offset7 {
    margin-left: 454px;
  }
  .offset6 {
    margin-left: 392px;
  }
  .offset5 {
    margin-left: 330px;
  }
  .offset4 {
    margin-left: 268px;
  }
  .offset3 {
    margin-left: 206px;
  }
  .offset2 {
    margin-left: 144px;
  }
  .offset1 {
    margin-left: 82px;
  }
  .row-fluid {
    width: 100%;
    *zoom: 1;
  }
  .row-fluid:before,
  .row-fluid:after {
    display: table;
    content: "";
    line-height: 0;
  }
  .row-fluid:after {
    clear: both;
  }
  .row-fluid [class*="span"] {
    display: block;
    width: 100%;
    min-height: 30px;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    float: left;
    margin-left: 2.76243094%;
    *margin-left: 2.70923945%;
  }
  .row-fluid [class*="span"]:first-child {
    margin-left: 0;
  }
  .row-fluid .controls-row [class*="span"] + [class*="span"] {
    margin-left: 2.76243094%;
  }
  .row-fluid .span12 {
    width: 100%;
    *width: 99.94680851%;
  }
  .row-fluid .span11 {
    width: 91.43646409%;
    *width: 91.3832726%;
  }
  .row-fluid .span10 {
    width: 82.87292818%;
    *width: 82.81973669%;
  }
  .row-fluid .span9 {
    width: 74.30939227%;
    *width: 74.25620078%;
  }
  .row-fluid .span8 {
    width: 65.74585635%;
    *width: 65.69266486%;
  }
  .row-fluid .span7 {
    width: 57.18232044%;
    *width: 57.12912895%;
  }
  .row-fluid .span6 {
    width: 48.61878453%;
    *width: 48.56559304%;
  }
  .row-fluid .span5 {
    width: 40.05524862%;
    *width: 40.00205713%;
  }
  .row-fluid .span4 {
    width: 31.49171271%;
    *width: 31.43852122%;
  }
  .row-fluid .span3 {
    width: 22.9281768%;
    *width: 22.87498531%;
  }
  .row-fluid .span2 {
    width: 14.36464088%;
    *width: 14.31144939%;
  }
  .row-fluid .span1 {
    width: 5.80110497%;
    *width: 5.74791348%;
  }
  .row-fluid .offset12 {
    margin-left: 105.52486188%;
    *margin-left: 105.4184789%;
  }
  .row-fluid .offset12:first-child {
    margin-left: 102.76243094%;
    *margin-left: 102.65604796%;
  }
  .row-fluid .offset11 {
    margin-left: 96.96132597%;
    *margin-left: 96.85494299%;
  }
  .row-fluid .offset11:first-child {
    margin-left: 94.19889503%;
    *margin-left: 94.09251205%;
  }
  .row-fluid .offset10 {
    margin-left: 88.39779006%;
    *margin-left: 88.29140708%;
  }
  .row-fluid .offset10:first-child {
    margin-left: 85.63535912%;
    *margin-left: 85.52897614%;
  }
  .row-fluid .offset9 {
    margin-left: 79.83425414%;
    *margin-left: 79.72787116%;
  }
  .row-fluid .offset9:first-child {
    margin-left: 77.0718232%;
    *margin-left: 76.96544023%;
  }
  .row-fluid .offset8 {
    margin-left: 71.27071823%;
    *margin-left: 71.16433525%;
  }
  .row-fluid .offset8:first-child {
    margin-left: 68.50828729%;
    *margin-left: 68.40190431%;
  }
  .row-fluid .offset7 {
    margin-left: 62.70718232%;
    *margin-left: 62.60079934%;
  }
  .row-fluid .offset7:first-child {
    margin-left: 59.94475138%;
    *margin-left: 59.8383684%;
  }
  .row-fluid .offset6 {
    margin-left: 54.14364641%;
    *margin-left: 54.03726343%;
  }
  .row-fluid .offset6:first-child {
    margin-left: 51.38121547%;
    *margin-left: 51.27483249%;
  }
  .row-fluid .offset5 {
    margin-left: 45.5801105%;
    *margin-left: 45.47372752%;
  }
  .row-fluid .offset5:first-child {
    margin-left: 42.81767956%;
    *margin-left: 42.71129658%;
  }
  .row-fluid .offset4 {
    margin-left: 37.01657459%;
    *margin-left: 36.91019161%;
  }
  .row-fluid .offset4:first-child {
    margin-left: 34.25414365%;
    *margin-left: 34.14776067%;
  }
  .row-fluid .offset3 {
    margin-left: 28.45303867%;
    *margin-left: 28.3466557%;
  }
  .row-fluid .offset3:first-child {
    margin-left: 25.69060773%;
    *margin-left: 25.58422476%;
  }
  .row-fluid .offset2 {
    margin-left: 19.88950276%;
    *margin-left: 19.78311978%;
  }
  .row-fluid .offset2:first-child {
    margin-left: 17.12707182%;
    *margin-left: 17.02068884%;
  }
  .row-fluid .offset1 {
    margin-left: 11.32596685%;
    *margin-left: 11.21958387%;
  }
  .row-fluid .offset1:first-child {
    margin-left: 8.56353591%;
    *margin-left: 8.45715293%;
  }
  input,
  textarea,
  .uneditable-input {
    margin-left: 0;
  }
  .controls-row [class*="span"] + [class*="span"] {
    margin-left: 20px;
  }
  input.span12,
  textarea.span12,
  .uneditable-input.span12 {
    width: 710px;
  }
  input.span11,
  textarea.span11,
  .uneditable-input.span11 {
    width: 648px;
  }
  input.span10,
  textarea.span10,
  .uneditable-input.span10 {
    width: 586px;
  }
  input.span9,
  textarea.span9,
  .uneditable-input.span9 {
    width: 524px;
  }
  input.span8,
  textarea.span8,
  .uneditable-input.span8 {
    width: 462px;
  }
  input.span7,
  textarea.span7,
  .uneditable-input.span7 {
    width: 400px;
  }
  input.span6,
  textarea.span6,
  .uneditable-input.span6 {
    width: 338px;
  }
  input.span5,
  textarea.span5,
  .uneditable-input.span5 {
    width: 276px;
  }
  input.span4,
  textarea.span4,
  .uneditable-input.span4 {
    width: 214px;
  }
  input.span3,
  textarea.span3,
  .uneditable-input.span3 {
    width: 152px;
  }
  input.span2,
  textarea.span2,
  .uneditable-input.span2 {
    width: 90px;
  }
  input.span1,
  textarea.span1,
  .uneditable-input.span1 {
    width: 28px;
  }
}
@media (max-width: 767px) {
  body {
    padding-left: 20px;
    padding-right: 20px;
  }
  .navbar-fixed-top,
  .navbar-fixed-bottom,
  .navbar-static-top {
    margin-left: -20px;
    margin-right: -20px;
  }
  .container-fluid {
    padding: 0;
  }
  .dl-horizontal dt {
    float: none;
    clear: none;
    width: auto;
    text-align: left;
  }
  .dl-horizontal dd {
    margin-left: 0;
  }
  .container {
    width: auto;
  }
  .row-fluid {
    width: 100%;
  }
  .row,
  .thumbnails {
    margin-left: 0;
  }
  .thumbnails > li {
    float: none;
    margin-left: 0;
  }
  [class*="span"],
  .uneditable-input[class*="span"],
  .row-fluid [class*="span"] {
    float: none;
    display: block;
    width: 100%;
    margin-left: 0;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
  }
  .span12,
  .row-fluid .span12 {
    width: 100%;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
  }
  .row-fluid [class*="offset"]:first-child {
    margin-left: 0;
  }
  .input-large,
  .input-xlarge,
  .input-xxlarge,
  input[class*="span"],
  select[class*="span"],
  textarea[class*="span"],
  .uneditable-input {
    display: block;
    width: 100%;
    min-height: 30px;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
  }
  .input-prepend input,
  .input-append input,
  .input-prepend input[class*="span"],
  .input-append input[class*="span"] {
    display: inline-block;
    width: auto;
  }
  .controls-row [class*="span"] + [class*="span"] {
    margin-left: 0;
  }
  .modal {
    position: fixed;
    top: 20px;
    left: 20px;
    right: 20px;
    width: auto;
    margin: 0;
  }
  .modal.fade {
    top: -100px;
  }
  .modal.fade.in {
    top: 20px;
  }
}
@media (max-width: 480px) {
  .nav-collapse {
    -webkit-transform: translate3d(0, 0, 0);
  }
  .page-header h1 small {
    display: block;
    line-height: 20px;
  }
  input[type="checkbox"],
  input[type="radio"] {
    border: 1px solid #ccc;
  }
  .form-horizontal .control-label {
    float: none;
    width: auto;
    padding-top: 0;
    text-align: left;
  }
  .form-horizontal .controls {
    margin-left: 0;
  }
  .form-horizontal .control-list {
    padding-top: 0;
  }
  .form-horizontal .form-actions {
    padding-left: 10px;
    padding-right: 10px;
  }
  .media .pull-left,
  .media .pull-right {
    float: none;
    display: block;
    margin-bottom: 10px;
  }
  .media-object {
    margin-right: 0;
    margin-left: 0;
  }
  .modal {
    top: 10px;
    left: 10px;
    right: 10px;
  }
  .modal-header .close {
    padding: 10px;
    margin: -10px;
  }
  .carousel-caption {
    position: static;
  }
}
@media (max-width: 979px) {
  body {
    padding-top: 0;
  }
  .navbar-fixed-top,
  .navbar-fixed-bottom {
    position: static;
  }
  .navbar-fixed-top {
    margin-bottom: 20px;
  }
  .navbar-fixed-bottom {
    margin-top: 20px;
  }
  .navbar-fixed-top .navbar-inner,
  .navbar-fixed-bottom .navbar-inner {
    padding: 5px;
  }
  .navbar .container {
    width: auto;
    padding: 0;
  }
  .navbar .brand {
    padding-left: 10px;
    padding-right: 10px;
    margin: 0 0 0 -5px;
  }
  .nav-collapse {
    clear: both;
  }
  .nav-collapse .nav {
    float: none;
    margin: 0 0 10px;
  }
  .nav-collapse .nav > li {
    float: none;
  }
  .nav-collapse .nav > li > a {
    margin-bottom: 2px;
  }
  .nav-collapse .nav > .divider-vertical {
    display: none;
  }
  .nav-collapse .nav .nav-header {
    color: #777777;
    text-shadow: none;
  }
  .nav-collapse .nav > li > a,
  .nav-collapse .dropdown-menu a {
    padding: 9px 15px;
    font-weight: bold;
    color: #777777;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
  }
  .nav-collapse .btn {
    padding: 4px 10px 4px;
    font-weight: normal;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
  }
  .nav-collapse .dropdown-menu li + li a {
    margin-bottom: 2px;
  }
  .nav-collapse .nav > li > a:hover,
  .nav-collapse .nav > li > a:focus,
  .nav-collapse .dropdown-menu a:hover,
  .nav-collapse .dropdown-menu a:focus {
    background-color: #f2f2f2;
  }
  .navbar-inverse .nav-collapse .nav > li > a,
  .navbar-inverse .nav-collapse .dropdown-menu a {
    color: #999999;
  }
  .navbar-inverse .nav-collapse .nav > li > a:hover,
  .navbar-inverse .nav-collapse .nav > li > a:focus,
  .navbar-inverse .nav-collapse .dropdown-menu a:hover,
  .navbar-inverse .nav-collapse .dropdown-menu a:focus {
    background-color: #111111;
  }
  .nav-collapse.in .btn-group {
    margin-top: 5px;
    padding: 0;
  }
  .nav-collapse .dropdown-menu {
    position: static;
    top: auto;
    left: auto;
    float: none;
    display: none;
    max-width: none;
    margin: 0 15px;
    padding: 0;
    background-color: transparent;
    border: none;
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    border-radius: 0;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
  }
  .nav-collapse .open > .dropdown-menu {
    display: block;
  }
  .nav-collapse .dropdown-menu:before,
  .nav-collapse .dropdown-menu:after {
    display: none;
  }
  .nav-collapse .dropdown-menu .divider {
    display: none;
  }
  .nav-collapse .nav > li > .dropdown-menu:before,
  .nav-collapse .nav > li > .dropdown-menu:after {
    display: none;
  }
  .nav-collapse .navbar-form,
  .nav-collapse .navbar-search {
    float: none;
    padding: 10px 15px;
    margin: 10px 0;
    border-top: 1px solid #f2f2f2;
    border-bottom: 1px solid #f2f2f2;
    -webkit-box-shadow: inset 0 1px 0 rgba(255,255,255,.1), 0 1px 0 rgba(255,255,255,.1);
    -moz-box-shadow: inset 0 1px 0 rgba(255,255,255,.1), 0 1px 0 rgba(255,255,255,.1);
    box-shadow: inset 0 1px 0 rgba(255,255,255,.1), 0 1px 0 rgba(255,255,255,.1);
  }
  .navbar-inverse .nav-collapse .navbar-form,
  .navbar-inverse .nav-collapse .navbar-search {
    border-top-color: #111111;
    border-bottom-color: #111111;
  }
  .navbar .nav-collapse .nav.pull-right {
    float: none;
    margin-left: 0;
  }
  .nav-collapse,
  .nav-collapse.collapse {
    overflow: hidden;
    height: 0;
  }
  .navbar .btn-navbar {
    display: block;
  }
  .navbar-static .navbar-inner {
    padding-left: 10px;
    padding-right: 10px;
  }
}
@media (min-width: 979px + 1) {
  .nav-collapse.collapse {
    height: auto !important;
    overflow: visible !important;
  }
}
.break-word {
  -ms-word-break: break-all;
  word-break: break-all;
  /* Non standard for webkit */
  word-break: break-word;
  -webkit-hyphens: auto;
  -moz-hyphens: auto;
  -ms-hyphens: auto;
  hyphens: auto;
}
.tag {
  display: inline-block;
  margin-bottom: 4px;
  color: #111111;
  background-color: #f6f6f6;
  padding: 1px 10px;
  border: 1px solid #dddddd;
  -webkit-border-radius: 100px;
  -moz-border-radius: 100px;
  border-radius: 100px;
  -webkit-box-shadow: inset 0 1px 0 #ffffff;
  -moz-box-shadow: inset 0 1px 0 #ffffff;
  box-shadow: inset 0 1px 0 #ffffff;
}
a.tag:hover {
  text-decoration: none;
  color: #fff;
  background-color: #ec66ab;
  border: 1px solid #e73892;
  -webkit-box-shadow: inset 0 1px 0 #f293c4;
  -moz-box-shadow: inset 0 1px 0 #f293c4;
  box-shadow: inset 0 1px 0 #f293c4;
}
.pill {
  display: inline-block;
  background-color: #6f8890;
  color: #ffffff;
  padding: 2px 10px 1px 10px;
  margin-right: 5px;
  font-weight: normal;
  -webkit-border-radius: 100px;
  -moz-border-radius: 100px;
  border-radius: 100px;
}
.pill a {
  color: #ffffff;
}
.pill a.remove {
  font-size: 11px;
}
.unstyled {
  margin: 0;
  list-style: none;
}
.simple-item {
  font-size: 12px;
  line-height: 1.16666667em;
  padding: 7px 25px;
  border-bottom: 1px dotted #dddddd;
}
.simple-item:last-of-type {
  border-bottom: 0;
}
.simple-list {
  *zoom: 1;
  margin: 0;
  list-style: none;
}
.simple-list:before,
.simple-list:after {
  display: table;
  content: "";
  line-height: 0;
}
.simple-list:after {
  clear: both;
}
.simple-list > li {
  font-size: 12px;
  line-height: 1.16666667em;
  padding: 7px 25px;
  border-bottom: 1px dotted #dddddd;
}
.simple-list > li:last-of-type {
  border-bottom: 0;
}
.simple-list .ckan-icon {
  position: relative;
  top: 0px;
}
.module-narrow .simple-list > li {
  padding-left: 15px;
  padding-right: 15px;
  position: relative;
}
.listing li {
  text-align: right;
  margin-bottom: 5px;
}
.listing .key {
  clear: right;
  font-weight: bold;
}
.js .tab-content {
  display: none;
}
.js .tab-content.active {
  display: block;
}
.box {
  background-color: #FFF;
  border: 1px solid #cccccc;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: 0 0 0 4px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: 0 0 0 4px rgba(0, 0, 0, 0.05);
  box-shadow: 0 0 0 4px rgba(0, 0, 0, 0.05);
}
.module {
  margin: 20px 0;
}
.module-heading {
  *zoom: 1;
  margin: 0;
  padding: 7px 25px;
  font-size: 14px;
  line-height: 1.3;
  background-color: #f6f6f6;
  border-top: 1px solid #dddddd;
  border-bottom: 1px solid #dddddd;
}
.module-heading:before,
.module-heading:after {
  display: table;
  content: "";
  line-height: 0;
}
.module-heading:after {
  clear: both;
}
.module-content {
  padding: 0 25px;
  margin: 20px 0;
}
@media (min-width: 768px) {
  .span9 div.module-content {
    padding-left: 10px;
  }
}
.module-content:first-child {
  margin-top: 0;
  padding-top: 20px;
}
.module-content:last-child {
  margin-bottom: 0;
  padding-bottom: 20px;
}
.module-content > :last-child {
  margin-bottom: 0;
}
.module:first-child .module-heading {
  -webkit-border-radius: 3px 0 0 0;
  -moz-border-radius: 3px 0 0 0;
  border-radius: 3px 0 0 0;
  border-top-width: 0;
}
.module:last-child {
  margin-bottom: 20px;
}
.module-footer {
  padding: 7px 25px 7px;
  margin: 0;
  border-top: 1px dotted #dddddd;
}
.module .read-more {
  font-weight: bold;
  color: #000000;
}
.module .pagination {
  height: 34px;
  margin-bottom: 0;
  border-top: 1px solid #dddddd;
}
.module-content .pagination {
  margin-left: -25px;
  margin-right: -25px;
  margin-bottom: -20px;
}
.module .pagination > ul {
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
  border: 0;
}
.module .pagination li a {
  border-top: none;
  border-bottom: none;
  padding-top: 7px;
  padding-bottom: 7px;
}
.module .pagination li:first-child a,
.module .pagination li:last-child a {
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.module .pagination li:first-child a {
  border-left-width: 0;
}
.module .pagination li:last-child a {
  border-right-width: 0;
}
.module .pagination li.active a {
  border-left-width: 1px;
  border-right-width: 1px;
}
.module-content-shallow {
  padding: 0;
  margin-top: 10px;
  padding-bottom: 10px;
}
.module h1 {
  margin-bottom: 20px;
}
.module-shallow .module-content {
  padding: 10px;
  margin: 0;
}
.module-shallow .module-tags {
  margin-top: 0;
  margin-bottom: 0;
}
.module-shallow .module-content:first-child {
  padding-top: 10px;
}
.module-shallow .module-content:last-child {
  padding-bottom: 10px;
}
.module-narrow .module-heading,
.module-narrow .module-content,
.module-narrow .module-footer {
  padding-left: 15px;
  padding-right: 15px;
}
.module-grid {
  margin: 0;
  list-style: none;
  *zoom: 1;
  margin: 0 -25px;
  padding-bottom: 15px;
  background: #fbfbfb url("../../../base/images/bg.png");
  border: 1px solid #dddddd;
  border-width: 1px 0;
}
.module-grid:before,
.module-grid:after {
  display: table;
  content: "";
  line-height: 0;
}
.module-grid:after {
  clear: both;
}
.module-item {
  width: 189px;
  padding: 15px;
  margin: 15px 0 0 15px;
  background-color: white;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  float: left;
  margin-left: 20px;
  width: 460px;
  padding-top: 10px;
  padding-bottom: 10px;
  padding-right: 50px;
  overflow: hidden;
  position: relative;
}
.module-item span.count {
  color: #999;
}
.module-item .media-image {
  margin-bottom: 5px;
}
.module-item .media-edit {
  opacity: 0;
  position: absolute;
  right: 15px;
  bottom: 15px;
  -webkit-transition: opacity 0.2s ease-in;
  -moz-transition: opacity 0.2s ease-in;
  -o-transition: opacity 0.2s ease-in;
  transition: opacity 0.2s ease-in;
}
.module-item:hover {
  z-index: 1;
}
.module-item:hover .media-edit {
  opacity: 1;
}
.module-item.first {
  clear: left;
}
.group .content img {
  margin: 0 -5px 5px;
  max-width: initial;
}
.group .content h3 {
  font-size: 14px;
  line-height: 1.3;
}
.group-listing {
  margin-left: -20px;
}
.ckanext-datapreview {
  position: relative;
  clear: both;
  padding-top: 15px;
  margin-top: 0;
}
.ckanext-datapreview > iframe {
  min-height: 400px;
}
.ckanext-datapreview > img {
  max-height: 500px;
  max-width: 100%;
  overflow: hidden;
}
.package-info h4 {
  margin-bottom: 10px;
}
.module-resource {
  background-color: #ffffff;
  border-bottom: 1px solid #dddddd;
  margin-top: 0;
  margin-bottom: 0;
  -webkit-border-radius: 3px 3px 0 0;
  -moz-border-radius: 3px 3px 0 0;
  border-radius: 3px 3px 0 0;
}
.module-resource .actions {
  position: relative;
  float: right;
  top: -10px;
  right: -15px;
}
.module .module-tags {
  padding-bottom: 8px;
}
.secondary .module:first-child,
.primary .module:first-child {
  margin-top: 0;
}
.no-nav .module:last-child {
  margin-top: 0;
}
.module-image {
  float: left;
  width: 50px;
  height: 50px;
  line-height: 50px;
  text-align: center;
  margin-right: 15px;
}
.module-image img {
  max-width: 50px;
  max-height: 50px;
  vertical-align: middle;
}
.banner {
  -webkit-transform: rotate(45deg);
  -moz-transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  -o-transform: rotate(45deg);
  transform: rotate(45deg);
  -webkit-transform-origin: center center;
  -moz-transform-origin: center center;
  -ms-transform-origin: center center;
  -o-transform-origin: center center;
  transform-origin: center center;
  position: absolute;
  top: 15px;
  right: -35px;
  width: 80px;
  color: #ffffff;
  background-color: #e73892;
  padding: 1px 20px;
  font-size: 11px;
  text-align: center;
  text-transform: uppercase;
}
.media-grid {
  margin: 0;
  list-style: none;
  *zoom: 1;
  margin: 0 -25px;
  padding-bottom: 15px;
  background: #fbfbfb url("../../../base/images/bg.png");
  border: 1px solid #dddddd;
  border-width: 1px 0;
}
.media-grid:before,
.media-grid:after {
  display: table;
  content: "";
  line-height: 0;
}
.media-grid:after {
  clear: both;
}
@media (min-width: 768px) {
  .media-grid {
    margin-left: -27px;
  }
}
.media-item {
  position: relative;
  float: left;
  width: 189px;
  padding: 15px;
  margin: 15px 0 0 15px;
  background-color: white;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.media-item span.count {
  color: #999;
}
.media-item .media-image {
  margin-bottom: 5px;
}
.media-item .media-edit {
  opacity: 0;
  position: absolute;
  right: 15px;
  bottom: 15px;
  -webkit-transition: opacity 0.2s ease-in;
  -moz-transition: opacity 0.2s ease-in;
  -o-transition: opacity 0.2s ease-in;
  transition: opacity 0.2s ease-in;
}
.media-item:hover {
  z-index: 1;
}
.media-item:hover .media-edit {
  opacity: 1;
}
.media-view {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  border: 1px solid #dddddd;
  overflow: hidden;
  -webkit-transition: all 0.2s ease-in;
  -moz-transition: all 0.2s ease-in;
  -o-transition: all 0.2s ease-in;
  transition: all 0.2s ease-in;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.media-view:hover,
.media-view.hovered {
  border-color: #e73892;
  -webkit-box-shadow: 0 0 0 4px rgba(0, 0, 0, 0.1);
  -moz-box-shadow: 0 0 0 4px rgba(0, 0, 0, 0.1);
  box-shadow: 0 0 0 4px rgba(0, 0, 0, 0.1);
}
.media-view:hover .banner,
.media-view.hovered .banner {
  background-color: #e73892;
}
.media-view span {
  display: none;
}
.media-view .banner {
  display: block;
  background-color: #b7b7b7;
  -webkit-transition: background-color 0.2s ease-in;
  -moz-transition: background-color 0.2s ease-in;
  -o-transition: background-color 0.2s ease-in;
  transition: background-color 0.2s ease-in;
}
.media-image {
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.media-heading {
  font-size: 18px;
  line-height: 1.3;
  margin: 5px 0;
  -ms-word-break: break-all;
  word-break: break-all;
  /* Non standard for webkit */
  word-break: break-word;
  -webkit-hyphens: auto;
  -moz-hyphens: auto;
  -ms-hyphens: auto;
  hyphens: auto;
}
.media-overlay {
  position: relative;
  min-height: 35px;
}
.media-overlay .media-heading {
  position: absolute;
  left: 0;
  right: 0;
  bottom: 0;
  padding: 12px 10px;
  margin: 0;
  background-color: #000;
  background-color: rgba(0, 0, 0, 0.8);
  font-size: 13px;
  color: #fff;
  z-index: 1;
  -webkit-border-radius: 0 0 3px 3px;
  -moz-border-radius: 0 0 3px 3px;
  border-radius: 0 0 3px 3px;
}
.media-overlay .media-image {
  float: none;
  display: block;
  margin-right: 0;
}
.media-item.is-expander .truncator-link {
  -webkit-transition: opacity 0.2s ease-in;
  -moz-transition: opacity 0.2s ease-in;
  -o-transition: opacity 0.2s ease-in;
  transition: opacity 0.2s ease-in;
  position: absolute;
  z-index: 10;
  left: 15px;
  bottom: 15px;
  opacity: 0;
}
.media-item.is-expander:hover {
  padding-bottom: 35px;
}
.media-item.is-expander:hover .truncator-link {
  opacity: 1;
}
.wide .media-item {
  width: 186px;
}
.nav-simple,
.nav-aside {
  *zoom: 1;
  margin: 0;
  list-style: none;
  padding-bottom: 0;
}
.nav-simple:before,
.nav-aside:before,
.nav-simple:after,
.nav-aside:after {
  display: table;
  content: "";
  line-height: 0;
}
.nav-simple:after,
.nav-aside:after {
  clear: both;
}
.nav-simple > li,
.nav-aside > li {
  font-size: 12px;
  line-height: 1.16666667em;
  padding: 7px 25px;
  border-bottom: 1px dotted #dddddd;
}
.nav-simple > li:last-of-type,
.nav-aside > li:last-of-type {
  border-bottom: 0;
}
.nav-simple .ckan-icon,
.nav-aside .ckan-icon {
  position: relative;
  top: 0px;
}
.nav-aside {
  border-top: 1px dotted #DDD;
  border-bottom: 1px dotted #DDD;
  margin-bottom: 15px;
}
.nav-item > a,
.nav-aside li a {
  color: #333333;
  font-size: 14px;
  line-height: 20px;
  margin: -7px -25px;
  padding: 7px 25px;
}
.nav-item.active,
.nav-aside li.active {
  background-color: #f6f6f6;
}
.nav-item.active > a,
.nav-aside li.active a {
  position: relative;
  color: #ffffff;
  background-color: #8ca0a6;
}
.nav-item.active > a:hover,
.nav-aside li.active a:hover {
  color: #ffffff;
  background-color: #8ca0a6;
}
@media (min-width: 768px) {
  .nav-item.active > a:before,
  .nav-aside li.active a:before {
    content: ' ';
    position: absolute;
    top: 0;
    right: -6px;
    width: 6px;
    height: 34px;
    background-image: url("../../../base/images/nav-active.png?1");
  }
}
.nav-item.active > a span,
.nav-aside li.active a span {
  white-space: nowrap;
  overflow: hidden;
  display: block;
}
.module-narrow .nav-item > a,
.module-narrow .nav-aside li a {
  padding-left: 15px;
  padding-right: 15px;
  position: relative;
}
.module-narrow .nav-item.image,
.module-narrow .nav-aside li.image {
  position: relative;
}
.module-narrow .nav-item.image > a,
.module-narrow .nav-aside li.image a {
  padding-left: 42px;
  padding-right: 42px;
}
.module-narrow .nav-item.image > img,
.module-narrow .nav-aside li.image img {
  position: absolute;
  top: 50%;
  left: 15px;
  width: 20px;
  height: 20px;
  margin-top: -10px;
  z-index: 2;
}
.nav-facet .nav-item > a:hover:after,
.nav-facet .nav-item.active > a:after {
  *margin-right: .3em;
  display: inline-block;
  vertical-align: text-bottom;
  position: relative;
  top: 2px;
  width: 16px;
  height: 16px;
  background-image: url("../../../base/images/sprite-ckan-icons.png");
  background-repeat: no-repeat;
  background-position: 16px 16px;
  content: "";
  position: absolute;
  top: 50%;
  right: 5px;
  margin-top: -8px;
}
.nav-facet .nav-item > a:hover:after {
  width: 17px;
  height: 17px;
  background-position: -17px -16px;
}
.nav-facet .nav-item.active > a:after {
  width: 17px;
  height: 17px;
  background-position: 0px -16px;
  right: 3px;
}
.user-list {
  margin: 0;
  list-style: none;
}
.user-list li {
  margin: 0 0 10px 0;
}
.user-list .gravatar {
  vertical-align: -4px;
  margin-right: 3px;
  -webkit-border-radius: 100px;
  -moz-border-radius: 100px;
  border-radius: 100px;
}
.nav-facet-tertiary {
  margin: 10px 0;
}
.nav-facet-tertiary .module-heading {
  margin-bottom: 5px;
  padding: 8px 12px;
  border-bottom-width: 0;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
}
.nav-facet-tertiary .module-heading i {
  display: none;
}
.nav-facet-tertiary .module-footer {
  padding: 8px 12px;
  border-top-width: 0;
}
.nav-facet-tertiary .module-footer a {
  font-weight: normal;
  color: #8C8C8C;
}
.nav-facet-tertiary .nav {
  margin-bottom: 0;
}
.nav-facet-tertiary .module-content.empty {
  padding: 8px 12px;
  margin-top: 0;
}
.nav-facet-tertiary .nav li.active {
  position: relative;
}
.nav-facet-tertiary .nav li.active > a:hover:after,
.nav-facet-tertiary .nav li.active > a:after {
  *margin-right: .3em;
  display: inline-block;
  vertical-align: text-bottom;
  position: relative;
  top: 2px;
  width: 16px;
  height: 16px;
  background-image: url("../../../base/images/sprite-ckan-icons.png");
  background-repeat: no-repeat;
  background-position: 16px 16px;
  width: 17px;
  height: 17px;
  background-position: 0px -16px;
  content: "";
  position: absolute;
  top: 50%;
  right: 5px;
  margin-top: -8px;
}
.nav-simple > .nav-btn {
  padding-left: 0;
  padding-right: 0;
  text-align: center;
}
.nav-simple > .nav-btn .btn {
  display: inline-block;
}
.js .js-hide {
  display: none;
}
.js .js-hide.active {
  display: block;
}
.btn,
label {
  font-weight: bold;
}
.btn-rounded {
  -webkit-border-radius: 100px;
  -moz-border-radius: 100px;
  border-radius: 100px;
  padding-left: 15px;
  padding-right: 15px;
}
label {
  cursor: pointer;
  font-size: 14px;
}
label:after {
  content: ":";
}
label.radio:after,
label.checkbox:after {
  content: "";
}
input[type=radio],
input[type=checkbox] {
  position: relative;
  top: 7px;
  padding: 0;
  margin: 0;
}
input[type=radio].checkbox-onown,
input[type=checkbox].checkbox-onown {
  top: 0;
}
select {
  padding: 4px;
}
textarea {
  max-width: 100%;
}
.control-group .btn {
  position: relative;
  top: -2px;
}
.control-full input,
.control-full select,
.control-full textarea {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  height: auto;
  width: 100%;
}
.control-medium input,
.control-medium select,
.control-medium textarea {
  width: 320px;
}
@media (max-width: 768px) {
  .control-medium input,
  .control-medium select,
  .control-medium textarea {
    width: 100%;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    min-height: 28px;
  }
}
.control-large input,
.control-large .control-label {
  font-size: 17.5px;
  line-height: 30px;
}
.control-large input {
  height: 41px;
}
.control-required {
  color: #c6898b;
}
.form-actions .control-required-message {
  float: left;
  margin-left: 20px;
  margin-bottom: 0;
  line-height: 30px;
}
.form-actions .control-required-message:first-child {
  margin-left: 0;
}
.form-actions {
  background: none;
  margin-left: -25px;
  margin-right: -25px;
  margin-bottom: 0;
  padding-bottom: 0;
}
@media (min-width: 768px) {
  .form-actions {
    text-align: right;
  }
}
.form-actions .action-info {
  line-height: 2;
  text-align: left;
  color: #707070;
  margin: 0;
}
@media (min-width: 768px) {
  .form-actions .action-info {
    float: left;
    width: 50%;
  }
}
.form-actions .action-info.small {
  font-size: 11px;
  line-height: 1.2;
}
@media (max-width: 768px) {
  .form-actions .btn {
    margin-top: 5px;
  }
}
.form-horizontal .control-label {
  width: 120px;
}
@media (min-width: 768px) {
  .form-horizontal .controls {
    margin-left: 130px;
  }
}
.form-horizontal .info-block {
  position: relative;
  display: block;
  font-size: 11px;
  color: #aaaaaa;
  line-height: 1.3;
  margin-top: 6px;
}
.form-horizontal .info-help {
  padding: 6px 0;
}
.form-horizontal .info-help:before {
  display: none;
}
.form-horizontal .info-help-tight {
  margin-top: -10px;
}
@media (min-width: 980px) {
  .form-horizontal .info-block {
    padding: 6px 0 6px 25px;
  }
  .form-horizontal .info-inline {
    float: right;
    width: 265px;
    margin-top: 0;
    padding-bottom: 0;
  }
}
.form-horizontal .control-medium .info-block.info-inline {
  width: 165px;
}
.form-horizontal .info-block:before {
  font-size: 2.2em;
  position: absolute;
  left: 0;
  top: 2px;
}
.form-horizontal .info-inline:before {
  top: 8px;
}
.info-block .icon-large,
.info-inline .icon-large {
  float: left;
  font-size: 22px;
  margin-right: 15px;
}
.form-horizontal .info-block a {
  color: #aaaaaa;
  text-decoration: underline;
}
.form-horizontal .form-actions {
  padding-left: 25px;
  padding-right: 25px;
}
.form-inline input {
  padding-bottom: 9px;
}
.form-inline select {
  margin-top: 0;
}
.form-inline .btn {
  margin-left: 5px;
}
.form-narrow label {
  margin-bottom: 0;
}
.form-narrow select {
  width: 100%;
}
.form-narrow .form-actions {
  margin-left: -15px;
  margin-right: -15px;
  padding: 10px 15px 0;
}
.form-select label {
  margin-right: 5px;
}
.simple-input label,
.simple-input button {
  display: none;
}
.simple-input .field {
  position: relative;
}
.simple-input .field-bordered {
  border-bottom: 1px dotted #dddddd;
}
.simple-input .field input {
  width: 100%;
  height: auto;
  margin: 0 -7px;
  padding: 7px 5px;
}
.simple-input .field .btn-search {
  position: absolute;
  display: block;
  height: 17px;
  width: 17px;
  padding: 0;
  top: 50%;
  right: 0;
  margin-top: -10px;
  background-color: transparent;
  border: none;
  color: #999;
  -webkit-transition: color 0.2s ease-in;
  -moz-transition: color 0.2s ease-in;
  -o-transition: color 0.2s ease-in;
  transition: color 0.2s ease-in;
}
.simple-input .field .btn-search:hover {
  color: #000;
}
.editor textarea {
  -webkit-border-radius: 3px 3px 0 0;
  -moz-border-radius: 3px 3px 0 0;
  border-radius: 3px 3px 0 0;
  border-bottom: none;
}
.editor .editor-info-block {
  -webkit-border-radius: 0 0 3px 3px;
  -moz-border-radius: 0 0 3px 3px;
  border-radius: 0 0 3px 3px;
  display: block;
  float: none;
  padding: 4px 10px;
  background: #ebebeb;
  width: auto;
  border: 1px solid #cccccc;
  border-top: none;
  font-size: 11px;
  color: #282828;
}
.editor .editor-info-block a {
  color: #e73892;
  text-decoration: none;
}
@media (max-width: 768px) {
  [data-module="custom-fields"] .input-prepend .add-on {
    display: block;
  }
}
@media (max-width: 480px) {
  [data-module="custom-fields"] .input-prepend {
    width: 100%;
  }
  [data-module="custom-fields"] .control-custom input {
    width: 100%;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    min-height: 28px;
  }
}
.control-custom {
  font-size: 0;
}
.control-custom label {
  margin-bottom: 0;
}
.control-custom input {
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
  width: 140px;
}
.control-custom input:last-of-type {
  -webkit-border-radius: 0 3px 3px 0;
  -moz-border-radius: 0 3px 3px 0;
  border-radius: 0 3px 3px 0;
}
.control-custom .checkbox {
  display: inline-block;
  margin-left: 5px;
}
.control-custom .checkbox input {
  width: auto;
}
.control-custom.disabled label,
.control-custom.disabled input {
  color: #aaaaaa;
  text-decoration: line-through;
  text-shadow: none;
}
.control-custom.disabled input {
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
  background-color: #f3f3f3;
}
.control-custom.disabled .checkbox {
  color: #444444;
  text-decoration: none;
}
.control-custom .checkbox.btn {
  -webkit-border-radius: 15px;
  -moz-border-radius: 15px;
  border-radius: 15px;
  position: relative;
  top: 0;
  left: 5px;
  height: 1px;
  width: 9px;
  padding: 3px 8px;
  line-height: 18px;
}
.control-custom .checkbox.btn span {
  display: none;
  width: 30px;
}
.control-custom .checkbox.btn:before {
  position: relative;
  top: 1px;
  left: -1px;
  color: #fff;
}
.control-custom .checkbox.btn input {
  display: none;
}
.control-custom.disabled .checkbox.btn {
  color: #ffffff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #ea53a1;
  background-image: -moz-linear-gradient(top, #ec66ab, #e73892);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ec66ab), to(#e73892));
  background-image: -webkit-linear-gradient(top, #ec66ab, #e73892);
  background-image: -o-linear-gradient(top, #ec66ab, #e73892);
  background-image: linear-gradient(to bottom, #ec66ab, #e73892);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffec66ab', endColorstr='#ffe73892', GradientType=0);
  border-color: #e73892 #e73892 #bc176c;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  *background-color: #e73892;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}
.control-custom.disabled .checkbox.btn:hover,
.control-custom.disabled .checkbox.btn:focus,
.control-custom.disabled .checkbox.btn:active,
.control-custom.disabled .checkbox.btn.active,
.control-custom.disabled .checkbox.btn.disabled,
.control-custom.disabled .checkbox.btn[disabled] {
  color: #ffffff;
  background-color: #e73892;
  *background-color: #e42186;
}
.control-custom.disabled .checkbox.btn:active,
.control-custom.disabled .checkbox.btn.active {
  background-color: #d31979 \9;
}
.control-custom.disabled .checkbox.btn .caret {
  border-top-color: #ffffff;
  border-bottom-color: #ffffff;
}
.alert-danger a,
.alert-error a {
  color: #b55457;
}
.control-group.error input,
.control-group.error select,
.control-group.error textarea,
.control-group.error .input-prepend .add-on,
.control-group.error .input-append .add-on {
  border-color: #c6898b;
}
.error-inline {
  color: #b55457;
}
.error-block,
.error-inline {
  font-size: 12px;
}
.error-block {
  -webkit-border-radius: 0 0 3px 3px;
  -moz-border-radius: 0 0 3px 3px;
  border-radius: 0 0 3px 3px;
  display: block;
  padding: 6px 8px 3px;
  background: #c6898b;
  margin: -3px 0 0;
  color: #ffffff;
  width: 208px;
}
.control-medium .error-block {
  width: 318px;
}
.control-full .error-block {
  width: auto;
}
.control-group.error .input-prepend .error-block,
.control-custom.error .error-block {
  width: auto;
}
.control-custom.error .error-block {
  width: 401px;
}
.control-select.error .error-block {
  width: 196px;
}
.stages {
  margin: 0;
  list-style: none;
  *zoom: 1;
  color: #aeaeae;
  counter-reset: stage;
  margin: -20px -25px 20px;
  overflow: hidden;
}
.stages:before,
.stages:after {
  display: table;
  content: "";
  line-height: 0;
}
.stages:after {
  clear: both;
}
.stages li {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  line-height: 27px;
  counter-increment: stage;
  width: 50%;
  background-color: #ededed;
  float: left;
  padding: 10px 20px;
  position: relative;
  z-index: 0;
}
.stages li:before {
  -webkit-border-radius: 14px;
  -moz-border-radius: 14px;
  border-radius: 14px;
  content: counter(stage);
  display: inline-block;
  width: 27px;
  height: 27px;
  margin-right: 5px;
  font-weight: bold;
  text-align: center;
  color: #ffffff;
  background-color: #aeaeae;
  z-index: 1;
}
.stages li:after {
  left: 0;
  border: solid rgba(237, 237, 237, 0);
  content: " ";
  height: 0;
  width: 0;
  position: absolute;
  pointer-events: none;
  border-top-color: #ededed;
  border-bottom-color: #ededed;
  border-width: 29px;
  top: 50%;
  margin-top: -29px;
  margin-left: -30px;
}
.stages li.last {
  position: relative;
  right: -1px;
}
.stages li.last,
.stages li.last .highlight {
  -webkit-border-radius: 0 3px 0 0;
  -moz-border-radius: 0 3px 0 0;
  border-radius: 0 3px 0 0;
}
.stages li.first:after {
  content: none;
  border: none;
}
.stages li.active:after {
  border-color: rgba(140, 198, 138, 0);
  border-top-color: #8cc68a;
  border-bottom-color: #8cc68a;
}
.stages li.complete:after {
  border-color: rgba(197, 226, 196, 0);
  border-top-color: #c5e2c4;
  border-bottom-color: #c5e2c4;
}
.stages.stage-3 li.complete:first-child:after {
  content: none;
}
.stages li.active,
.stages li.complete {
  background: none;
}
.stages li.active:before {
  color: #8cc68a;
  background: #ffffff;
}
.stages li.complete:before {
  color: #c5e2c4;
  background: #eef6ed;
}
.stages li .highlight {
  display: block;
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  width: 100%;
  padding: 10px 52px;
  border: none;
  text-align: left;
  text-decoration: none;
  line-height: 27px;
  z-index: -1;
}
@media (max-width: 768px) {
  .stages li .highlight {
    text-indent: -9999px;
  }
}
.stages li.active .highlight {
  color: #ffffff;
  background: #8cc68a;
}
.stages li.complete .highlight {
  color: #eef6ed;
  background: #c5e2c4;
}
.alert > :last-child {
  margin-bottom: 0;
}
.slug-preview {
  font-size: 14px;
  line-height: 1.5;
  margin-top: 5px;
  margin-left: 10px;
}
.slug-preview-value {
  background-color: #faedcf;
  margin-right: 3px;
}
.resource-upload-field {
  position: relative;
  overflow: hidden;
  display: inline-block;
  vertical-align: bottom;
}
.resource-upload-field label {
  z-index: 0;
}
.resource-upload-field input {
  opacity: 0;
  filter: alpha(opacity=0);
  position: absolute;
  top: 0;
  right: 0;
  z-index: 1;
  margin: 0;
  border: solid transparent;
  border-width: 100px 0 0 200px;
  cursor: pointer;
  direction: ltr;
  -moz-transform: translate(-300px, 0) scale(4);
}
.resource-upload-field.loading {
  display: inline-block;
  background: url("../../../base/images/loading-spinner.gif") no-repeat center right;
  padding-right: 5px;
}
.select2-container .select2-choice input,
.select2-container-multi .select2-choices .select2-search-field:first-child input {
  font-size: 14px;
}
.select2-container-multi .select2-choices .select2-search-field input {
  height: 29px;
}
.select2-container .select2-choice input,
.select2-container-multi .select2-choices .select2-search-field:first-child input {
  padding-left: 10px;
}
.select2-container {
  margin-top: 1px;
}
.select2-container-multi {
  margin-top: 0;
}
.select2-container-multi .select2-choices .select2-search-choice {
  padding: 5px 8px 5px 22px;
}
.select2-container-multi.select2-container .select2-choices {
  padding-top: 3px;
  padding-bottom: 3px;
}
.select2-search-choice-close,
.select2-container-multi .select2-search-choice-close {
  top: 6px;
  left: 5px;
}
.select2-container-multi .select2-choices {
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -webkit-transition: border linear 0.2s, box-shadow linear 0.2s;
  -moz-transition: border linear 0.2s, box-shadow linear 0.2s;
  -o-transition: border linear 0.2s, box-shadow linear 0.2s;
  transition: border linear 0.2s, box-shadow linear 0.2s;
  background-color: #ffffff;
  border: 1px solid #cccccc;
}
.select2-container-active .select2-choices,
.select2-container-multi.select2-container-active .select2-choices {
  border-color: rgba(82, 168, 236, 0.8);
  outline: 0;
  outline: thin dotted \9;
  /* IE6-9 */
  -webkit-box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(82,168,236,.6);
  -moz-box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(82,168,236,.6);
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(82,168,236,.6);
}
.select2-container-multi .select2-drop {
  margin-top: -2px;
}
.select2-container .select2-results li {
  line-height: 18px;
  padding-top: 4px;
  padding-bottom: 4px;
}
.control-full .select2-container {
  max-width: 100%;
}
.control-group.error .select2-container input:focus,
.control-group.error .select2-container select:focus,
.control-group.error .select2-container textarea:focus {
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
}
.js .image-upload #field-image-url {
  padding-right: 29px;
}
.js .image-upload #field-image-upload {
  cursor: pointer;
  position: absolute;
  z-index: 1;
  opacity: 0;
  filter: alpha(opacity=0);
}
.js .image-upload .controls {
  position: relative;
}
.js .image-upload .btn {
  position: relative;
  top: 0;
  margin-right: 10px;
}
.js .image-upload .btn.hover {
  color: #333333;
  text-decoration: none;
  background-position: 0 -15px;
  -webkit-transition: background-position 0.1s linear;
  -moz-transition: background-position 0.1s linear;
  -o-transition: background-position 0.1s linear;
  transition: background-position 0.1s linear;
}
.js .image-upload .btn-remove-url {
  position: absolute;
  margin-right: 0;
  top: 4px;
  right: 5px;
  padding: 0 4px;
  -webkit-border-radius: 100px;
  -moz-border-radius: 100px;
  border-radius: 100px;
}
.js .image-upload .btn-remove-url .icon-remove {
  margin-right: 0;
}
.add-member-form .control-label {
  width: 100%;
  text-align: left;
}
.add-member-form .controls {
  margin-left: auto;
}
.add-member-or {
  float: left;
  margin-top: 75px;
  width: 7%;
  text-align: center;
  text-transform: uppercase;
  color: #999999;
  font-weight: bold;
}
.add-member-form .row-fluid .control-group {
  float: left;
  width: 45%;
}
.add-member-form .row-fluid .select2-container,
.add-member-form .row-fluid input {
  width: 100% !important;
}
#recaptcha_table {
  table-layout: inherit;
  line-height: 1;
}
.dataset-item {
  border-bottom: 1px dotted #dddddd;
  padding-bottom: 20px;
  margin-bottom: 20px;
}
@media (max-width: 768px) {
  .dataset-item {
    word-wrap: break-word;
  }
}
.dataset-item:last-of-type {
  border-bottom: none;
  margin-bottom: 0;
  padding-bottom: 0;
}
.dataset-heading {
  font-size: 16px;
  margin-top: 0;
  margin-bottom: 8px;
  line-height: 1.3;
}
.dataset-heading a {
  color: #333333;
}
.dataset-heading .label {
  position: relative;
  top: -1px;
}
.dataset-private {
  margin-right: 10px;
  text-transform: uppercase;
}
.dataset-private .icon-lock {
  width: 9px;
}
.dataset-private.pull-right {
  margin-right: 0;
}
.dataset-resources {
  margin-top: 8px;
}
.dataset-resources li {
  display: inline;
}
.dataset-resources li a {
  background-color: #aaaaaa;
}
.dataset-heading .popular {
  top: 0;
}
.resource-list {
  margin: 0;
  list-style: none;
  margin: -10px -10px 10px -10px;
}
.resource-item {
  position: relative;
  padding: 10px 10px 10px 60px;
  margin-bottom: 0px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.resource-item:hover {
  background-color: #eeeeee;
}
.resource-item .heading {
  color: #000000;
  font-size: 14px;
  font-weight: bold;
}
.resource-item .format-label {
  position: absolute;
  top: 10px;
  left: 10px;
}
.resource-item .description {
  font-size: 12px;
  margin-bottom: 0;
  min-height: 12px;
}
.resource-item .btn-group {
  position: absolute;
  top: 14px;
  right: 10px;
}
@media (max-width: 768px) {
  .resource-item .btn-group {
    display: none;
  }
}
.resource-list.reordering .resource-item {
  border: 1px solid #dddddd;
  margin-bottom: 10px;
  cursor: move;
}
.resource-list.reordering .resource-item .handle {
  display: block;
  position: absolute;
  color: #888888;
  left: -31px;
  top: 50%;
  margin-top: -15px;
  width: 30px;
  height: 30px;
  line-height: 30px;
  text-align: center;
  border: 1px solid #dddddd;
  border-width: 1px 0 1px 1px;
  background-color: #ffffff;
  -webkit-border-radius: 20px 0 0 20px;
  -moz-border-radius: 20px 0 0 20px;
  border-radius: 20px 0 0 20px;
}
.resource-list.reordering .resource-item .handle:hover {
  text-decoration: none;
}
.resource-list.reordering .resource-item:hover .handle {
  background-color: #eeeeee;
}
.resource-list.reordering .resource-item.ui-sortable-helper {
  background-color: #eeeeee;
  border: 1px solid #e73892;
}
.resource-list.reordering .resource-item.ui-sortable-helper .handle {
  background-color: #eeeeee;
  border-color: #e73892;
  color: #333333;
}
.resource-item .handle {
  display: none;
}
.tag-list {
  margin: 0;
  list-style: none;
  padding: 10px 10px 5px 10px;
}
.tag-list li {
  display: inline-block;
  margin-right: 5px;
}
.tag-list li:last-child {
  margin-right: 0;
}
.additional-info td,
.additional-info th {
  width: 50%;
}
.label[data-format=html],
.label[data-format*=html] {
  background-color: #55a1ce;
}
.label[data-format=json],
.label[data-format*=json] {
  background-color: #ef7100;
}
.label[data-format=xml],
.label[data-format*=xml] {
  background-color: #ef7100;
}
.label[data-format=text],
.label[data-format*=text] {
  background-color: #74cbec;
}
.label[data-format=csv],
.label[data-format*=csv] {
  background-color: #dfb100;
}
.label[data-format=xls],
.label[data-format*=xls] {
  background-color: #2db55d;
}
.label[data-format=zip],
.label[data-format*=zip] {
  background-color: #686868;
}
.label[data-format=api],
.label[data-format*=api] {
  background-color: #ec96be;
}
.label[data-format=pdf],
.label[data-format*=pdf] {
  background-color: #e0051e;
}
.label[data-format=rdf],
.label[data-format*=rdf],
.label[data-format*=nquad],
.label[data-format*=ntriples],
.label[data-format*=turtle] {
  background-color: #0b4498;
}
.view-list {
  margin: 0;
  list-style: none;
}
.view-list li {
  position: relative;
  margin-bottom: 10px;
}
.view-list li a {
  display: block;
  min-height: 50px;
  padding: 10px;
  border: 1px solid #dddddd;
  overflow: hidden;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.view-list li a .icon {
  float: left;
  width: 50px;
  height: 50px;
  overflow: hidden;
  margin-right: 10px;
  color: #444444;
  background-color: #eeeeee;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.view-list li a .icon i {
  display: block;
  text-align: center;
  font-size: 28px;
  line-height: 50px;
}
.view-list li a h3 {
  color: #000000;
  font-weight: bold;
  font-size: 16px;
  margin: 0 0 3px 0;
}
.view-list li a p {
  margin: 0;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  color: #444444;
}
.view-list li a.active,
.view-list li a:hover {
  text-decoration: none;
  border-color: #e73892;
}
.view-list li a.active .icon,
.view-list li a:hover .icon {
  background-color: #e73892;
  color: #f6f6f6;
}
.view-list li .arrow {
  position: absolute;
  display: none;
  border: 8px solid transparent;
  border-top-color: #e73892;
  left: 50%;
  bottom: -15px;
  margin-left: -4px;
}
.view-list li.active a {
  text-decoration: none;
  border-color: #e73892;
}
.view-list li.active a .icon {
  background-color: #e73892;
  color: #f6f6f6;
}
.view-list li.active .arrow {
  display: block;
}
.view-list.stacked {
  overflow-y: hidden;
  overflow-x: auto;
  height: 100px;
  white-space: nowrap;
}
.view-list.stacked li {
  display: inline-block;
  width: 250px;
  margin-right: 10px;
}
.view-list.stacked li:last-child {
  margin-right: 0;
}
.view-list.stacked::-webkit-scrollbar {
  width: 7px;
  height: 7px;
}
.view-list.stacked::-webkit-scrollbar-track {
  border-radius: 10px;
  background-color: #f6f6f6;
}
.view-list.stacked::-webkit-scrollbar-thumb {
  border-radius: 10px;
  background-color: #c3c3c3;
}
.view-list.stacked::-webkit-scrollbar-thumb:hover {
  background-color: #e73892;
}
.resource-view {
  margin-top: 20px;
}
.search-form {
  margin-bottom: 20px;
  padding-bottom: 25px;
  border-bottom: 1px dotted #dddddd;
}
.search-form .search-input {
  position: relative;
  margin-bottom: 20px;
}
.search-form .search-input input {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  margin: 0;
  width: 100%;
  height: auto;
}
.search-form .search-input button {
  cursor: pointer;
  display: block;
  position: absolute;
  top: 50%;
  margin-top: -10px;
  right: 10px;
  height: 20px;
  padding: 0;
  border: none;
  background: transparent;
}
.search-form .search-input button span {
  display: none;
}
.search-form .search-input button i {
  color: #cccccc;
  -webkit-transition: color 0.2s ease-in;
  -moz-transition: color 0.2s ease-in;
  -o-transition: color 0.2s ease-in;
  transition: color 0.2s ease-in;
}
.search-form .search-input button:hover i {
  color: #000000;
}
.search-form .search-input.search-giant input {
  font-size: 16px;
  padding: 15px;
}
.search-form .search-input.search-giant button {
  margin-top: -15px;
  right: 15px;
  height: 30px;
}
.search-form .search-input.search-giant button i {
  font-size: 28px;
  width: 28px;
}
.search-form .control-order-by label,
.search-form .control-order-by select {
  display: inline;
}
.search-form .control-order-by select {
  width: 160px;
  margin: 0;
}
.search-form h2 {
  font-size: 24px;
  line-height: 1.3;
  color: #000000;
  margin-bottom: 0;
  margin-top: 20px;
}
.search-form .filter-list {
  color: #444444;
  line-height: 32px;
  margin: 10px 0 0 0;
}
.search-form .filter-list .pill {
  line-height: 21px;
}
.search-form .filter-list .extra {
  margin-top: 10px;
  font-size: 18px;
  font-weight: normal;
  color: #000000;
}
.search-form.no-bottom-border {
  border-bottom-width: 0;
  margin-bottom: 0;
}
.tertiary .control-order-by {
  float: none;
  margin: 0;
}
.tertiary .control-order-by label {
  display: block;
  margin-bottom: 5px;
  font-weight: normal;
  font-size: 12px;
}
.tertiary .control-order-by select {
  display: block;
  font-size: 12px;
  width: 100%;
}
.tertiary .search-input {
  margin-bottom: 10px;
}
@media (min-width: 980px) {
  .search-form .control-order-by {
    float: right;
    margin-left: 15px;
  }
  .tertiary .search-form .control-order-by {
    float: none;
    margin: 0;
  }
}
.group .media-vertical .image {
  margin: 0 -5px 5px;
}
.group-list:nth-child(odd) {
  clear: left;
}
.group-list .module-heading {
  padding-top: 15px;
  padding-bottom: 15px;
}
.group-list .dataset-content {
  min-height: 54px;
}
.group-list .module-heading h3 {
  margin-bottom: 2px;
}
.group-list .module-heading h3 a {
  color: #333333;
}
.group-list .module-heading .media-image {
  overflow: hidden;
  max-height: 60px;
}
.group-list .module-heading .media-image img {
  max-width: 85px;
}
.toolbar {
  *zoom: 1;
  position: relative;
  margin-bottom: 10px;
  padding: 5px 0;
}
.toolbar:before,
.toolbar:after {
  display: table;
  content: "";
  line-height: 0;
}
.toolbar:after {
  clear: both;
}
.page_primary_action {
  margin-bottom: 20px;
}
.toolbar .breadcrumb {
  *zoom: 1;
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
  position: relative;
  float: left;
  margin: 0;
  padding: 0;
  border: none;
  background: none;
  font-size: 20px;
  line-height: 1.3;
}
.toolbar .breadcrumb:before,
.toolbar .breadcrumb:after {
  display: table;
  content: "";
  line-height: 0;
}
.toolbar .breadcrumb:after {
  clear: both;
}
.toolbar .breadcrumb li:after {
  content: " / ";
}
.toolbar .breadcrumb li.active:after {
  content: "";
}
.toolbar .breadcrumb li:last-of-type:after {
  content: "";
}
.toolbar .home a {
  text-decoration: none;
}
.toolbar .home span {
  display: none;
}
.toolbar .breadcrumb a {
  color: #505050;
}
@media (max-width: 767px) {
  .toolbar .breadcrumb {
    color: #fff;
    text-shadow: none;
  }
  .toolbar .breadcrumb .home {
    display: none;
  }
  .toolbar .breadcrumb a {
    color: #fff;
    text-shadow: none;
  }
}
.toolbar .breadcrumb .active a,
.toolbar .breadcrumb a.active {
  font-weight: bold;
}
.actions {
  margin: 0;
  list-style: none;
  position: absolute;
  top: 10px;
  right: 10px;
  z-index: 1;
}
.actions li {
  display: inline-block;
  margin-right: 5px;
  *display: inline;
  /* IE7 inline-block hack */
  *zoom: 1;
}
.actions li:last-of-type {
  margin-right: 0;
}
.hide-heading {
  display: none;
}
.page-header {
  *zoom: 1;
  border-bottom: 1px solid #dddddd;
  background-color: #f6f6f6;
  -webkit-border-radius: 0 3px 0 0;
  -moz-border-radius: 0 3px 0 0;
  border-radius: 0 3px 0 0;
}
.page-header:before,
.page-header:after {
  display: table;
  content: "";
  line-height: 0;
}
.page-header:after {
  clear: both;
}
.page-header .nav-tabs {
  float: left;
  margin-bottom: -1px;
}
.page-header .nav-tabs li.active a,
.page-header .nav-tabs a:hover {
  background-color: #ffffff;
}
.page-header .content_action {
  float: right;
  margin-top: -5px;
  margin-right: -7px;
}
.no-nav .page-header {
  -webkit-border-radius: 3px 3px 0 0;
  -moz-border-radius: 3px 3px 0 0;
  border-radius: 3px 3px 0 0;
}
.nav-tabs-plain {
  padding: 0 25px;
}
.nav-tabs-plain > .active > a,
.nav-tabs-plain > .active > a:hover {
  background-color: #ffffff;
}
@media (min-width: 768px) {
  .span9 .page-header {
    margin-left: -17px;
  }
}
@media (max-width: 768px) {
  .page-header .nav-tabs {
    margin: 5px 10px 10px -5px;
    border: none;
  }
  .page-header .nav-tabs > li {
    float: none;
  }
  .page-header .nav-tabs > li a {
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
  }
  .page-header .nav-tabs > .active > a,
  .page-header .nav-tabs > .active > a:hover,
  .page-header .nav-tabs > .active > a:focus {
    border-bottom-color: #dddddd;
  }
}
h1 {
  font-size: 28px;
}
h2 {
  font-size: 21px;
}
h3 {
  font-size: 18px;
}
h4 {
  font-size: 14px;
}
h1,
h2,
h3,
h4 {
  line-height: 1.5;
}
h1 small,
h2 small,
h3 small,
h4 small {
  font-size: 14px;
}
.prose h1,
.prose heading-1 h2,
.prose heading-2 {
  margin-bottom: 15px;
}
.prose h3,
.prose heading-3 {
  margin-bottom: 10px;
}
.table-chunky td,
.table-chunky th {
  padding: 12px 15px;
  font-size: 12px;
}
.table-chunky thead th,
.table-chunky thead td {
  color: #ffffff;
  background-color: #aaaaaa;
  padding-top: 10px;
  padding-bottom: 10px;
}
.table-striped tbody tr:nth-child(odd) td,
.table-striped tbody tr:nth-child(odd) th {
  background-color: transparent;
}
.table-striped tbody tr:nth-child(even) td,
.table-striped tbody tr:nth-child(even) th {
  background-color: #f2f2f2;
}
.table-chunky.table-bordered {
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  border-radius: 2px;
}
.table-chunky.table-bordered thead:first-child tr:first-child th:first-child,
.table-chunky.table-bordered tbody:first-child tr:first-child td:first-child {
  -webkit-border-top-left-radius: 2px;
  -moz-border-radius-topleft: 2px;
  border-top-left-radius: 2px;
}
.table-chunky.table-bordered thead:first-child tr:first-child th:last-child,
.table-chunky.table-bordered tbody:first-child tr:first-child td:last-child {
  -webkit-border-top-right-radius: 2px;
  -moz-border-radius-topright: 2px;
  border-top-right-radius: 2px;
}
.table-chunky.table-bordered thead:last-child tr:last-child th:first-child,
.table-chunky.table-bordered tbody:last-child tr:last-child td:first-child {
  -webkit-border-radius: 0 0 0 2px;
  -moz-border-radius: 0 0 0 2px;
  border-radius: 0 0 0 2px;
  -webkit-border-bottom-left-radius: 2px;
  -moz-border-radius-bottomleft: 2px;
  border-bottom-left-radius: 2px;
}
.table-chunky.table-bordered thead:last-child tr:last-child th:last-child,
.table-chunky.table-bordered tbody:last-child tr:last-child td:last-child {
  -webkit-border-bottom-right-radius: 2px;
  -moz-border-radius-bottomright: 2px;
  border-bottom-right-radius: 2px;
}
.ellipsis {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.ckan-icon {
  *margin-right: .3em;
  display: inline-block;
  vertical-align: text-bottom;
  position: relative;
  top: 2px;
  width: 16px;
  height: 16px;
  background-image: url("../../../base/images/sprite-ckan-icons.png");
  background-repeat: no-repeat;
  background-position: 16px 16px;
}
.ckan-icon-fb {
  width: 16px;
  height: 16px;
  background-position: 0px 0;
}
.ckan-icon-gplus {
  width: 16px;
  height: 16px;
  background-position: -16px 0;
}
.ckan-icon-twitter {
  width: 16px;
  height: 16px;
  background-position: -32px 0;
}
.ckan-icon-email {
  width: 16px;
  height: 16px;
  background-position: -48px 0;
}
.ckan-icon-share {
  width: 16px;
  height: 16px;
  background-position: -64px 0;
}
.ckan-icon-feed {
  width: 16px;
  height: 16px;
  background-position: -80px 0;
}
.ckan-icon-calendar {
  width: 16px;
  height: 16px;
  background-position: -96px 0;
}
.ckan-icon-file {
  width: 16px;
  height: 16px;
  background-position: -112px 0;
}
.ckan-icon-lock {
  width: 16px;
  height: 16px;
  background-position: -128px 0;
}
.ckan-icon-link-file {
  width: 16px;
  height: 16px;
  background-position: -144px 0;
}
.ckan-icon-link-plugin {
  width: 16px;
  height: 16px;
  background-position: -160px 0;
}
.ckan-icon-upload-file {
  width: 16px;
  height: 16px;
  background-position: -176px 0;
}
.ckan-icon-callout {
  width: 16px;
  height: 16px;
  background-position: -192px 0;
}
.ckan-icon-circle-cross {
  width: 17px;
  height: 17px;
  background-position: 0px -16px;
}
.ckan-icon-circle-add {
  width: 17px;
  height: 17px;
  background-position: -17px -16px;
}
.ckan-icon-flame {
  width: 17px;
  height: 17px;
  background-position: -34px -16px;
}
.ckan-icon-search {
  width: 17px;
  height: 17px;
  background-position: -51px -16px;
}
.ckan-icon-large-lock {
  width: 20px;
  height: 20px;
  background-position: 0px -33px;
}
.ckan-icon-photo {
  width: 20px;
  height: 20px;
  background-position: -20px -33px;
}
.ckan-icon-add {
  width: 20px;
  height: 20px;
  background-position: -40px -33px;
}
.ckan-icon-home {
  width: 20px;
  height: 20px;
  background-position: -60px -33px;
}
.ckan-icon-rewind {
  width: 20px;
  height: 20px;
  background-position: -80px -33px;
}
.ckan-icon-tools {
  width: 20px;
  height: 20px;
  background-position: -100px -33px;
}
.ckan-icon-flag {
  width: 20px;
  height: 20px;
  background-position: -120px -33px;
}
.ckan-icon-clipboard {
  width: 20px;
  height: 20px;
  background-position: -140px -33px;
}
.ckan-icon-share {
  width: 20px;
  height: 20px;
  background-position: -160px -33px;
}
.ckan-icon-info {
  width: 20px;
  height: 20px;
  background-position: -180px -33px;
}
.ckan-icon-download {
  width: 20px;
  height: 20px;
  background-position: -200px -33px;
}
.ckan-icon-star {
  width: 20px;
  height: 20px;
  background-position: -220px -33px;
}
.ckan-icon-info-flat {
  width: 20px;
  height: 20px;
  background-position: -240px -33px;
}
.ckan-icon-tag {
  width: 20px;
  height: 20px;
  background-position: -260px -33px;
}
.ckan-icon-plus {
  width: 20px;
  height: 20px;
  background-position: -280px -33px;
  width: 16px;
}
.ckan-icon-head {
  width: 20px;
  height: 20px;
  background-position: -300px -33px;
}
.ckan-icon-arrow-e {
  width: 20px;
  height: 20px;
  background-position: -320px -33px;
  width: 16px;
}
.ckan-icon-bookmark {
  width: 25px;
  height: 25px;
  background-position: 0px -53px;
}
.format-label {
  *margin-right: .3em;
  display: inline-block;
  vertical-align: text-bottom;
  position: relative;
  top: 2px;
  width: 16px;
  height: 16px;
  background-image: url("../../../base/images/sprite-ckan-icons.png");
  background-repeat: no-repeat;
  background-position: 16px 16px;
  text-indent: -900em;
  background: url("../../../base/images/sprite-resource-icons.png") no-repeat 0 0;
}
.format-label {
  width: 32px;
  height: 35px;
  background-position: 0px -62px;
}
.format-label[data-format=rdf],
.format-label[data-format*=rdf] {
  width: 32px;
  height: 35px;
  background-position: -32px -62px;
}
.format-label[data-format=pdf],
.format-label[data-format*=pdf] {
  width: 32px;
  height: 35px;
  background-position: -64px -62px;
}
.format-label[data-format=api],
.format-label[data-format*=api] {
  width: 32px;
  height: 35px;
  background-position: -96px -62px;
}
.format-label[data-format=zip],
.format-label[data-format*=zip] {
  width: 32px;
  height: 35px;
  background-position: -128px -62px;
}
.format-label[data-format=xls],
.format-label[data-format*=xls] {
  width: 32px;
  height: 35px;
  background-position: -160px -62px;
}
.format-label[data-format=csv],
.format-label[data-format*=csv] {
  width: 32px;
  height: 35px;
  background-position: -192px -62px;
}
.format-label[data-format=txt],
.format-label[data-format*=txt] {
  width: 32px;
  height: 35px;
  background-position: -224px -62px;
}
.format-label[data-format=xml],
.format-label[data-format*=xml] {
  width: 32px;
  height: 35px;
  background-position: -256px -62px;
}
.format-label[data-format=json],
.format-label[data-format*=json] {
  width: 32px;
  height: 35px;
  background-position: -288px -62px;
}
.format-label[data-format=html],
.format-label[data-format*=html] {
  width: 32px;
  height: 35px;
  background-position: -320px -62px;
}
[class^="icon-"],
[class*=" icon-"] {
  display: inline-block;
  text-align: right;
  font-size: 14px;
  line-height: 1;
  width: 14px;
}
.btn [class^="icon-"],
.nav [class^="icon-"],
.module-heading [class^="icon-"],
.dropdown [class^="icon-"],
.btn [class*=" icon-"],
.nav [class*=" icon-"],
.module-heading [class*=" icon-"],
.dropdown [class*=" icon-"] {
  margin-right: 4px;
}
.info-block [class^="icon-"],
.info-block [class*=" icon-"] {
  float: left;
  font-size: 28px;
  width: 28px;
  margin-right: 5px;
  margin-top: 2px;
}
.breadcrumb .home .icon-home {
  font-size: 24px;
  width: 24px;
  vertical-align: -1px;
}
.info-block-small [class^="icon-"],
.info-block-small [class*=" icon-"] {
  font-size: 14px;
  width: 14px;
  margin-top: 1px;
}
.wrapper {
  *zoom: 1;
  background-color: #FFF;
  border: 1px solid #cccccc;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: 0 0 0 4px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: 0 0 0 4px rgba(0, 0, 0, 0.05);
  box-shadow: 0 0 0 4px rgba(0, 0, 0, 0.05);
  position: relative;
  background-color: #fff;
  margin-bottom: 20px;
  margin-left: 0;
}
.wrapper:before,
.wrapper:after {
  display: table;
  content: "";
  line-height: 0;
}
.wrapper:after {
  clear: both;
}
@media (min-width: 768px) {
  .wrapper {
    background-image: url("../../../base/images/nav.png");
    background-repeat: repeat-y;
    background-position: -54px 0px;
  }
}
@media (min-width: 980px) {
  .wrapper {
    background-position: 0px 0px;
  }
}
.wrapper.no-nav {
  background-image: none;
}
[role=main],
.main {
  position: relative;
  padding-bottom: 20px;
}
@media (min-width: 768px) {
  [role=main],
  .main {
    padding-top: 10px;
    background: #eeeeee url("../../../base/images/bg.png");
  }
}
[role=main] {
  min-height: 350px;
}
.main:after,
[role=main]:after {
  bottom: 0;
  border-top-width: 1px;
}
[role=main] .primary {
  float: right;
  margin-left: 0;
}
[role=main] .secondary {
  margin-left: 0;
}
/* Filters modal */
.no-text .text {
  display: none;
}
.js body.filters-modal {
  overflow: hidden;
}
.show-filters.btn,
.hide-filters {
  display: none;
}
@media (max-width: 768px) {
  .wrapper {
    margin: 0 -20px;
    border-width: 0;
    -webkit-box-shadow: 0;
    -moz-box-shadow: 0;
    box-shadow: 0;
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    border-radius: 0;
  }
  .js [role=main] .secondary .filters {
    display: none;
    position: fixed;
    overflow: auto;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    z-index: 1;
    padding: 10px;
    background-color: #000000;
    background-color: rgba(0, 0, 0, 0.5);
  }
  .js body.filters-modal .secondary .filters {
    display: block;
  }
  .js [role=main] .secondary .filters > div {
    background-color: #fff;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    overflow: hidden;
  }
  .js [role=main] .secondary .filters > div .module-footer {
    display: none;
  }
  .js body.filters-modal .secondary .filters .hide-filters {
    display: inline-block;
    position: absolute;
    top: 14px;
    right: 17px;
    opacity: 0.6;
  }
  .js body.filters-modal .secondary .filters .hide-filters i {
    font-size: 18px;
  }
  .js .show-filters.btn {
    display: inline-block;
  }
}
.primary > :last-child,
.secondary > :last-child {
  margin-bottom: 0;
}
.primary .primary {
  float: left;
  width: 467px;
  margin-left: 0;
  margin-bottom: 20px;
}
.primary .primary h1:first-child,
.primary .primary h2:first-child,
.primary .primary h3:first-child,
.primary .primary h4:first-child {
  margin-top: 0;
}
.primary .tertiary {
  float: left;
  width: 180px;
  margin-left: 18px;
  margin-bottom: 20px;
}
@media (min-width: 768px) {
  .hero {
    background: url("../../../base/images/background-tile.png");
  }
}
.hero:after {
  background-color: rgba(0, 0, 0, 0.09);
  background-image: -moz-linear-gradient(top, rgba(0, 0, 0, 0.15), rgba(0, 0, 0, 0));
  background-image: -ms-linear-gradient(top, rgba(0, 0, 0, 0.15), rgba(0, 0, 0, 0));
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(rgba(0, 0, 0, 0.15)), to(rgba(0, 0, 0, 0)));
  background-image: -webkit-linear-gradient(top, rgba(0, 0, 0, 0.15), rgba(0, 0, 0, 0));
  background-image: -o-linear-gradient(top, rgba(0, 0, 0, 0.15), rgba(0, 0, 0, 0));
  background-image: linear-gradient(top, rgba(0, 0, 0, 0.15), rgba(0, 0, 0, 0));
  background-repeat: repeat-x;
  background-color: #f6f6f6;
  border-bottom: 1px solid #d0d0d0;
  -webkit-border-radius: 3px 3px 0 0;
  -moz-border-radius: 3px 3px 0 0;
  border-radius: 3px 3px 0 0;
  -webkit-box-shadow: inset 0 -4px 0 rgba(0, 0, 0, 0.03);
  -moz-box-shadow: inset 0 -4px 0 rgba(0, 0, 0, 0.03);
  box-shadow: inset 0 -4px 0 rgba(0, 0, 0, 0.03);
}
.hero:after .back:hover {
  text-decoration: none;
}
.hero:after .back:hover span {
  text-decoration: underline;
}
.context-info .module-content {
  padding: 15px;
}
.context-info .image {
  margin-bottom: 10px;
}
.context-info .image img,
.context-info .image a {
  display: block;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.context-info p {
  overflow: auto;
}
.context-info code {
  display: block;
  font-weight: normal;
  padding: 0;
  margin: 0;
  overflow: auto;
}
.context-info h1.heading {
  margin: 0 0 5px 0;
  font-size: 18px;
  line-height: 1.3;
  -ms-word-break: break-all;
  word-break: break-all;
  /* Non standard for webkit */
  word-break: break-word;
  -webkit-hyphens: auto;
  -moz-hyphens: auto;
  -ms-hyphens: auto;
  hyphens: auto;
}
.context-info .info {
  margin-top: 15px;
  padding-top: 10px;
  border-top: 1px dotted #DDD;
  word-break: break-word;
}
.context-info .info dl dd {
  margin-top: 3px;
  margin-left: 0;
}
.context-info .nums {
  *zoom: 1;
  margin-top: 15px;
  padding-top: 10px;
  padding-bottom: 0;
  border-top: 1px dotted #DDD;
}
.context-info .nums:before,
.context-info .nums:after {
  display: table;
  content: "";
  line-height: 0;
}
.context-info .nums:after {
  clear: both;
}
.context-info .nums dl {
  float: left;
  width: 50%;
  margin: 5px 0 0 0;
  color: #444444;
}
.context-info .nums dl dt {
  display: block;
  font-size: 13px;
  font-weight: 300;
}
.context-info .nums dl dd {
  display: block;
  font-size: 30px;
  font-weight: 700;
  line-height: 36px;
  margin-left: 0;
}
.context-info .nums dl dd .smallest {
  font-size: 13px;
}
.context-info .nums dl dd .smaller {
  font-size: 16px;
}
.context-info .nums dl dd .small {
  font-size: 21px;
}
.context-info .follow_button {
  margin-top: 15px;
}
.context-info.editing .module-content {
  margin-top: 0;
}
.flash-messages .alert {
  -webkit-box-shadow: 0 0 0 1px #ffffff;
  -moz-box-shadow: 0 0 0 1px #ffffff;
  box-shadow: 0 0 0 1px #ffffff;
}
.homepage .row {
  position: relative;
}
.homepage .module-search {
  padding: 5px;
  margin: 20px 0 0 0;
  color: #ffffff;
  background: #ffffff;
}
.homepage .module-search .search-giant {
  margin-bottom: 10px;
}
.homepage .module-search .search-giant input {
  border-color: #003f52;
}
.homepage .module-search .module-content {
  -webkit-border-radius: 3px 3px 0 0;
  -moz-border-radius: 3px 3px 0 0;
  border-radius: 3px 3px 0 0;
  background-color: #e73892;
  border-bottom: none;
}
.homepage .module-search .module-content .heading {
  margin-top: 0;
  margin-bottom: 7px;
  font-size: 24px;
  line-height: 40px;
}
.homepage .module-search .tags {
  *zoom: 1;
  padding: 5px 10px 10px 10px;
  background-color: #d31979;
  -webkit-border-radius: 0 0 3px 3px;
  -moz-border-radius: 0 0 3px 3px;
  border-radius: 0 0 3px 3px;
}
.homepage .module-search .tags:before,
.homepage .module-search .tags:after {
  display: table;
  content: "";
  line-height: 0;
}
.homepage .module-search .tags:after {
  clear: both;
}
.homepage .module-search .tags h3,
.homepage .module-search .tags .tag {
  display: block;
  float: left;
  margin: 5px 10px 0 0;
}
.homepage .module-search .tags h3 {
  font-size: 14px;
  line-height: 20px;
  padding: 2px 8px;
}
.homepage .group-list {
  margin: 0;
}
.homepage .box .inner {
  padding: 20px 25px;
}
.homepage .stats h3 {
  margin: 0 0 10px 0;
}
.homepage .stats ul {
  margin: 0;
  list-style: none;
  *zoom: 1;
}
.homepage .stats ul:before,
.homepage .stats ul:after {
  display: table;
  content: "";
  line-height: 0;
}
.homepage .stats ul:after {
  clear: both;
}
.homepage .stats ul li {
  float: left;
  width: 25%;
  font-weight: 300;
}
.homepage .stats ul li a {
  display: block;
}
.homepage .stats ul li a b {
  display: block;
  font-size: 35px;
  line-height: 1.5;
}
.homepage .stats ul li a:hover {
  text-decoration: none;
}
.homepage.layout-2 .stats {
  margin-top: 20px;
}
@media (min-width: 768px) {
  .homepage [role=main] {
    padding: 20px 0;
  }
  .homepage.layout-1 .row1 .col2 {
    position: absolute;
    bottom: 0;
    right: 0;
  }
  .homepage.layout-1 .row1 .col2 .module-search {
    bottom: 0;
    left: 0;
    right: 0;
  }
}
.account-masthead {
  *zoom: 1;
  min-height: 30px;
  color: #ffffff;
  background: #d31979 url("../../../base/images/bg.png");
}
.account-masthead:before,
.account-masthead:after {
  display: table;
  content: "";
  line-height: 0;
}
.account-masthead:after {
  clear: both;
}
.account-masthead .account {
  float: right;
}
.account-masthead .account ul {
  *zoom: 1;
}
.account-masthead .account ul:before,
.account-masthead .account ul:after {
  display: table;
  content: "";
  line-height: 0;
}
.account-masthead .account ul:after {
  clear: both;
}
.account-masthead .account ul li {
  display: block;
  float: left;
  border-left: 1px solid #bc176c;
}
.account-masthead .account ul li a {
  display: block;
  color: #f9cde4;
  font-size: 13px;
  font-weight: bold;
  padding: 0 10px;
  line-height: 31px;
}
.account-masthead .account ul li a span.username,
.account-masthead .account ul li a span.text {
  margin: 0 2px 0 4px;
}
.account-masthead .account ul li a span.text {
  position: absolute;
  top: -9999px;
  left: -9999px;
}
.account-masthead .account ul li a:hover {
  color: #fbe1ef;
  background-color: #bc176c;
  text-decoration: none;
}
.account-masthead .account ul li a.sub {
  font-weight: 300;
}
.account-masthead .account ul li a .btn {
  vertical-align: 1px;
  margin-left: 3px;
}
.account-masthead .account .notifications a span.badge {
  font-size: 12px;
  margin-left: 3px;
  padding: 1px 6px;
  background-color: #bc176c;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  text-shadow: none;
  color: #f9cde4;
}
.account-masthead .account .notifications a:hover span {
  color: #ffffff;
  background-color: #a5145f;
}
.account-masthead .account .notifications.notifications-important a span.badge {
  color: #ffffff;
  background-color: #c9403a;
}
.account-masthead .account.authed .image {
  padding: 0 6px;
}
.account-masthead .account.authed .image img {
  vertical-align: -6px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.masthead {
  *zoom: 1;
  min-height: 55px;
  color: #ffffff;
  background: #e73892 url("../../../base/images/bg.png");
}
.masthead:before,
.masthead:after {
  display: table;
  content: "";
  line-height: 0;
}
.masthead:after {
  clear: both;
}
.masthead .container {
  position: relative;
}
.masthead a {
  color: #ffffff;
}
.masthead hgroup h1,
.masthead hgroup h2 {
  float: left;
  font-size: 30px;
  line-height: 1.5;
}
.masthead hgroup h1 {
  font-weight: 900;
  letter-spacing: -1px;
  margin: 3px 0;
}
.masthead hgroup h2 {
  position: absolute;
  bottom: -3px;
  left: 0;
  margin: 0;
  font-size: 15px;
  font-weight: normal;
  line-height: 1.2;
  white-space: nowrap;
}
.masthead .nav-collapse {
  padding-top: 10px;
}
.masthead .section {
  float: left;
}
.masthead input[type="text"] {
  border-color: #e42186;
}
.masthead .navigation {
  margin-right: 20px;
}
.masthead .navigation .nav-pills {
  margin-bottom: 0;
}
.masthead .navigation .nav-pills li a:hover,
.masthead .navigation .nav-pills li.active a {
  background-color: #d31979;
}
.masthead .nav > li > a,
.masthead .nav > li > a:focus,
.masthead .nav > li > a:hover,
.masthead .nav > .active > a,
.masthead .nav > .active > a:hover,
.masthead .nav > .active > a:focus {
  color: #fff;
  text-shadow: none;
}
.masthead .site-search {
  margin: 2px 8px 2px 0;
}
.masthead .site-search input {
  width: 200px;
  padding: 4px 10px;
}
.masthead .btn-navbar,
.masthead .btn-navbar:hover,
.masthead .btn-navbar:focus,
.masthead .btn-navbar:active,
.masthead .btn-navbar.active,
.masthead .btn-navbar.disabled,
.masthead .btn-navbar[disabled] {
  background-color: #d31979;
  background-image: none;
  border: none;
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
  text-shadow: none;
  margin-top: 15px;
}
.masthead .btn-navbar .icon-bar,
.masthead .btn-navbar:hover .icon-bar,
.masthead .btn-navbar:focus .icon-bar,
.masthead .btn-navbar:active .icon-bar,
.masthead .btn-navbar.active .icon-bar,
.masthead .btn-navbar.disabled .icon-bar,
.masthead .btn-navbar[disabled] .icon-bar {
  margin-right: 0;
}
.masthead .debug {
  position: absolute;
  top: 37px;
  left: 10px;
  color: rgba(255, 255, 255, 0.5);
}
@media (min-width: 980px) {
  .masthead .nav-collapse {
    float: right;
  }
}
@media (max-width: 767px) {
  .account-masthead {
    margin-left: -20px;
    margin-right: -20px;
    padding-left: 20px;
    padding-right: 20px;
  }
  .masthead .section {
    float: none;
  }
  .masthead .section .nav-collapse {
    margin-bottom: 25px;
  }
}
@media (max-width: 979px) {
  .masthead .container {
    padding-left: 20px;
    padding-right: 20px;
  }
  .masthead .site-search {
    display: none;
  }
}
.site-footer {
  *zoom: 1;
  min-height: 55px;
  color: #ffffff;
  background: #e73892 url("../../../base/images/bg.png");
  padding: 20px 0;
}
.site-footer:before,
.site-footer:after {
  display: table;
  content: "";
  line-height: 0;
}
.site-footer:after {
  clear: both;
}
.site-footer .container {
  position: relative;
}
.site-footer a {
  color: #ffffff;
}
.site-footer hgroup h1,
.site-footer hgroup h2 {
  float: left;
  font-size: 30px;
  line-height: 1.5;
}
.site-footer hgroup h1 {
  font-weight: 900;
  letter-spacing: -1px;
  margin: 3px 0;
}
.site-footer hgroup h2 {
  position: absolute;
  bottom: -3px;
  left: 0;
  margin: 0;
  font-size: 15px;
  font-weight: normal;
  line-height: 1.2;
  white-space: nowrap;
}
.site-footer .nav-collapse {
  padding-top: 10px;
}
.site-footer .section {
  float: left;
}
.site-footer input[type="text"] {
  border-color: #e42186;
}
.site-footer .navigation {
  margin-right: 20px;
}
.site-footer .navigation .nav-pills {
  margin-bottom: 0;
}
.site-footer .navigation .nav-pills li a:hover,
.site-footer .navigation .nav-pills li.active a {
  background-color: #d31979;
}
.site-footer .nav > li > a,
.site-footer .nav > li > a:focus,
.site-footer .nav > li > a:hover,
.site-footer .nav > .active > a,
.site-footer .nav > .active > a:hover,
.site-footer .nav > .active > a:focus {
  color: #fff;
  text-shadow: none;
}
.site-footer .site-search {
  margin: 2px 8px 2px 0;
}
.site-footer .site-search input {
  width: 200px;
  padding: 4px 10px;
}
.site-footer .btn-navbar,
.site-footer .btn-navbar:hover,
.site-footer .btn-navbar:focus,
.site-footer .btn-navbar:active,
.site-footer .btn-navbar.active,
.site-footer .btn-navbar.disabled,
.site-footer .btn-navbar[disabled] {
  background-color: #d31979;
  background-image: none;
  border: none;
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
  text-shadow: none;
  margin-top: 15px;
}
.site-footer .btn-navbar .icon-bar,
.site-footer .btn-navbar:hover .icon-bar,
.site-footer .btn-navbar:focus .icon-bar,
.site-footer .btn-navbar:active .icon-bar,
.site-footer .btn-navbar.active .icon-bar,
.site-footer .btn-navbar.disabled .icon-bar,
.site-footer .btn-navbar[disabled] .icon-bar {
  margin-right: 0;
}
.site-footer .debug {
  position: absolute;
  top: 37px;
  left: 10px;
  color: rgba(255, 255, 255, 0.5);
}
.site-footer,
.site-footer label,
.site-footer small {
  color: #f5afd3;
}
.site-footer a {
  color: #f5afd3;
}
.footer-links ul li {
  margin-bottom: 5px;
}
.attribution small {
  color: #f5afd3;
  font-size: 12px;
}
.attribution .ckan-footer-logo {
  display: block;
  width: 68px;
  height: 21px;
  margin-top: 2px;
  background: url("../../../base/images/ckan-logo-footer.png") no-repeat top left;
  text-indent: -900em;
}
.lang-select {
  *zoom: 1;
}
.lang-select:before,
.lang-select:after {
  display: table;
  content: "";
  line-height: 0;
}
.lang-select:after {
  clear: both;
}
.lang-select label,
.lang-select select,
.lang-select .lang-container {
  float: left;
  margin-top: 0;
}
.lang-dropdown {
  color: #000000;
}
.lang-dropdown li {
  width: auto;
}
.table-selected td {
  background-color: #f5f5f5;
}
.table-selected td .edit {
  display: block;
}
.table-bulk-edit th input {
  top: -5px;
}
.table-bulk-edit .table-actions .btn-group {
  float: left;
  margin: 0 10px 0 0;
}
.table-bulk-edit .context p {
  margin-bottom: 0;
}
.table-header thead th {
  background-color: #f6f6f6;
}
.table-edit-hover .edit {
  display: none;
  float: right;
}
.table-edit-hover tr:hover .edit {
  display: block;
}
.js .table-toggle-more .toggle-more {
  display: none;
}
.js .table-toggle-more .show-more {
  display: inline;
}
.js .table-toggle-more .show-less {
  display: none;
}
.js .table-toggle-more .toggle-seperator {
  display: table-row;
}
.js .table-toggle-more .toggle-seperator td {
  height: 11px;
  padding: 0;
  background-image: url("../../../base/images/table-seperator.png");
}
.js .table .toggle-show td {
  background: none;
  text-align: center;
}
.js .table-toggle-less .show-less {
  display: inline;
}
.js .table-toggle-less .show-more {
  display: none;
}
.js .table-toggle-less .toggle-seperator {
  display: none;
}
.profile .empty,
.profile .dataset-list {
  margin-bottom: 20px;
}
.activity {
  margin: 10px 0;
  padding: 0;
  list-style-type: none;
  background: transparent url('../../../base/images/dotted.png') 14px 0 repeat-y;
}
.activity .item {
  position: relative;
  margin: 0 0 15px 0;
  padding: 0;
  *zoom: 1;
}
.activity .item:before,
.activity .item:after {
  display: table;
  content: "";
  line-height: 0;
}
.activity .item:after {
  clear: both;
}
.activity .item .icon {
  display: block;
  position: absolute;
  top: 0;
  left: 0;
  width: 30px;
  height: 30px;
  line-height: 30px;
  text-align: center;
  color: #ffffff;
  text-shadow: 0 1px 2px rgba(0, 0, 0, 0.2);
  font-weight: normal;
  margin-right: 10px;
  -webkit-border-radius: 100px;
  -moz-border-radius: 100px;
  border-radius: 100px;
  -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.2);
  -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.2);
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.2);
}
.activity .item .gravatar {
  -webkit-border-radius: 100px;
  -moz-border-radius: 100px;
  border-radius: 100px;
}
.activity .item .actor .gravatar {
  position: absolute;
  top: 0;
  left: 40px;
}
.activity .item p {
  font-size: 14px;
  line-height: 1.5;
  margin: 5px 0 0 80px;
}
.activity .item .date {
  color: #999;
  font-size: 12px;
  white-space: nowrap;
}
.activity .item .new {
  display: block;
  position: absolute;
  overflow: hidden;
  top: -3px;
  left: -3px;
  width: 10px;
  height: 10px;
  background-color: #A35647;
  border: 1px solid #FFF;
  text-indent: -1000px;
  -webkit-border-radius: 100px;
  -moz-border-radius: 100px;
  border-radius: 100px;
  -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2);
  -moz-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2);
}
.activity .item.no-avatar p {
  margin-left: 40px;
}
.activity .load-less {
  margin-bottom: 15px;
}
.popover {
  width: 300px;
}
.popover .popover-title {
  font-weight: bold;
  margin-bottom: 0;
}
.popover p.about {
  margin: 0 0 10px 0;
}
.popover .popover-close {
  float: right;
  text-decoration: none;
}
.popover .popover-content {
  font-size: 14px;
  line-height: 20px;
  color: #444444;
  word-break: break-all;
}
.popover .popover-content dl {
  margin: 0;
}
.popover .popover-content dl dd {
  margin-left: 0;
  margin-bottom: 10px;
}
.activity .item .icon {
  background-color: #999999;
}
.activity .item.failure .icon {
  background-color: #b95252;
}
.activity .item.success .icon {
  background-color: #69a67a;
}
.activity .item.added-tag .icon {
  background-color: #6995a6;
}
.activity .item.changed-group .icon {
  background-color: #767dce;
}
.activity .item.changed-package .icon {
  background-color: #8c76ce;
}
.activity .item.changed-package_extra .icon {
  background-color: #769ace;
}
.activity .item.changed-resource .icon {
  background-color: #aa76ce;
}
.activity .item.changed-user .icon {
  background-color: #76b8ce;
}
.activity .item.changed-organization .icon {
  background-color: #699fa6;
}
.activity .item.deleted-group .icon {
  background-color: #b95252;
}
.activity .item.deleted-package .icon {
  background-color: #b97452;
}
.activity .item.deleted-package_extra .icon {
  background-color: #b95274;
}
.activity .item.deleted-resource .icon {
  background-color: #b99752;
}
.activity .item.deleted-organization .icon {
  background-color: #b95297;
}
.activity .item.new-group .icon {
  background-color: #69a67a;
}
.activity .item.new-package .icon {
  background-color: #69a68e;
}
.activity .item.new-package_extra .icon {
  background-color: #6ca669;
}
.activity .item.new-resource .icon {
  background-color: #81a669;
}
.activity .item.new-user .icon {
  background-color: #69a6a3;
}
.activity .item.new-organization .icon {
  background-color: #81a669;
}
.activity .item.removed-tag .icon {
  background-color: #b95297;
}
.activity .item.deleted-related-item .icon {
  background-color: #b9b952;
}
.activity .item.follow-dataset .icon {
  background-color: #767dce;
}
.activity .item.follow-user .icon {
  background-color: #8c76ce;
}
.activity .item.new-related-item .icon {
  background-color: #95a669;
}
.activity .item.follow-group .icon {
  background-color: #8ba669;
}
.dropdown:hover .dropdown-menu {
  display: block;
}
.js .dropdown .dropdown-menu,
.js .dropdown:hover .dropdown-menu {
  display: none;
}
.js .dropdown.open .dropdown-menu {
  display: block;
}
#followee-filter .btn {
  *zoom: 1;
}
#followee-filter .btn:before,
#followee-filter .btn:after {
  display: table;
  content: "";
  line-height: 0;
}
#followee-filter .btn:after {
  clear: both;
}
#followee-filter .btn span,
#followee-filter .btn strong {
  display: block;
  float: left;
  line-height: 1.5;
}
#followee-filter .btn span {
  font-weight: normal;
}
#followee-filter .btn strong {
  margin: 0 5px;
  white-space: nowrap;
  max-width: 90px;
  overflow: hidden;
  text-overflow: ellipsis;
}
.dashboard-context {
  position: relative;
  margin-bottom: 20px;
  padding: 20px;
  border-bottom: 1px solid #DCDCDC;
  background-color: #f6f6f6;
  -webkit-border-radius: 3px 0 0 0;
  -moz-border-radius: 3px 0 0 0;
  border-radius: 3px 0 0 0;
}
.dashboard-context h2 {
  margin-bottom: 10px;
}
.dashboard-context .arrow {
  position: absolute;
  content: ' ';
  top: 30px;
  right: -10px;
  width: 10px;
  height: 21px;
  background: transparent url("../../../base/images/dashboard-followee-related.png");
}
.popover-followee .popover-title {
  display: none;
}
.popover-followee .popover-content {
  padding: 0;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.popover-followee .empty {
  padding: 10px;
}
.popover-followee .popover-header {
  *zoom: 1;
  background-color: whiteSmoke;
  padding: 5px;
  border-bottom: 1px solid #cccccc;
  -webkit-border-radius: 3px 3px 0 0;
  -moz-border-radius: 3px 3px 0 0;
  border-radius: 3px 3px 0 0;
}
.popover-followee .popover-header:before,
.popover-followee .popover-header:after {
  display: table;
  content: "";
  line-height: 0;
}
.popover-followee .popover-header:after {
  clear: both;
}
.popover-followee .popover-header .input-prepend {
  margin-bottom: 0;
}
.popover-followee .popover-header .add-on,
.popover-followee .popover-header input {
  float: left;
  margin: 0;
}
.popover-followee .popover-header .add-on {
  padding: 4px 8px 4px 12px;
  border-right-width: 0;
  -webkit-border-radius: 100px 0 0 100px;
  -moz-border-radius: 100px 0 0 100px;
  border-radius: 100px 0 0 100px;
}
.popover-followee .popover-header input {
  padding: 4px 12px 4px 8px;
  font-size: 13px;
  width: 207px;
  -webkit-border-radius: 0 100px 100px 0;
  -moz-border-radius: 0 100px 100px 0;
  border-radius: 0 100px 100px 0;
}
.popover-followee .nav {
  padding: 0;
  margin: 0;
  max-height: 205px;
  overflow: auto;
  -webkit-border-radius: 0 0 3px 3px;
  -moz-border-radius: 0 0 3px 3px;
  border-radius: 0 0 3px 3px;
}
.popover-followee .nav li a {
  display: block;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  padding: 7px 10px 7px 15px;
  margin: 0;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.popover-followee .nav li a i {
  background-color: #e73892;
  color: #ffffff;
  margin-right: 11px;
  padding: 3px 5px;
  line-height: 1;
  -webkit-border-radius: 100px;
  -moz-border-radius: 100px;
  border-radius: 100px;
  -webkit-box-shadow: inset 0 1px 2x rgba(0, 0, 0, 0.2);
  -moz-box-shadow: inset 0 1px 2x rgba(0, 0, 0, 0.2);
  box-shadow: inset 0 1px 2x rgba(0, 0, 0, 0.2);
}
.popover-followee .nav li a:hover i {
  background-color: #000;
}
.popover-followee .nav li.active a i {
  color: #e73892;
  background-color: #ffffff;
}
.dashboard-me {
  *zoom: 1;
  padding: 15px 15px 0 15px;
}
.dashboard-me:before,
.dashboard-me:after {
  display: table;
  content: "";
  line-height: 0;
}
.dashboard-me:after {
  clear: both;
}
.dashboard-me img {
  float: left;
  margin-right: 10px;
  -webkit-border-radius: 100px;
  -moz-border-radius: 100px;
  border-radius: 100px;
}
.dashboard-me strong {
  display: block;
  font-size: 16px;
  margin: 3px 0;
}
.resource-view-filters {
  margin-bottom: 1em;
}
.resource-view-filters .resource-view-filter {
  margin-bottom: 1.0em;
}
.resource-view-filters .resource-view-remove-filter {
  cursor: pointer;
  color: #b55457;
}
.resource-view-filters .resource-view-filter-values .select2-container {
  margin-right: 0.3em;
  margin-bottom: 0.2em;
  width: 24% !important;
}
.resource-view-filters .resource-view-filter-values .select2-container .select2-search-choice-close {
  left: auto;
}
.datapusher-status-link:hover {
  text-decoration: none;
}
.datapusher-status.status-unknown {
  color: #bbb;
}
.datapusher-status.status-pending {
  color: #FFCC00;
}
.datapusher-status.status-error {
  color: red;
}
.datapusher-status.status-complete {
  color: #009900;
}
body {
  background: #e73892 url("../../../base/images/bg.png");
}
[hidden] {
  display: none;
}
table {
  table-layout: fixed;
}
thead th {
  vertical-align: top;
}
td,
th {
  word-wrap: break-word;
}
table .metric {
  width: 140px;
}
code {
  color: #000000;
  border: none;
  background: none;
  white-space: normal;
}
pre {
  border: none;
  background: none;
  padding-left: 0;
  padding-right: 0;
}
mark {
  background: #fdf7e9;
}
blockquote p {
  font-size: 1em;
}
iframe {
  border: none;
}
.embedded-content h1 {
  font-size: 1.4em;
}
.embedded-content h2 {
  font-size: 1.4em;
}
.embedded-content h3 {
  font-size: 1.2em;
}
.popular {
  text-indent: -999em;
}
.empty {
  color: #aaaaaa;
  font-style: italic;
}
.page-heading {
  margin-top: 0;
  margin-bottom: 16px;
}
.m-top {
  margin-top: 15px;
}
.m-left {
  margin-left: 15px;
}
.m-right {
  margin-right: 15px;
}
.m-bottom {
  margin-bottom: 15px;
}
.no-margin {
  margin: 0;
}
.reduced-margin {
  margin: 3px 5px;
}
.p-top {
  padding-top: 15px;
}
.p-left {
  padding-left: 15px;
}
.p-right {
  padding-right: 15px;
}
.p-bottom {
  padding-bottom: 15px;
}
.no-padding {
  padding: 0;
}
.reduced-padding {
  padding: 3px 5px;
}
.ie .lang-dropdown {
  position: relative;
  top: -20px;
}
.ie .module-popup {
  border-bottom: none;
}
.ie .banner {
  top: 0;
  right: 0;
  width: auto;
}
.ie .group-listing {
  margin-left: -24px;
}
.ie .toolbar .breadcrumb {
  filter: none;
}
.ie .toolbar .breadcrumb li {
  float: left;
}
.ie .toolbar .breadcrumb li:after {
  margin: 0 0.2em;
}
.ie9 .control-large input {
  height: 56px;
}
.ie8 .account-masthead a.image,
.ie8 .account-masthead .username {
  white-space: nowrap;
}
.ie9 .homepage .media.module-heading .media-image img,
.ie8 .homepage .media.module-heading .media-image img,
.ie7 .homepage .media.module-heading .media-image img {
  width: 85px !important;
}
.ie8 .masthead .nav-collapse,
.ie7 .masthead .nav-collapse {
  float: right;
}
.ie8 [role=main],
.ie7 [role=main],
.ie8 .main,
.ie7 .main {
  padding-top: 10px;
  background: #eeeeee url("../../../base/images/bg.png");
}
.ie8 .hero,
.ie7 .hero {
  background: url("../../../base/images/background-tile.png");
}
.ie8 .hero .hero-primary.module-popup .box,
.ie7 .hero .hero-primary.module-popup .box {
  padding-bottom: 20px !important;
  margin-bottom: 0 !important;
}
.ie8 .lang-dropdown,
.ie7 .lang-dropdown {
  position: relative !important;
  top: -90px !important;
}
.ie7 .alert {
  position: relative;
}
.ie7 .alert .close {
  position: absolute;
  top: 6px !important;
  right: 20px;
}
.ie7 .media-item {
  width: 30%;
}
.ie7 .tags .tag-list {
  *zoom: 1;
}
.ie7 .tags .tag-list:before,
.ie7 .tags .tag-list:after {
  display: table;
  content: "";
  line-height: 0;
}
.ie7 .tags .tag-list:after {
  clear: both;
}
.ie7 .tags .tag-list li {
  display: block;
  float: left;
}
.ie7 .tags h3 {
  float: left;
}
.ie7 .tags .tag {
  display: block;
}
.ie7 .search-giant input {
  width: 95%;
}
.ie7 .control-full input,
.ie7 .control-full select,
.ie7 .control-full textarea {
  width: 95%;
}
.ie7 .control-full.control-large .controls input {
  padding-bottom: 20px;
}
.ie7 .controls {
  position: relative;
}
.ie7 .controls .info-block,
.ie7 .controls .info-inline {
  position: absolute;
  top: 0;
  right: 0;
}
.ie7 .form-horizontal .controls {
  margin-left: 0;
}
.ie7 .control-custom .checkbox {
  *display: inline;
  /* IE7 inline-block hack */
  *zoom: 1;
}
.ie7 .stages {
  overflow: hidden;
  background-color: #ededed;
}
.ie7 .stages li {
  height: 30px;
  width: 27.5%;
}
.ie7 .stages li button,
.ie7 .stages li span {
  display: block;
  height: 30px;
  padding-left: 20px;
}
.ie7 .stages li button {
  height: 50px;
}
.ie7 .stages li .highlight {
  width: auto;
}
.ie7 .account-masthead .account a i {
  line-height: 31px;
}
.ie7 .masthead {
  position: relative;
  z-index: 1;
}
.ie7 .masthead .logo img,
.ie7 .masthead nav {
  *display: inline;
  /* IE7 inline-block hack */
  *zoom: 1;
}
.ie7 .masthead .header-image {
  display: block;
}
.ie7 .masthead .account .dropdown-menu {
  z-index: 10000;
}
.ie7 .module-narrow .nav-item.image {
  *zoom: 1;
}
.ie7 .module-narrow .nav-item.image:before,
.ie7 .module-narrow .nav-item.image:after {
  display: table;
  content: "";
  line-height: 0;
}
.ie7 .module-narrow .nav-item.image:after {
  clear: both;
}
.ie7 .nav-facet .nav-item.active a {
  content: 'x';
}
.ie7 .toolbar .breadcrumb li {
  padding-right: 10px;
  margin-right: 5px;
  background: transparent url("../../../base/images/breadcrumb-slash-ie7.png") 100% 50% no-repeat;
}
.ie7 .toolbar .breadcrumb li.active {
  background-image: none;
}
.ie7 .module-heading {
  *zoom: 1;
  position: relative;
}
.ie7 .module-heading:before,
.ie7 .module-heading:after {
  display: table;
  content: "";
  line-height: 0;
}
.ie7 .module-heading:after {
  clear: both;
}
.ie7 .module-heading .media-content {
  position: relative;
}
.ie7 .module-heading .media-image img {
  float: left;
}
.ie7 .group-listing {
  position: relative;
  zoom: 1;
}
.ie7 .resource-item {
  position: static;
  padding-bottom: 1px;
}
.ie7 .resource-item .heading {
  position: relative;
}
.ie7 .resource-item .format-label {
  left: -48px;
}
.ie7 .resource-item .btn-group {
  position: relative;
  float: right;
  top: -35px;
  right: 0;
}
.ie7 .media-overlay .media-heading {
  background-color: #000;
}
